labels = {
    "label_hash": "6979f252-ba3a-4beb-89bd-f00d0ff5eb85",
    "branch_name": "main",
    "dataset_hash": "d9f19c3c-5cd0-4f8c-b98c-6c0e24676224",
    "data_hash": "aaa6bc82-9f89-4545-adbb-f271bf28cf99",
    "is_shadow_data": False,
    "created_at": "Thu, 09 Feb 2023 14:12:03 UTC",
    "last_edited_at": "Thu, 09 Feb 2023 14:12:03 UTC",
    "dataset_title": "One image group",
    "data_title": "image-group-8375e",
    "data_type": "img_group",
    "data_units": {
        "f850dfb4-7146-49e0-9afc-2b9434a64a9f": {
            "data_hash": "f850dfb4-7146-49e0-9afc-2b9434a64a9f",
            "data_title": "Screenshot 2021-11-24 at 18.35.57.png",
            "data_link": "https://storage.googleapis.com/cord-ai-platform.appspot.com/cord-images-prod/yiA5JxmLEGSoEcJAuxr3AJdDDXE2/f850dfb4-7146-49e0-9afc-2b9434a64a9f?X-Goog-Algorithm=GOOG4-RSA-SHA256&X-Goog-Credential=firebase-adminsdk-64w1p%40cord-ai-platform.iam.gserviceaccount.com%2F20230210%2Fauto%2Fstorage%2Fgoog4_request&X-Goog-Date=20230210T112705Z&X-Goog-Expires=604800&X-Goog-SignedHeaders=host&X-Goog-Signature=3294f34fbc5be24f6e43c3d6e47e1dc478181a8392eb24fdbda134fe1bd4ecde1278d8a4c93e566b82247ca66e8c051a7974f07586975dbf6187284a10e7335903f1dea2927c037bbe441be67df76cf1de1a24518f6e0630e894f91f2f47e59c16e4810fc9db4e84b95add963c1ab48336594bfd89e997066d3fc5b821e0e276fc2a1a473f435620d3a8568369c16b6d822e16bcd8ac918f2d63bc469d1bb9bc6a0ad9a0dbe92b8f9efaf3ee94a2b39791dd5a5a06cfdcea1610d855b8e02d7e329bf035ad2266c8319e956b23d8278d66ee8198fabc634b74808fcadda3e4098f6442ee42865ff544f149089e6722818be4cd1e84dac53a95ff724d2b76118f",
            "data_type": "image/png",
            "data_sequence": "0",
            "width": 952,
            "height": 678,
            "labels": {
                "objects": [
                    {
                        "name": "Box",
                        "color": "#D33115",
                        "shape": "bounding_box",
                        "value": "box",
                        "createdAt": "Fri, 10 Feb 2023 11:08:03 UTC",
                        "createdBy": "denis@cord.tech",
                        "confidence": 1,
                        "objectHash": "SRIJiIjv",
                        "featureHash": "MjI2NzEy",
                        "lastEditedAt": "Fri, 10 Feb 2023 11:10:38 UTC",
                        "lastEditedBy": "denis@cord.tech",
                        "manualAnnotation": True,
                        "boundingBox": {"h": 0.0687, "w": 0.0709, "x": 0.3812, "y": 0.4186},
                        "reviews": [
                            {
                                "id": 2134704,
                                "exists": True,
                                "status": "ASSIGNED",
                                "comment": "reject round 1\n",
                                "task_id": 2970724,
                                "user_id": 524,
                                "approved": False,
                                "instance": {
                                    "name": "Box",
                                    "range": [[0, 2]],
                                    "shape": "bounding_box",
                                    "objectID": 0,
                                    "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                    "objectHash": "SRIJiIjv",
                                    "featureHash": "MjI2NzEy",
                                    "classifications": [],
                                    "manual_annotation": True,
                                },
                                "metadata": None,
                                "createdAt": "Fri, 10 Feb 2023 11:08:41 UTC",
                                "createdBy": "denis@cord.tech",
                                "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                "created_at": "2023-02-10 11:08:26",
                                "rejections": None,
                                "user_email": "denis@cord.tech",
                                "granularity": "OBJECT",
                                "granularity_id": "SRIJiIjv",
                                "last_edited_at": "2023-02-10 11:08:29",
                                "displayed_status": "ASSIGNED",
                            },
                            {
                                "id": 2134704,
                                "exists": True,
                                "status": "ASSIGNED",
                                "comment": "reject round two\n",
                                "task_id": 2970724,
                                "user_id": 524,
                                "approved": False,
                                "instance": {
                                    "name": "Box",
                                    "range": [[0, 2]],
                                    "shape": "bounding_box",
                                    "objectID": 0,
                                    "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                    "objectHash": "SRIJiIjv",
                                    "featureHash": "MjI2NzEy",
                                    "classifications": [],
                                    "manual_annotation": True,
                                },
                                "metadata": {
                                    "reviews": [
                                        {
                                            "id": 2134704,
                                            "exists": True,
                                            "status": "ASSIGNED",
                                            "comment": "reject round 1\n",
                                            "task_id": 2970724,
                                            "user_id": 524,
                                            "approved": False,
                                            "instance": {
                                                "name": "Box",
                                                "range": [[0, 2]],
                                                "shape": "bounding_box",
                                                "objectID": 0,
                                                "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                                "objectHash": "SRIJiIjv",
                                                "featureHash": "MjI2NzEy",
                                                "classifications": [],
                                                "manual_annotation": True,
                                            },
                                            "metadata": None,
                                            "createdAt": "Fri, 10 Feb 2023 11:08:41 UTC",
                                            "createdBy": "yiA5JxmLEGSoEcJAuxr3AJdDDXE2",
                                            "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                            "created_at": "2023-02-10 11:08:26",
                                            "rejections": None,
                                            "user_email": "denis@cord.tech",
                                            "granularity": "OBJECT",
                                            "granularity_id": "SRIJiIjv",
                                            "last_edited_at": "2023-02-10 11:08:29",
                                            "displayed_status": "ASSIGNED",
                                        }
                                    ]
                                },
                                "createdAt": "Fri, 10 Feb 2023 11:10:01 UTC",
                                "createdBy": "denis@cord.tech",
                                "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                "created_at": "2023-02-10 11:08:26",
                                "rejections": None,
                                "user_email": "denis@cord.tech",
                                "granularity": "OBJECT",
                                "granularity_id": "SRIJiIjv",
                                "last_edited_at": "2023-02-10 11:09:49",
                                "displayed_status": "ASSIGNED",
                            },
                            {
                                "id": 2134704,
                                "exists": True,
                                "status": "ASSIGNED",
                                "comment": None,
                                "task_id": 2970724,
                                "user_id": 524,
                                "approved": True,
                                "instance": {
                                    "name": "Box",
                                    "range": [[0, 2]],
                                    "shape": "bounding_box",
                                    "objectID": 0,
                                    "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                    "objectHash": "SRIJiIjv",
                                    "featureHash": "MjI2NzEy",
                                    "classifications": [],
                                    "manual_annotation": True,
                                },
                                "metadata": {
                                    "reviews": [
                                        {
                                            "id": 2134704,
                                            "exists": True,
                                            "status": "ASSIGNED",
                                            "comment": "reject round 1\n",
                                            "task_id": 2970724,
                                            "user_id": 524,
                                            "approved": False,
                                            "instance": {
                                                "name": "Box",
                                                "range": [[0, 2]],
                                                "shape": "bounding_box",
                                                "objectID": 0,
                                                "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                                "objectHash": "SRIJiIjv",
                                                "featureHash": "MjI2NzEy",
                                                "classifications": [],
                                                "manual_annotation": True,
                                            },
                                            "metadata": None,
                                            "createdAt": "Fri, 10 Feb 2023 11:08:41 UTC",
                                            "createdBy": "yiA5JxmLEGSoEcJAuxr3AJdDDXE2",
                                            "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                            "created_at": "2023-02-10 11:08:26",
                                            "rejections": None,
                                            "user_email": "denis@cord.tech",
                                            "granularity": "OBJECT",
                                            "granularity_id": "SRIJiIjv",
                                            "last_edited_at": "2023-02-10 11:08:29",
                                            "displayed_status": "ASSIGNED",
                                        },
                                        {
                                            "id": 2134704,
                                            "exists": True,
                                            "status": "ASSIGNED",
                                            "comment": "reject round two\n",
                                            "task_id": 2970724,
                                            "user_id": 524,
                                            "approved": False,
                                            "instance": {
                                                "name": "Box",
                                                "range": [[0, 2]],
                                                "shape": "bounding_box",
                                                "objectID": 0,
                                                "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                                "objectHash": "SRIJiIjv",
                                                "featureHash": "MjI2NzEy",
                                                "classifications": [],
                                                "manual_annotation": True,
                                            },
                                            "metadata": {
                                                "reviews": [
                                                    {
                                                        "id": 2134704,
                                                        "exists": True,
                                                        "status": "ASSIGNED",
                                                        "comment": "reject round 1\n",
                                                        "task_id": 2970724,
                                                        "user_id": 524,
                                                        "approved": False,
                                                        "instance": {
                                                            "name": "Box",
                                                            "range": [[0, 2]],
                                                            "shape": "bounding_box",
                                                            "objectID": 0,
                                                            "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                                            "objectHash": "SRIJiIjv",
                                                            "featureHash": "MjI2NzEy",
                                                            "classifications": [],
                                                            "manual_annotation": True,
                                                        },
                                                        "metadata": None,
                                                        "createdAt": "Fri, 10 Feb 2023 11:08:41 UTC",
                                                        "createdBy": "yiA5JxmLEGSoEcJAuxr3AJdDDXE2",
                                                        "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                                        "created_at": "2023-02-10 11:08:26",
                                                        "rejections": None,
                                                        "user_email": "denis@cord.tech",
                                                        "granularity": "OBJECT",
                                                        "granularity_id": "SRIJiIjv",
                                                        "last_edited_at": "2023-02-10 11:08:29",
                                                        "displayed_status": "ASSIGNED",
                                                    }
                                                ]
                                            },
                                            "createdAt": "Fri, 10 Feb 2023 11:10:01 UTC",
                                            "createdBy": "yiA5JxmLEGSoEcJAuxr3AJdDDXE2",
                                            "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                            "created_at": "2023-02-10 11:08:26",
                                            "rejections": None,
                                            "user_email": "denis@cord.tech",
                                            "granularity": "OBJECT",
                                            "granularity_id": "SRIJiIjv",
                                            "last_edited_at": "2023-02-10 11:09:49",
                                            "displayed_status": "ASSIGNED",
                                        },
                                    ]
                                },
                                "createdAt": "Fri, 10 Feb 2023 11:10:48 UTC",
                                "createdBy": "denis@cord.tech",
                                "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                "created_at": "2023-02-10 11:08:26",
                                "rejections": None,
                                "user_email": "denis@cord.tech",
                                "granularity": "OBJECT",
                                "granularity_id": "SRIJiIjv",
                                "last_edited_at": "2023-02-10 11:10:45",
                                "displayed_status": "ASSIGNED",
                            },
                        ],
                    },
                    {
                        "name": "Polyline",
                        "color": "#16406C",
                        "shape": "polyline",
                        "value": "polyline",
                        "polyline": {
                            "0": {"x": 0.7628, "y": 0.5645},
                            "1": {"x": 0.7718, "y": 0.5898},
                            "2": {"x": 0.7928, "y": 0.6305},
                            "3": {"x": 0.7958, "y": 0.6417},
                            "4": {"x": 0.8007, "y": 0.6585},
                            "5": {"x": 0.8027, "y": 0.6726},
                            "6": {"x": 0.7988, "y": 0.688},
                            "7": {"x": 0.7768, "y": 0.7119},
                            "8": {"x": 0.7588, "y": 0.7217},
                            "9": {"x": 0.7488, "y": 0.7245},
                            "10": {"x": 0.7388, "y": 0.7259},
                            "11": {"x": 0.7258, "y": 0.7245},
                            "12": {"x": 0.7148, "y": 0.7231},
                            "13": {"x": 0.6988, "y": 0.7203},
                        },
                        "createdAt": "Fri, 10 Feb 2023 11:08:23 UTC",
                        "createdBy": "denis@cord.tech",
                        "confidence": 1,
                        "objectHash": "983w0TxX",
                        "featureHash": "OTcxMzIy",
                        "lastEditedAt": "Fri, 10 Feb 2023 11:09:12 UTC",
                        "lastEditedBy": "denis@cord.tech",
                        "manualAnnotation": True,
                        "reviews": [
                            {
                                "id": 2134705,
                                "exists": True,
                                "status": "ASSIGNED",
                                "comment": None,
                                "task_id": 2970724,
                                "user_id": 524,
                                "approved": True,
                                "instance": {
                                    "name": "Polyline",
                                    "range": [[0, 0]],
                                    "shape": "polyline",
                                    "objectID": 0,
                                    "indexHash": "683e286d-1b42-4145-8185-edb6565a6568",
                                    "objectHash": "983w0TxX",
                                    "featureHash": "OTcxMzIy",
                                    "classifications": [],
                                    "manual_annotation": True,
                                },
                                "metadata": None,
                                "createdAt": "Fri, 10 Feb 2023 11:08:44 UTC",
                                "createdBy": "denis@cord.tech",
                                "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                "created_at": "2023-02-10 11:08:26",
                                "rejections": None,
                                "user_email": "denis@cord.tech",
                                "granularity": "OBJECT",
                                "granularity_id": "983w0TxX",
                                "last_edited_at": "2023-02-10 11:08:29",
                                "displayed_status": "ASSIGNED",
                            }
                        ],
                    },
                ],
                "classifications": [
                    {
                        "name": "Radio classification 1",
                        "value": "radio_classification_1",
                        "createdAt": "Fri, 10 Feb 2023 11:08:18 UTC",
                        "createdBy": "denis@cord.tech",
                        "confidence": 1,
                        "featureHash": "NzIxNTU1",
                        "lastEditedAt": "Fri, 10 Feb 2023 11:08:18 UTC",
                        "classificationHash": "hLs1sDAr",
                        "manualAnnotation": True,
                        "reviews": [
                            {
                                "id": 2134706,
                                "exists": True,
                                "status": "ASSIGNED",
                                "comment": "reject classification\n",
                                "task_id": 2970724,
                                "user_id": 524,
                                "approved": False,
                                "instance": {
                                    "name": "Radio classification 1",
                                    "range": [[0, 0]],
                                    "indexHash": "b55c46d5-54af-4cac-8e1f-25ba741925fa",
                                    "featureHash": "NzIxNTU1",
                                    "classifications": [
                                        {
                                            "name": "Radio classification 1",
                                            "value": "radio_classification_1",
                                            "answers": [
                                                {
                                                    "name": "cl 1 option 1",
                                                    "value": "cl_1_option_1",
                                                    "featureHash": "MTcwMjM5",
                                                }
                                            ],
                                            "featureHash": "MjI5MTA5",
                                            "manual_annotation": True,
                                        }
                                    ],
                                    "manual_annotation": True,
                                    "classificationHash": "hLs1sDAr",
                                    "hideDropdownButton": True,
                                },
                                "metadata": None,
                                "createdAt": "Fri, 10 Feb 2023 11:09:04 UTC",
                                "createdBy": "denis@cord.tech",
                                "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                "created_at": "2023-02-10 11:08:26",
                                "rejections": None,
                                "user_email": "denis@cord.tech",
                                "granularity": "CLASSIFICATION",
                                "granularity_id": "hLs1sDAr",
                                "last_edited_at": "2023-02-10 11:08:29",
                                "displayed_status": "ASSIGNED",
                            },
                            {
                                "id": 2134706,
                                "exists": True,
                                "status": "ASSIGNED",
                                "comment": "bad classification",
                                "task_id": 2970724,
                                "user_id": 524,
                                "approved": False,
                                "instance": {
                                    "name": "Radio classification 1",
                                    "range": [[0, 0]],
                                    "actions": [],
                                    "indexHash": "b55c46d5-54af-4cac-8e1f-25ba741925fa",
                                    "featureHash": "NzIxNTU1",
                                    "classifications": [
                                        {
                                            "name": "cl 1 2 text",
                                            "value": "cl_1_2_text",
                                            "answers": "new text",
                                            "featureHash": "MTg0MjIw",
                                            "manual_annotation": True,
                                        },
                                        {
                                            "name": "Radio classification 1",
                                            "value": "radio_classification_1",
                                            "answers": [
                                                {
                                                    "name": "cl 1 option 2",
                                                    "value": "cl_1_option_2",
                                                    "featureHash": "MjUzMTg1",
                                                }
                                            ],
                                            "featureHash": "MjI5MTA5",
                                            "manual_annotation": True,
                                        },
                                    ],
                                    "manual_annotation": True,
                                    "classificationHash": "hLs1sDAr",
                                    "hideDropdownButton": True,
                                },
                                "metadata": {
                                    "reviews": [
                                        {
                                            "id": 2134706,
                                            "exists": True,
                                            "status": "ASSIGNED",
                                            "comment": "reject classification\n",
                                            "task_id": 2970724,
                                            "user_id": 524,
                                            "approved": False,
                                            "instance": {
                                                "name": "Radio classification 1",
                                                "range": [[0, 0]],
                                                "indexHash": "b55c46d5-54af-4cac-8e1f-25ba741925fa",
                                                "featureHash": "NzIxNTU1",
                                                "classifications": [
                                                    {
                                                        "name": "Radio classification 1",
                                                        "value": "radio_classification_1",
                                                        "answers": [
                                                            {
                                                                "name": "cl 1 option 1",
                                                                "value": "cl_1_option_1",
                                                                "featureHash": "MTcwMjM5",
                                                            }
                                                        ],
                                                        "featureHash": "MjI5MTA5",
                                                        "manual_annotation": True,
                                                    }
                                                ],
                                                "manual_annotation": True,
                                                "classificationHash": "hLs1sDAr",
                                                "hideDropdownButton": True,
                                            },
                                            "metadata": None,
                                            "createdAt": "Fri, 10 Feb 2023 11:09:04 UTC",
                                            "createdBy": "yiA5JxmLEGSoEcJAuxr3AJdDDXE2",
                                            "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                            "created_at": "2023-02-10 11:08:26",
                                            "rejections": None,
                                            "user_email": "denis@cord.tech",
                                            "granularity": "CLASSIFICATION",
                                            "granularity_id": "hLs1sDAr",
                                            "last_edited_at": "2023-02-10 11:08:29",
                                            "displayed_status": "ASSIGNED",
                                        }
                                    ]
                                },
                                "createdAt": "Fri, 10 Feb 2023 11:10:14 UTC",
                                "createdBy": "denis@cord.tech",
                                "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                "created_at": "2023-02-10 11:08:26",
                                "rejections": None,
                                "user_email": "denis@cord.tech",
                                "granularity": "CLASSIFICATION",
                                "granularity_id": "hLs1sDAr",
                                "last_edited_at": "2023-02-10 11:09:49",
                                "displayed_status": "ASSIGNED",
                            },
                            {
                                "id": 2134706,
                                "exists": True,
                                "status": "ASSIGNED",
                                "comment": None,
                                "task_id": 2970724,
                                "user_id": 524,
                                "approved": True,
                                "instance": {
                                    "name": "Radio classification 1",
                                    "range": [[0, 0]],
                                    "actions": [],
                                    "indexHash": "b55c46d5-54af-4cac-8e1f-25ba741925fa",
                                    "featureHash": "NzIxNTU1",
                                    "classifications": [
                                        {
                                            "name": "cl 1 2 text",
                                            "value": "cl_1_2_text",
                                            "answers": "new text",
                                            "featureHash": "MTg0MjIw",
                                            "manual_annotation": True,
                                        },
                                        {
                                            "name": "Radio classification 1",
                                            "value": "radio_classification_1",
                                            "answers": [
                                                {
                                                    "name": "cl 1 option 2",
                                                    "value": "cl_1_option_2",
                                                    "featureHash": "MjUzMTg1",
                                                }
                                            ],
                                            "featureHash": "MjI5MTA5",
                                            "manual_annotation": True,
                                        },
                                    ],
                                    "manual_annotation": True,
                                    "classificationHash": "hLs1sDAr",
                                    "hideDropdownButton": True,
                                },
                                "metadata": {
                                    "reviews": [
                                        {
                                            "id": 2134706,
                                            "exists": True,
                                            "status": "ASSIGNED",
                                            "comment": "reject classification\n",
                                            "task_id": 2970724,
                                            "user_id": 524,
                                            "approved": False,
                                            "instance": {
                                                "name": "Radio classification 1",
                                                "range": [[0, 0]],
                                                "indexHash": "b55c46d5-54af-4cac-8e1f-25ba741925fa",
                                                "featureHash": "NzIxNTU1",
                                                "classifications": [
                                                    {
                                                        "name": "Radio classification 1",
                                                        "value": "radio_classification_1",
                                                        "answers": [
                                                            {
                                                                "name": "cl 1 option 1",
                                                                "value": "cl_1_option_1",
                                                                "featureHash": "MTcwMjM5",
                                                            }
                                                        ],
                                                        "featureHash": "MjI5MTA5",
                                                        "manual_annotation": True,
                                                    }
                                                ],
                                                "manual_annotation": True,
                                                "classificationHash": "hLs1sDAr",
                                                "hideDropdownButton": True,
                                            },
                                            "metadata": None,
                                            "createdAt": "Fri, 10 Feb 2023 11:09:04 UTC",
                                            "createdBy": "yiA5JxmLEGSoEcJAuxr3AJdDDXE2",
                                            "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                            "created_at": "2023-02-10 11:08:26",
                                            "rejections": None,
                                            "user_email": "denis@cord.tech",
                                            "granularity": "CLASSIFICATION",
                                            "granularity_id": "hLs1sDAr",
                                            "last_edited_at": "2023-02-10 11:08:29",
                                            "displayed_status": "ASSIGNED",
                                        },
                                        {
                                            "id": 2134706,
                                            "exists": True,
                                            "status": "ASSIGNED",
                                            "comment": "bad classification",
                                            "task_id": 2970724,
                                            "user_id": 524,
                                            "approved": False,
                                            "instance": {
                                                "name": "Radio classification 1",
                                                "range": [[0, 0]],
                                                "actions": [],
                                                "indexHash": "b55c46d5-54af-4cac-8e1f-25ba741925fa",
                                                "featureHash": "NzIxNTU1",
                                                "classifications": [
                                                    {
                                                        "name": "cl 1 2 text",
                                                        "value": "cl_1_2_text",
                                                        "answers": "new text",
                                                        "featureHash": "MTg0MjIw",
                                                        "manual_annotation": True,
                                                    },
                                                    {
                                                        "name": "Radio classification 1",
                                                        "value": "radio_classification_1",
                                                        "answers": [
                                                            {
                                                                "name": "cl 1 option 2",
                                                                "value": "cl_1_option_2",
                                                                "featureHash": "MjUzMTg1",
                                                            }
                                                        ],
                                                        "featureHash": "MjI5MTA5",
                                                        "manual_annotation": True,
                                                    },
                                                ],
                                                "manual_annotation": True,
                                                "classificationHash": "hLs1sDAr",
                                                "hideDropdownButton": True,
                                            },
                                            "metadata": {
                                                "reviews": [
                                                    {
                                                        "id": 2134706,
                                                        "exists": True,
                                                        "status": "ASSIGNED",
                                                        "comment": "reject classification\n",
                                                        "task_id": 2970724,
                                                        "user_id": 524,
                                                        "approved": False,
                                                        "instance": {
                                                            "name": "Radio classification 1",
                                                            "range": [[0, 0]],
                                                            "indexHash": "b55c46d5-54af-4cac-8e1f-25ba741925fa",
                                                            "featureHash": "NzIxNTU1",
                                                            "classifications": [
                                                                {
                                                                    "name": "Radio classification 1",
                                                                    "value": "radio_classification_1",
                                                                    "answers": [
                                                                        {
                                                                            "name": "cl 1 option 1",
                                                                            "value": "cl_1_option_1",
                                                                            "featureHash": "MTcwMjM5",
                                                                        }
                                                                    ],
                                                                    "featureHash": "MjI5MTA5",
                                                                    "manual_annotation": True,
                                                                }
                                                            ],
                                                            "manual_annotation": True,
                                                            "classificationHash": "hLs1sDAr",
                                                            "hideDropdownButton": True,
                                                        },
                                                        "metadata": None,
                                                        "createdAt": "Fri, 10 Feb 2023 11:09:04 UTC",
                                                        "createdBy": "yiA5JxmLEGSoEcJAuxr3AJdDDXE2",
                                                        "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                                        "created_at": "2023-02-10 11:08:26",
                                                        "rejections": None,
                                                        "user_email": "denis@cord.tech",
                                                        "granularity": "CLASSIFICATION",
                                                        "granularity_id": "hLs1sDAr",
                                                        "last_edited_at": "2023-02-10 11:08:29",
                                                        "displayed_status": "ASSIGNED",
                                                    }
                                                ]
                                            },
                                            "createdAt": "Fri, 10 Feb 2023 11:10:14 UTC",
                                            "createdBy": "yiA5JxmLEGSoEcJAuxr3AJdDDXE2",
                                            "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                            "created_at": "2023-02-10 11:08:26",
                                            "rejections": None,
                                            "user_email": "denis@cord.tech",
                                            "granularity": "CLASSIFICATION",
                                            "granularity_id": "hLs1sDAr",
                                            "last_edited_at": "2023-02-10 11:09:49",
                                            "displayed_status": "ASSIGNED",
                                        },
                                    ]
                                },
                                "createdAt": "Fri, 10 Feb 2023 11:10:48 UTC",
                                "createdBy": "denis@cord.tech",
                                "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                "created_at": "2023-02-10 11:08:26",
                                "rejections": None,
                                "user_email": "denis@cord.tech",
                                "granularity": "CLASSIFICATION",
                                "granularity_id": "hLs1sDAr",
                                "last_edited_at": "2023-02-10 11:10:45",
                                "displayed_status": "ASSIGNED",
                            },
                        ],
                    }
                ],
            },
        },
        "177d1bb7-5394-4772-ba9f-4569f0c2a995": {
            "data_hash": "177d1bb7-5394-4772-ba9f-4569f0c2a995",
            "data_title": "Screenshot 2021-11-24 at 18.36.02.png",
            "data_link": "https://storage.googleapis.com/cord-ai-platform.appspot.com/cord-images-prod/yiA5JxmLEGSoEcJAuxr3AJdDDXE2/177d1bb7-5394-4772-ba9f-4569f0c2a995?X-Goog-Algorithm=GOOG4-RSA-SHA256&X-Goog-Credential=firebase-adminsdk-64w1p%40cord-ai-platform.iam.gserviceaccount.com%2F20230210%2Fauto%2Fstorage%2Fgoog4_request&X-Goog-Date=20230210T112705Z&X-Goog-Expires=604800&X-Goog-SignedHeaders=host&X-Goog-Signature=3ba2077a0dd94322189cdacbbd2933f625a86cf676f53084c551ad36dd48470b766cb5a009dc04c578eb91b4d94f857cc359744c638a509b5076dc46bd9f76531fcff1c2dae4a4202889ef76de36093b7087b15112d02fce1b366ea5f824feb9ec426a285a7fd9d0134bc51e2f1733eceb72cf84b6327611eddd048f562ae41a39c8eb43c6d1f1d166272a2e73f78ee2893df23494b14298420a0117e985ac45161ade4dc43c47c9747079f9abe44d3d0768813271e69862de1e285be6875ef101364533ff2cdaf7b3a7b1a6df79110a212e06fe9d9350d4fd84ded325d3e7d77d05d163fd9c9c09235fe382417e5513c574315f7411b59fe80e074c296878d8",
            "data_type": "image/png",
            "data_sequence": "1",
            "width": 952,
            "height": 678,
            "labels": {
                "objects": [
                    {
                        "name": "Box",
                        "color": "#D33115",
                        "shape": "bounding_box",
                        "value": "box",
                        "createdAt": "Fri, 10 Feb 2023 11:08:07 UTC",
                        "createdBy": "denis@cord.tech",
                        "lastEditedAt": "Fri, 10 Feb 2023 13:58:24 UTC",
                        "isDeleted": False,
                        "confidence": 1,
                        "objectHash": "SRIJiIjv",
                        "featureHash": "MjI2NzEy",
                        "manualAnnotation": True,
                        "boundingBox": {"h": 0.0701, "w": 0.0709, "x": 0.3082, "y": 0.3639},
                        "reviews": [
                            {
                                "id": 2134704,
                                "exists": True,
                                "status": "ASSIGNED",
                                "comment": "reject round 1\n",
                                "task_id": 2970724,
                                "user_id": 524,
                                "approved": False,
                                "instance": {
                                    "name": "Box",
                                    "range": [[0, 2]],
                                    "shape": "bounding_box",
                                    "objectID": 0,
                                    "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                    "objectHash": "SRIJiIjv",
                                    "featureHash": "MjI2NzEy",
                                    "classifications": [],
                                    "manual_annotation": True,
                                },
                                "metadata": None,
                                "createdAt": "Fri, 10 Feb 2023 11:08:41 UTC",
                                "createdBy": "denis@cord.tech",
                                "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                "created_at": "2023-02-10 11:08:26",
                                "rejections": None,
                                "user_email": "denis@cord.tech",
                                "granularity": "OBJECT",
                                "granularity_id": "SRIJiIjv",
                                "last_edited_at": "2023-02-10 11:08:29",
                                "displayed_status": "ASSIGNED",
                            },
                            {
                                "id": 2134704,
                                "exists": True,
                                "status": "ASSIGNED",
                                "comment": "reject round two\n",
                                "task_id": 2970724,
                                "user_id": 524,
                                "approved": False,
                                "instance": {
                                    "name": "Box",
                                    "range": [[0, 2]],
                                    "shape": "bounding_box",
                                    "objectID": 0,
                                    "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                    "objectHash": "SRIJiIjv",
                                    "featureHash": "MjI2NzEy",
                                    "classifications": [],
                                    "manual_annotation": True,
                                },
                                "metadata": {
                                    "reviews": [
                                        {
                                            "id": 2134704,
                                            "exists": True,
                                            "status": "ASSIGNED",
                                            "comment": "reject round 1\n",
                                            "task_id": 2970724,
                                            "user_id": 524,
                                            "approved": False,
                                            "instance": {
                                                "name": "Box",
                                                "range": [[0, 2]],
                                                "shape": "bounding_box",
                                                "objectID": 0,
                                                "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                                "objectHash": "SRIJiIjv",
                                                "featureHash": "MjI2NzEy",
                                                "classifications": [],
                                                "manual_annotation": True,
                                            },
                                            "metadata": None,
                                            "createdAt": "Fri, 10 Feb 2023 11:08:41 UTC",
                                            "createdBy": "yiA5JxmLEGSoEcJAuxr3AJdDDXE2",
                                            "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                            "created_at": "2023-02-10 11:08:26",
                                            "rejections": None,
                                            "user_email": "denis@cord.tech",
                                            "granularity": "OBJECT",
                                            "granularity_id": "SRIJiIjv",
                                            "last_edited_at": "2023-02-10 11:08:29",
                                            "displayed_status": "ASSIGNED",
                                        }
                                    ]
                                },
                                "createdAt": "Fri, 10 Feb 2023 11:10:01 UTC",
                                "createdBy": "denis@cord.tech",
                                "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                "created_at": "2023-02-10 11:08:26",
                                "rejections": None,
                                "user_email": "denis@cord.tech",
                                "granularity": "OBJECT",
                                "granularity_id": "SRIJiIjv",
                                "last_edited_at": "2023-02-10 11:09:49",
                                "displayed_status": "ASSIGNED",
                            },
                            {
                                "id": 2134704,
                                "exists": True,
                                "status": "ASSIGNED",
                                "comment": None,
                                "task_id": 2970724,
                                "user_id": 524,
                                "approved": True,
                                "instance": {
                                    "name": "Box",
                                    "range": [[0, 2]],
                                    "shape": "bounding_box",
                                    "objectID": 0,
                                    "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                    "objectHash": "SRIJiIjv",
                                    "featureHash": "MjI2NzEy",
                                    "classifications": [],
                                    "manual_annotation": True,
                                },
                                "metadata": {
                                    "reviews": [
                                        {
                                            "id": 2134704,
                                            "exists": True,
                                            "status": "ASSIGNED",
                                            "comment": "reject round 1\n",
                                            "task_id": 2970724,
                                            "user_id": 524,
                                            "approved": False,
                                            "instance": {
                                                "name": "Box",
                                                "range": [[0, 2]],
                                                "shape": "bounding_box",
                                                "objectID": 0,
                                                "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                                "objectHash": "SRIJiIjv",
                                                "featureHash": "MjI2NzEy",
                                                "classifications": [],
                                                "manual_annotation": True,
                                            },
                                            "metadata": None,
                                            "createdAt": "Fri, 10 Feb 2023 11:08:41 UTC",
                                            "createdBy": "yiA5JxmLEGSoEcJAuxr3AJdDDXE2",
                                            "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                            "created_at": "2023-02-10 11:08:26",
                                            "rejections": None,
                                            "user_email": "denis@cord.tech",
                                            "granularity": "OBJECT",
                                            "granularity_id": "SRIJiIjv",
                                            "last_edited_at": "2023-02-10 11:08:29",
                                            "displayed_status": "ASSIGNED",
                                        },
                                        {
                                            "id": 2134704,
                                            "exists": True,
                                            "status": "ASSIGNED",
                                            "comment": "reject round two\n",
                                            "task_id": 2970724,
                                            "user_id": 524,
                                            "approved": False,
                                            "instance": {
                                                "name": "Box",
                                                "range": [[0, 2]],
                                                "shape": "bounding_box",
                                                "objectID": 0,
                                                "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                                "objectHash": "SRIJiIjv",
                                                "featureHash": "MjI2NzEy",
                                                "classifications": [],
                                                "manual_annotation": True,
                                            },
                                            "metadata": {
                                                "reviews": [
                                                    {
                                                        "id": 2134704,
                                                        "exists": True,
                                                        "status": "ASSIGNED",
                                                        "comment": "reject round 1\n",
                                                        "task_id": 2970724,
                                                        "user_id": 524,
                                                        "approved": False,
                                                        "instance": {
                                                            "name": "Box",
                                                            "range": [[0, 2]],
                                                            "shape": "bounding_box",
                                                            "objectID": 0,
                                                            "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                                            "objectHash": "SRIJiIjv",
                                                            "featureHash": "MjI2NzEy",
                                                            "classifications": [],
                                                            "manual_annotation": True,
                                                        },
                                                        "metadata": None,
                                                        "createdAt": "Fri, 10 Feb 2023 11:08:41 UTC",
                                                        "createdBy": "yiA5JxmLEGSoEcJAuxr3AJdDDXE2",
                                                        "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                                        "created_at": "2023-02-10 11:08:26",
                                                        "rejections": None,
                                                        "user_email": "denis@cord.tech",
                                                        "granularity": "OBJECT",
                                                        "granularity_id": "SRIJiIjv",
                                                        "last_edited_at": "2023-02-10 11:08:29",
                                                        "displayed_status": "ASSIGNED",
                                                    }
                                                ]
                                            },
                                            "createdAt": "Fri, 10 Feb 2023 11:10:01 UTC",
                                            "createdBy": "yiA5JxmLEGSoEcJAuxr3AJdDDXE2",
                                            "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                            "created_at": "2023-02-10 11:08:26",
                                            "rejections": None,
                                            "user_email": "denis@cord.tech",
                                            "granularity": "OBJECT",
                                            "granularity_id": "SRIJiIjv",
                                            "last_edited_at": "2023-02-10 11:09:49",
                                            "displayed_status": "ASSIGNED",
                                        },
                                    ]
                                },
                                "createdAt": "Fri, 10 Feb 2023 11:10:48 UTC",
                                "createdBy": "denis@cord.tech",
                                "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                "created_at": "2023-02-10 11:08:26",
                                "rejections": None,
                                "user_email": "denis@cord.tech",
                                "granularity": "OBJECT",
                                "granularity_id": "SRIJiIjv",
                                "last_edited_at": "2023-02-10 11:10:45",
                                "displayed_status": "ASSIGNED",
                            },
                        ],
                    }
                ],
                "classifications": [],
            },
        },
        "5f393aff-38e3-4364-8ece-340d5aade1c4": {
            "data_hash": "5f393aff-38e3-4364-8ece-340d5aade1c4",
            "data_title": "Screenshot 2021-11-24 at 18.36.07.png",
            "data_link": "https://storage.googleapis.com/cord-ai-platform.appspot.com/cord-images-prod/yiA5JxmLEGSoEcJAuxr3AJdDDXE2/5f393aff-38e3-4364-8ece-340d5aade1c4?X-Goog-Algorithm=GOOG4-RSA-SHA256&X-Goog-Credential=firebase-adminsdk-64w1p%40cord-ai-platform.iam.gserviceaccount.com%2F20230210%2Fauto%2Fstorage%2Fgoog4_request&X-Goog-Date=20230210T112705Z&X-Goog-Expires=604800&X-Goog-SignedHeaders=host&X-Goog-Signature=5ae06a77d625317c20271c9931f5317fd3ca6d59f4ed17acb0bb2c8983307a9e3da4aea4575fbdb8e1c3c767a598a93d3b41d5b8bb6ec3b70abf8bdc4b0ac01486589028e5674aa62934f2d7fc7feb4c0ec114eb33cbf8a7a810851992422787b1276ad4fe9583946c392d8bb4659246027fdf0e45a5c8235872c31a5069697597e04cf6cce89b1731a38af525e072895eb5d75655aad32fd6f4e3d9158f46c91b6f66dc629cc6f6c5d9a9b3ba644728964c8ed8b1a0ee9e61d45c15db84d391d893cacceda29ee3f228ce46cacce6ba357188f5ab706e60de3c89ebc23f3c360b442e3b3c7e9a05d17bd6d2c6bedcc7d43e4a8a3709d3bdd2283de459f826fd",
            "data_type": "image/png",
            "data_sequence": "2",
            "width": 952,
            "height": 678,
            "labels": {
                "objects": [
                    {
                        "name": "Box",
                        "color": "#D33115",
                        "shape": "bounding_box",
                        "value": "box",
                        "createdAt": "Fri, 10 Feb 2023 11:08:08 UTC",
                        "createdBy": "denis@cord.tech",
                        "lastEditedAt": "Fri, 10 Feb 2023 13:58:24 UTC",
                        "isDeleted": False,
                        "confidence": 1,
                        "objectHash": "SRIJiIjv",
                        "featureHash": "MjI2NzEy",
                        "manualAnnotation": True,
                        "boundingBox": {"h": 0.0701, "w": 0.0709, "x": 0.3082, "y": 0.3639},
                        "reviews": [
                            {
                                "id": 2134704,
                                "exists": True,
                                "status": "ASSIGNED",
                                "comment": "reject round 1\n",
                                "task_id": 2970724,
                                "user_id": 524,
                                "approved": False,
                                "instance": {
                                    "name": "Box",
                                    "range": [[0, 2]],
                                    "shape": "bounding_box",
                                    "objectID": 0,
                                    "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                    "objectHash": "SRIJiIjv",
                                    "featureHash": "MjI2NzEy",
                                    "classifications": [],
                                    "manual_annotation": True,
                                },
                                "metadata": None,
                                "createdAt": "Fri, 10 Feb 2023 11:08:41 UTC",
                                "createdBy": "denis@cord.tech",
                                "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                "created_at": "2023-02-10 11:08:26",
                                "rejections": None,
                                "user_email": "denis@cord.tech",
                                "granularity": "OBJECT",
                                "granularity_id": "SRIJiIjv",
                                "last_edited_at": "2023-02-10 11:08:29",
                                "displayed_status": "ASSIGNED",
                            },
                            {
                                "id": 2134704,
                                "exists": True,
                                "status": "ASSIGNED",
                                "comment": "reject round two\n",
                                "task_id": 2970724,
                                "user_id": 524,
                                "approved": False,
                                "instance": {
                                    "name": "Box",
                                    "range": [[0, 2]],
                                    "shape": "bounding_box",
                                    "objectID": 0,
                                    "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                    "objectHash": "SRIJiIjv",
                                    "featureHash": "MjI2NzEy",
                                    "classifications": [],
                                    "manual_annotation": True,
                                },
                                "metadata": {
                                    "reviews": [
                                        {
                                            "id": 2134704,
                                            "exists": True,
                                            "status": "ASSIGNED",
                                            "comment": "reject round 1\n",
                                            "task_id": 2970724,
                                            "user_id": 524,
                                            "approved": False,
                                            "instance": {
                                                "name": "Box",
                                                "range": [[0, 2]],
                                                "shape": "bounding_box",
                                                "objectID": 0,
                                                "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                                "objectHash": "SRIJiIjv",
                                                "featureHash": "MjI2NzEy",
                                                "classifications": [],
                                                "manual_annotation": True,
                                            },
                                            "metadata": None,
                                            "createdAt": "Fri, 10 Feb 2023 11:08:41 UTC",
                                            "createdBy": "yiA5JxmLEGSoEcJAuxr3AJdDDXE2",
                                            "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                            "created_at": "2023-02-10 11:08:26",
                                            "rejections": None,
                                            "user_email": "denis@cord.tech",
                                            "granularity": "OBJECT",
                                            "granularity_id": "SRIJiIjv",
                                            "last_edited_at": "2023-02-10 11:08:29",
                                            "displayed_status": "ASSIGNED",
                                        }
                                    ]
                                },
                                "createdAt": "Fri, 10 Feb 2023 11:10:01 UTC",
                                "createdBy": "denis@cord.tech",
                                "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                "created_at": "2023-02-10 11:08:26",
                                "rejections": None,
                                "user_email": "denis@cord.tech",
                                "granularity": "OBJECT",
                                "granularity_id": "SRIJiIjv",
                                "last_edited_at": "2023-02-10 11:09:49",
                                "displayed_status": "ASSIGNED",
                            },
                            {
                                "id": 2134704,
                                "exists": True,
                                "status": "ASSIGNED",
                                "comment": None,
                                "task_id": 2970724,
                                "user_id": 524,
                                "approved": True,
                                "instance": {
                                    "name": "Box",
                                    "range": [[0, 2]],
                                    "shape": "bounding_box",
                                    "objectID": 0,
                                    "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                    "objectHash": "SRIJiIjv",
                                    "featureHash": "MjI2NzEy",
                                    "classifications": [],
                                    "manual_annotation": True,
                                },
                                "metadata": {
                                    "reviews": [
                                        {
                                            "id": 2134704,
                                            "exists": True,
                                            "status": "ASSIGNED",
                                            "comment": "reject round 1\n",
                                            "task_id": 2970724,
                                            "user_id": 524,
                                            "approved": False,
                                            "instance": {
                                                "name": "Box",
                                                "range": [[0, 2]],
                                                "shape": "bounding_box",
                                                "objectID": 0,
                                                "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                                "objectHash": "SRIJiIjv",
                                                "featureHash": "MjI2NzEy",
                                                "classifications": [],
                                                "manual_annotation": True,
                                            },
                                            "metadata": None,
                                            "createdAt": "Fri, 10 Feb 2023 11:08:41 UTC",
                                            "createdBy": "yiA5JxmLEGSoEcJAuxr3AJdDDXE2",
                                            "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                            "created_at": "2023-02-10 11:08:26",
                                            "rejections": None,
                                            "user_email": "denis@cord.tech",
                                            "granularity": "OBJECT",
                                            "granularity_id": "SRIJiIjv",
                                            "last_edited_at": "2023-02-10 11:08:29",
                                            "displayed_status": "ASSIGNED",
                                        },
                                        {
                                            "id": 2134704,
                                            "exists": True,
                                            "status": "ASSIGNED",
                                            "comment": "reject round two\n",
                                            "task_id": 2970724,
                                            "user_id": 524,
                                            "approved": False,
                                            "instance": {
                                                "name": "Box",
                                                "range": [[0, 2]],
                                                "shape": "bounding_box",
                                                "objectID": 0,
                                                "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                                "objectHash": "SRIJiIjv",
                                                "featureHash": "MjI2NzEy",
                                                "classifications": [],
                                                "manual_annotation": True,
                                            },
                                            "metadata": {
                                                "reviews": [
                                                    {
                                                        "id": 2134704,
                                                        "exists": True,
                                                        "status": "ASSIGNED",
                                                        "comment": "reject round 1\n",
                                                        "task_id": 2970724,
                                                        "user_id": 524,
                                                        "approved": False,
                                                        "instance": {
                                                            "name": "Box",
                                                            "range": [[0, 2]],
                                                            "shape": "bounding_box",
                                                            "objectID": 0,
                                                            "indexHash": "efe467d1-37b7-4f68-beab-8b14bb9c8b62",
                                                            "objectHash": "SRIJiIjv",
                                                            "featureHash": "MjI2NzEy",
                                                            "classifications": [],
                                                            "manual_annotation": True,
                                                        },
                                                        "metadata": None,
                                                        "createdAt": "Fri, 10 Feb 2023 11:08:41 UTC",
                                                        "createdBy": "yiA5JxmLEGSoEcJAuxr3AJdDDXE2",
                                                        "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                                        "created_at": "2023-02-10 11:08:26",
                                                        "rejections": None,
                                                        "user_email": "denis@cord.tech",
                                                        "granularity": "OBJECT",
                                                        "granularity_id": "SRIJiIjv",
                                                        "last_edited_at": "2023-02-10 11:08:29",
                                                        "displayed_status": "ASSIGNED",
                                                    }
                                                ]
                                            },
                                            "createdAt": "Fri, 10 Feb 2023 11:10:01 UTC",
                                            "createdBy": "yiA5JxmLEGSoEcJAuxr3AJdDDXE2",
                                            "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                            "created_at": "2023-02-10 11:08:26",
                                            "rejections": None,
                                            "user_email": "denis@cord.tech",
                                            "granularity": "OBJECT",
                                            "granularity_id": "SRIJiIjv",
                                            "last_edited_at": "2023-02-10 11:09:49",
                                            "displayed_status": "ASSIGNED",
                                        },
                                    ]
                                },
                                "createdAt": "Fri, 10 Feb 2023 11:10:48 UTC",
                                "createdBy": "denis@cord.tech",
                                "data_hash": "47f194ca-11cc-4060-a8b7-5c90345cf8e2",
                                "created_at": "2023-02-10 11:08:26",
                                "rejections": None,
                                "user_email": "denis@cord.tech",
                                "granularity": "OBJECT",
                                "granularity_id": "SRIJiIjv",
                                "last_edited_at": "2023-02-10 11:10:45",
                                "displayed_status": "ASSIGNED",
                            },
                        ],
                    }
                ],
                "classifications": [],
            },
        },
        "6518e742-8dee-4a6d-b491-710f8a5c0fc4": {
            "data_hash": "6518e742-8dee-4a6d-b491-710f8a5c0fc4",
            "data_title": "Screenshot 2021-11-24 at 18.36.11.png",
            "data_link": "https://storage.googleapis.com/cord-ai-platform.appspot.com/cord-images-prod/yiA5JxmLEGSoEcJAuxr3AJdDDXE2/6518e742-8dee-4a6d-b491-710f8a5c0fc4?X-Goog-Algorithm=GOOG4-RSA-SHA256&X-Goog-Credential=firebase-adminsdk-64w1p%40cord-ai-platform.iam.gserviceaccount.com%2F20230210%2Fauto%2Fstorage%2Fgoog4_request&X-Goog-Date=20230210T112705Z&X-Goog-Expires=604800&X-Goog-SignedHeaders=host&X-Goog-Signature=797a1756d07215641f7baeaff646ad3e33c8c7295f3cec19964b84d6753a316608f7d94e488c77b0c20c2943b9692574f6b578e23ddd6ec971740fe721dc3953c892c55ebf60b01d9f7d427a2bc91e0971abf38b1e87c88b71ad77947b81e9f09838bd6ac1156ee8fd229a8034dee7869539f52851d9d48046ae147a1d68812b6bbcf718f2b1ae34fcfb1c049b948c818be2ec41845bfc18708c1bc8b1a7e9eb9841cf4547039d8b3e17980aae0edd17127abf48dbab16635ef1e6f5d85fde90b5280e3c58daf721d0fa1d370dfe0fa9db4fd3133fb9b909ba9f6df94470a95d6d3017418b68be238aed4168e8d0d41c4b16c3ea99bb4775180c1e90fd6f2086",
            "data_type": "image/png",
            "data_sequence": "3",
            "width": 952,
            "height": 678,
            "labels": {"objects": [], "classifications": []},
        },
        "24dd04ee-ff3f-4f91-b6b5-b385defc7307": {
            "data_hash": "24dd04ee-ff3f-4f91-b6b5-b385defc7307",
            "data_title": "Screenshot 2021-11-24 at 18.36.19.png",
            "data_link": "https://storage.googleapis.com/cord-ai-platform.appspot.com/cord-images-prod/yiA5JxmLEGSoEcJAuxr3AJdDDXE2/24dd04ee-ff3f-4f91-b6b5-b385defc7307?X-Goog-Algorithm=GOOG4-RSA-SHA256&X-Goog-Credential=firebase-adminsdk-64w1p%40cord-ai-platform.iam.gserviceaccount.com%2F20230210%2Fauto%2Fstorage%2Fgoog4_request&X-Goog-Date=20230210T112705Z&X-Goog-Expires=604800&X-Goog-SignedHeaders=host&X-Goog-Signature=2d223caa54259ea6ae49b140d98dcb00f0e6dc3842f4a8e0abfcbeaafda0dfae3c8796f61800c80a6d623e67b53e457a2e11d79e61d5a5a56998a6dc14fe5176d2794d6e0723d6b4fe9c8c335ab17f4f9c87a1425b17fc725760a1f6748da189f25d9db2c1b061f262be722c80ccd6d9e97dd7ef65c3a3c4a1a8bd9d943d391f336a9156b8938aa47783a5a6229d5d4f0a7ccf96759d3193b63d76b9c515a8beb453652e0a7d64b8c371040ef237a85e4eb12386bb3f62d2823f49a8a6f905931b0f864acc104bf6222f79f91081ad23880d834d3c3441471030d091517752a62055a17465349a9f9e1e1972b91b51865937909898d0fc913b31888cb645631e",
            "data_type": "image/png",
            "data_sequence": "4",
            "width": 952,
            "height": 678,
            "labels": {"objects": [], "classifications": []},
        },
    },
    "object_answers": {
        "SRIJiIjv": {"objectHash": "SRIJiIjv", "classifications": []},
        "983w0TxX": {"objectHash": "983w0TxX", "classifications": []},
    },
    "classification_answers": {
        "hLs1sDAr": {
            "classificationHash": "hLs1sDAr",
            "featureHash": "NzIxNTU1",
            "classifications": [
                {
                    "name": "cl 1 2 text",
                    "value": "cl_1_2_text",
                    "answers": "new text",
                    "featureHash": "MTg0MjIw",
                    "manualAnnotation": True,
                },
                {
                    "name": "Radio classification 1",
                    "value": "radio_classification_1",
                    "answers": [{"name": "cl 1 option 2", "value": "cl_1_option_2", "featureHash": "MjUzMTg1"}],
                    "featureHash": "MjI5MTA5",
                    "manualAnnotation": True,
                },
            ],
        }
    },
    "object_actions": {},
    "label_status": "LABELLED",
    "annotation_task_status": "COMPLETED",
}
