labels = {
    "label_hash": "66454013-7382-4418-a9ca-41c089d8997f",
    "branch_name": "main",
    "created_at": "Thu, 09 Feb 2023 14:12:03 UTC",
    "last_edited_at": "Thu, 09 Feb 2023 14:12:03 UTC",
    "data_hash": "aaa6bc82-9f89-4545-adbb-f271bf28cf99",
    "annotation_task_status": "QUEUED",
    "is_shadow_data": False,
    "dataset_hash": "77f9c59a-89d3-4635-a20e-5da9a01d5138",
    "dataset_title": "Dataset with one single image annotated",
    "data_title": "rousseau_2.jpg",
    "data_type": "image",
    "data_units": {
        "649aba74-365b-45fa-a375-3036ee0eda78": {
            "data_hash": "649aba74-365b-45fa-a375-3036ee0eda78",
            "data_title": "rousseau_2.jpg",
            "data_type": "image/jpeg",
            "data_sequence": 0,
            "labels": {
                "objects": [
                    {
                        "name": "Nested Box",
                        "color": "#FCDC00",
                        "shape": "bounding_box",
                        "value": "nested_box",
                        "createdAt": "Tue, 17 Jan 2023 11:43:52 UTC",
                        "createdBy": "denis@cord.tech",
                        "lastEditedAt": "Tue, 17 Jan 2023 11:43:52 UTC",
                        "lastEditedBy": "denis@cord.tech",
                        "confidence": 1,
                        "objectHash": "saG3qh6C",
                        "featureHash": "MTA2MjAx",
                        "manualAnnotation": True,
                        "boundingBox": {"h": 0.1561, "w": 0.0856, "x": 0.6212, "y": 0.4114},
                    },
                    {
                        "name": "Nested Box",
                        "color": "#FCDC00",
                        "shape": "bounding_box",
                        "value": "nested_box",
                        "createdAt": "Tue, 17 Jan 2023 11:44:02 UTC",
                        "createdBy": "denis@cord.tech",
                        "lastEditedAt": "Tue, 17 Jan 2023 11:44:02 UTC",
                        "lastEditedBy": "denis@cord.tech",
                        "confidence": 1,
                        "objectHash": "2c1Uso5b",
                        "featureHash": "MTA2MjAx",
                        "manualAnnotation": True,
                        "boundingBox": {"h": 0.1336, "w": 0.1008, "x": 0.7343, "y": 0.5648},
                    },
                    {
                        "name": "Deeply Nested Polygon",
                        "color": "#DBDF00",
                        "shape": "polygon",
                        "value": "deeply_nested_polygon",
                        "polygon": {
                            "0": {"x": 0.7017, "y": 0.7857},
                            "1": {"x": 0.6895, "y": 0.7989},
                            "2": {"x": 0.6793, "y": 0.8122},
                            "3": {"x": 0.6711, "y": 0.8267},
                            "4": {"x": 0.6711, "y": 0.8439},
                            "5": {"x": 0.6742, "y": 0.8585},
                            "6": {"x": 0.6803, "y": 0.8783},
                            "7": {"x": 0.6864, "y": 0.8915},
                            "8": {"x": 0.6935, "y": 0.9021},
                            "9": {"x": 0.7017, "y": 0.9101},
                            "10": {"x": 0.7139, "y": 0.914},
                            "11": {"x": 0.7271, "y": 0.9127},
                            "12": {"x": 0.7445, "y": 0.9061},
                            "13": {"x": 0.7536, "y": 0.8981},
                            "14": {"x": 0.7689, "y": 0.8849},
                            "15": {"x": 0.7781, "y": 0.8757},
                            "16": {"x": 0.7883, "y": 0.8571},
                            "17": {"x": 0.7984, "y": 0.8333},
                            "18": {"x": 0.7995, "y": 0.8201},
                        },
                        "polygons": [
                            [
                                [
                                    0.7017,
                                    0.7857,
                                    0.6895,
                                    0.7989,
                                    0.6793,
                                    0.8122,
                                    0.6711,
                                    0.8267,
                                    0.6711,
                                    0.8439,
                                    0.6742,
                                    0.8585,
                                    0.6803,
                                    0.8783,
                                    0.6864,
                                    0.8915,
                                    0.6935,
                                    0.9021,
                                    0.7017,
                                    0.9101,
                                    0.7139,
                                    0.914,
                                    0.7271,
                                    0.9127,
                                    0.7445,
                                    0.9061,
                                    0.7536,
                                    0.8981,
                                    0.7689,
                                    0.8849,
                                    0.7781,
                                    0.8757,
                                    0.7883,
                                    0.8571,
                                    0.7984,
                                    0.8333,
                                    0.7995,
                                    0.8201,
                                ]
                            ]
                        ],
                        "createdAt": "Tue, 17 Jan 2023 11:44:38 UTC",
                        "createdBy": "denis@cord.tech",
                        "lastEditedAt": "Tue, 17 Jan 2023 11:44:38 UTC",
                        "lastEditedBy": "denis@cord.tech",
                        "confidence": 1,
                        "objectHash": "f7RpEkg5",
                        "featureHash": "MTM1MTQy",
                        "manualAnnotation": True,
                    },
                ],
                "classifications": [
                    {
                        "name": "Radio classification 1",
                        "value": "radio_classification_1",
                        "createdAt": "Tue, 17 Jan 2023 11:44:53 UTC",
                        "createdBy": "denis@cord.tech",
                        "confidence": 1,
                        "featureHash": "NzIxNTU1",
                        "lastEditedAt": "Tue, 17 Jan 2023 11:44:53 UTC",
                        "lastEditedBy": "denis@cord.tech",
                        "classificationHash": "3AqiIPrF",
                        "manualAnnotation": True,
                    },
                    {
                        "name": "Text classification",
                        "value": "text_classification",
                        "createdAt": "Tue, 17 Jan 2023 11:45:01 UTC",
                        "createdBy": "denis@cord.tech",
                        "confidence": 1,
                        "featureHash": "jPOcEsbw",
                        "lastEditedAt": "Tue, 17 Jan 2023 11:45:01 UTC",
                        "lastEditedBy": "denis@cord.tech",
                        "classificationHash": "HVwOV4hB",
                        "manualAnnotation": True,
                    },
                    {
                        "name": "Checklist classification",
                        "value": "checklist_classification",
                        "createdAt": "Tue, 17 Jan 2023 11:45:07 UTC",
                        "createdBy": "denis@cord.tech",
                        "confidence": 1,
                        "featureHash": "3DuQbFxo",
                        "lastEditedAt": "Tue, 17 Jan 2023 11:45:07 UTC",
                        "lastEditedBy": "denis@cord.tech",
                        "classificationHash": "37vDK5u0",
                        "manualAnnotation": True,
                    },
                ],
            },
            "data_link": "cord-images-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/649aba74-365b-45fa-a375-3036ee0eda78",
            "width": 1200,
            "height": 924,
        }
    },
    "object_answers": {
        "saG3qh6C": {
            "objectHash": "saG3qh6C",
            "classifications": [
                {
                    "name": "Mood",
                    "value": "mood",
                    "answers": [{"name": "Sad", "value": "sad", "featureHash": "Nzg3MDE3"}],
                    "featureHash": "ODcxMDAy",
                    "manualAnnotation": True,
                },
                {
                    "name": "First name",
                    "value": "first_name",
                    "answers": "Lion",
                    "featureHash": "OTkxMjU1",
                    "manualAnnotation": True,
                },
            ],
        },
        "2c1Uso5b": {
            "objectHash": "2c1Uso5b",
            "classifications": [
                {
                    "name": "Mood",
                    "value": "mood",
                    "answers": [
                        {"name": "Angry", "value": "angry", "featureHash": "MTE5MjQ3"},
                        {"name": "Sad", "value": "sad", "featureHash": "Nzg3MDE3"},
                    ],
                    "featureHash": "ODcxMDAy",
                    "manualAnnotation": True,
                },
                {
                    "name": "First name",
                    "value": "first_name",
                    "answers": "Aphrodite",
                    "featureHash": "OTkxMjU1",
                    "manualAnnotation": True,
                },
            ],
        },
        "f7RpEkg5": {
            "objectHash": "f7RpEkg5",
            "classifications": [
                {
                    "name": "1 2 radio 1",
                    "value": "1_2_radio_1",
                    "answers": [{"name": "1 2 1 option ", "value": "1_2_1_option_", "featureHash": "MTI4MjQy"}],
                    "featureHash": "NDYyMjQx",
                    "manualAnnotation": True,
                },
                {
                    "name": "Radio level 1 ",
                    "value": "radio_level_1_",
                    "answers": [{"name": "1 option 2", "value": "1_option_2", "featureHash": "MTcxMjAy"}],
                    "featureHash": "MTExMjI3",
                    "manualAnnotation": True,
                },
            ],
        },
    },
    "classification_answers": {
        "3AqiIPrF": {
            "classificationHash": "3AqiIPrF",
            "featureHash": "NzIxNTU1",
            "classifications": [
                {
                    "name": "cl 1 2 text",
                    "value": "cl_1_2_text",
                    "answers": "The moon is pretty",
                    "featureHash": "MTg0MjIw",
                    "manualAnnotation": True,
                },
                {
                    "name": "Radio classification 1",
                    "value": "radio_classification_1",
                    "answers": [{"name": "cl 1 option 2", "value": "cl_1_option_2", "featureHash": "MjUzMTg1"}],
                    "featureHash": "MjI5MTA5",
                    "manualAnnotation": True,
                },
            ],
        },
        "HVwOV4hB": {
            "classificationHash": "HVwOV4hB",
            "featureHash": "jPOcEsbw",
            "classifications": [
                {
                    "name": "Text classification",
                    "value": "text_classification",
                    "answers": "Rousseau",
                    "featureHash": "OxrtEM+v",
                    "manualAnnotation": True,
                }
            ],
        },
        "37vDK5u0": {
            "classificationHash": "37vDK5u0",
            "featureHash": "3DuQbFxo",
            "classifications": [
                {
                    "name": "Checklist classification",
                    "value": "checklist_classification",
                    "answers": [],
                    "featureHash": "9mwWr3OE",
                    "manualAnnotation": True,
                }
            ],
        },
    },
    "object_actions": {},
    "label_status": "LABEL_IN_PROGRESS",
}
