ONTOLOGY_BLURB = {
    "ontology_hash": "bab95d1e-3070-48fb-9d40-ad168b55310e",
    "title": "Test ontology",
    "description": "",
    "created_at": "Thu, 18 Feb 2021 22:24:59 GMT",
    "last_edited_at": "Thu, 18 Feb 2021 22:24:59 GMT",
    "editor": {
        "objects": [
            {
                "id": "1",
                "name": "Apple",
                "color": "#D33115",
                "shape": "bounding_box",
                "featureNodeHash": "qWm5E3j4",
                "attributes": [
                    {
                        "id": "1.1",
                        "name": "Big",
                        "type": "text",
                        "required": False,
                        "dynamic": False,
                        "featureNodeHash": "LNRORV/z",
                    },
                    {
                        "id": "1.2",
                        "name": "Small",
                        "type": "text",
                        "required": False,
                        "dynamic": False,
                        "featureNodeHash": "hQPM/8Ax",
                    },
                ],
            },
            {"id": "2", "name": "Pear", "color": "#E27300", "shape": "bounding_box", "featureNodeHash": "no8RyWRY"},
        ],
        "classifications": [
            {
                "id": "1",
                "featureNodeHash": "4BjoumKd",
                "attributes": [
                    {
                        "id": "1.1",
                        "name": "hot dog",
                        "type": "radio",
                        "required": False,
                        "featureNodeHash": "t/prlg4Z",
                        "options": [
                            {"id": "1.1.1", "label": "hot dog", "value": "hot_dog", "featureNodeHash": "8fjrfCJy"},
                            {
                                "id": "1.1.2",
                                "label": "not hot dog",
                                "value": "not_hot_dog",
                                "featureNodeHash": "MpKwvogL",
                            },
                        ],
                    }
                ],
            }
        ],
    },
}
