labels = {
    "label_hash": "66454013-7382-4418-a9ca-41c089d8997f",
    "branch_name": "main",
    "created_at": "2023-02-09 14:12:03",
    "last_edited_at": "2023-02-09 14:12:03",
    "data_hash": "aaa6bc82-9f89-4545-adbb-f271bf28cf99",
    "annotation_task_status": "QUEUED",
    "is_shadow_data": False,
    "dataset_hash": "77f9c59a-89d3-4635-a20e-5da9a01d5138",
    "dataset_title": "Dataset with one single image annotated",
    "data_title": "rousseau_2.jpg",
    "data_type": "image",
    "data_units": {
        "649aba74-365b-45fa-a375-3036ee0eda78": {
            "data_hash": "649aba74-365b-45fa-a375-3036ee0eda78",
            "data_title": "rousseau_2.jpg",
            "data_type": "image/jpeg",
            "data_sequence": 0,
            "labels": {
                "objects": [],
                "classifications": [
                    {
                        "name": "Radio classification 1",
                        "value": "radio_classification_1",
                        "createdAt": "Tue, 17 Jan 2023 11:44:53 GMT",
                        "createdBy": "denis@cord.tech",
                        "confidence": 1,
                        "featureHash": "NzIxNTU1",
                        "lastEditedAt": "Tue, 17 Jan 2023 11:44:53 GMT",
                        "classificationHash": "3AqiIPrF",
                        "manualAnnotation": True,
                    },
                    {
                        "name": "Text classification",
                        "value": "text_classification",
                        "createdAt": "Tue, 17 Jan 2023 11:45:01 GMT",
                        "createdBy": "denis@cord.tech",
                        "confidence": 1,
                        "featureHash": "jPOcEsbw",
                        "lastEditedAt": "Tue, 17 Jan 2023 11:45:01 GMT",
                        "classificationHash": "HVwOV4hB",
                        "manualAnnotation": True,
                    },
                    {
                        "name": "Checklist classification",
                        "value": "checklist_classification",
                        "createdAt": "Tue, 17 Jan 2023 11:45:07 GMT",
                        "createdBy": "denis@cord.tech",
                        "confidence": 1,
                        "featureHash": "3DuQbFxo",
                        "lastEditedAt": "Tue, 17 Jan 2023 11:45:07 GMT",
                        "classificationHash": "37vDK5u0",
                        "manualAnnotation": True,
                    },
                ],
            },
            "data_link": "cord-images-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/649aba74-365b-45fa-a375-3036ee0eda78",
            "width": 1200,
            "height": 924,
        }
    },
    "object_answers": {},
    "classification_answers": {},
    "object_actions": {},
    "label_status": "LABEL_IN_PROGRESS",
}
