AUDIO_OBJECTS = {
    "label_hash": "0aea5ac7-cbc0-4451-a242-e22445d2c9fa",
    "branch_name": "main",
    "created_at": "Thu, 09 Feb 2023 14:12:03 UTC",
    "last_edited_at": "Thu, 09 Feb 2023 14:12:03 UTC",
    "data_hash": "aaa6bc82-9f89-4545-adbb-f271bf28cf99",
    "dataset_hash": "b02ba3d9-883b-4c5e-ba09-751072ccfc57",
    "dataset_title": "Audio Dataset",
    "data_title": "sample-audio.mp3",
    "data_type": "audio",
    "annotation_task_status": "QUEUED",
    "is_shadow_data": False,
    "object_answers": {
        "IJVE50rx": {
            "classifications": [],
            "objectHash": "IJVE50rx",
            "range": [[16884, 23716]],
            "createdBy": "NlZNOzo0M5fqmHAPHiNiYs0UQYo2",
            "createdAt": "Thu, 05 Dec 2024 15:24:19 UTC",
            "lastEditedBy": "NlZNOzo0M5fqmHAPHiNiYs0UQYo2",
            "lastEditedAt": "Thu, 05 Dec 2024 15:24:44 UTC",
            "manualAnnotation": True,
            "featureHash": "3X3+Ydcy",
            "name": "audio 4",
            "color": "#A4DD00",
            "shape": "audio",
            "value": "audio_4",
        },
        "JfASSVHt": {
            "classifications": [],
            "objectHash": "JfASSVHt",
            "range": [[38111, 45455]],
            "createdBy": "NlZNOzo0M5fqmHAPHiNiYs0UQYo2",
            "createdAt": "Thu, 05 Dec 2024 15:24:25 UTC",
            "lastEditedBy": "NlZNOzo0M5fqmHAPHiNiYs0UQYo2",
            "lastEditedAt": "Thu, 05 Dec 2024 15:24:29 UTC",
            "manualAnnotation": True,
            "featureHash": "bjvtzFgi",
            "name": "audio 3",
            "color": "#A4DD00",
            "shape": "audio",
            "value": "audio_3",
        },
        "VDeQk05m": {
            "classifications": [],
            "objectHash": "VDeQk05m",
            "range": [[2095, 6521]],
            "createdBy": "NlZNOzo0M5fqmHAPHiNiYs0UQYo2",
            "createdAt": "Thu, 05 Dec 2024 15:24:18 UTC",
            "lastEditedBy": "NlZNOzo0M5fqmHAPHiNiYs0UQYo2",
            "lastEditedAt": "Sat, 07 Dec 2024 15:24:19 UTC",
            "manualAnnotation": True,
            "featureHash": "bjvtzFgi",
            "name": "audio 3",
            "color": "#A4DD00",
            "shape": "audio",
            "value": "audio_3",
        },
        "jXAb6rvo": {
            "classifications": [],
            "objectHash": "jXAb6rvo",
            "range": [[27338, 34349]],
            "createdBy": "NlZNOzo0M5fqmHAPHiNiYs0UQYo2",
            "createdAt": "Thu, 05 Dec 2024 15:24:20 UTC",
            "lastEditedBy": "NlZNOzo0M5fqmHAPHiNiYs0UQYo2",
            "lastEditedAt": "Sat, 07 Dec 2024 15:24:19 UTC",
            "manualAnnotation": True,
            "featureHash": "9dt+r+op",
            "name": "audio 1",
            "color": "#A4DD00",
            "shape": "audio",
            "value": "audio_1",
        },
        "mJIIPFG2": {
            "classifications": [],
            "objectHash": "mJIIPFG2",
            "range": [[7450, 14194]],
            "createdBy": "NlZNOzo0M5fqmHAPHiNiYs0UQYo2",
            "createdAt": "Thu, 05 Dec 2024 15:24:19 UTC",
            "lastEditedBy": "NlZNOzo0M5fqmHAPHiNiYs0UQYo2",
            "lastEditedAt": "Sat, 07 Dec 2024 15:24:19 UTC",
            "manualAnnotation": True,
            "featureHash": "9dt+r+op",
            "name": "audio 1",
            "color": "#A4DD00",
            "shape": "audio",
            "value": "audio_1",
        },
    },
    "classification_answers": {},
    "object_actions": {},
    "label_status": "LABELLED",
    "data_units": {
        "cd53f484-c9ab-4fd1-9c14-5b34d4e42ba2": {
            "data_hash": "cd53f484-c9ab-4fd1-9c14-5b34d4e42ba2",
            "data_title": "sample-audio.mp3",
            "data_link": "audio-link",
            "data_type": "audio/mpeg",
            "data_sequence": 0,
            "audio_codec": "mp3",
            "audio_sample_rate": 44100,
            "audio_bit_depth": 8,
            "audio_num_channels": 2,
            "labels": {},
            "data_duration": 100,
        }
    },
}
