dicom_labels = {
    "label_hash": "0aea5ac7-cbc0-4451-a242-e22445d2c9fa",
    "branch_name": "main",
    "created_at": "Thu, 09 Feb 2023 14:12:03 UTC",
    "last_edited_at": "Thu, 09 Feb 2023 14:12:03 UTC",
    "data_hash": "aaa6bc82-9f89-4545-adbb-f271bf28cf99",
    "annotation_task_status": "QUEUED",
    "is_shadow_data": False,
    "dataset_hash": "b02ba3d9-883b-4c5e-ba09-751072ccfc57",
    "dataset_title": "DICOM dataset",
    "data_title": "cd53",
    "data_type": "dicom",
    "data_units": {
        "cd53f484-c9ab-4fd1-9c14-5b34d4e42ba2": {
            "data_hash": "cd53f484-c9ab-4fd1-9c14-5b34d4e42ba2",
            "data_title": "cd53",
            "data_type": "application/dicom",
            "data_sequence": 0,
            "labels": {
                "86": {
                    "objects": [
                        {
                            "name": "person_1dynamic_c1",
                            "color": "#FCDC00",
                            "shape": "bounding_box",
                            "value": "person_1dynamic_c1",
                            "createdAt": "Tue, 17 Jan 2023 14:17:47 UTC",
                            "createdBy": "denis@cord.tech",
                            "confidence": 1,
                            "lastEditedAt": "Tue, 17 Jan 2023 14:18:55 UTC",
                            "objectHash": "ai7DhsOA",
                            "featureHash": "2689db00",
                            "manualAnnotation": True,
                            "boundingBox": {"h": 0.095, "w": 0.1471, "x": 0.3445, "y": 0.4269},
                        }
                    ],
                    "classifications": [],
                },
                "87": {
                    "objects": [
                        {
                            "name": "person_1dynamic_c1",
                            "color": "#FCDC00",
                            "shape": "bounding_box",
                            "value": "person_1dynamic_c1",
                            "createdAt": "Tue, 17 Jan 2023 14:17:52 UTC",
                            "createdBy": "denis@cord.tech",
                            "isDeleted": False,
                            "confidence": 1,
                            "objectHash": "ai7DhsOA",
                            "featureHash": "2689db00",
                            "lastEditedAt": "Tue, 17 Jan 2023 14:17:55 UTC",
                            "lastEditedBy": "denis@cord.tech",
                            "manualAnnotation": True,
                            "boundingBox": {"h": 0.095, "w": 0.1471, "x": 0.3671, "y": 0.4463},
                        }
                    ],
                    "classifications": [],
                },
                "88": {
                    "objects": [
                        {
                            "name": "person_1dynamic_c1",
                            "color": "#FCDC00",
                            "shape": "bounding_box",
                            "value": "person_1dynamic_c1",
                            "createdAt": "Tue, 17 Jan 2023 14:19:09 UTC",
                            "createdBy": "denis@cord.tech",
                            "isDeleted": False,
                            "confidence": 1,
                            "objectHash": "ai7DhsOA",
                            "featureHash": "2689db00",
                            "lastEditedAt": "Tue, 17 Jan 2023 14:19:10 UTC",
                            "lastEditedBy": "denis@cord.tech",
                            "manualAnnotation": True,
                            "boundingBox": {"h": 0.095, "w": 0.1471, "x": 0.3722, "y": 0.4219},
                        }
                    ],
                    "classifications": [],
                },
            },
            "data_links": [
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/21c366c5-84ce-41e4-b66b-1d40d510100d",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/90f31dc4-3d9b-4d6d-9da4-068b7b4149f9",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/c886b77a-1ca4-40f5-9d66-593dbd115850",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/e38edda7-b6c4-45b6-824c-ce3165d4b826",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/287d43f6-81f6-4458-9590-76e7f394eb38",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/e4163909-6a18-4926-8a8a-ec57bd41329c",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/bb20ac48-fd1e-48c0-bb3d-8077872ecf84",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/16274082-18c3-4dba-98de-cfb99b70af7d",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/b02b6407-7823-41f4-a7e9-ddb2bf12b844",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/df55023f-b31f-467d-9732-9c3d885b7e7f",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/d821e391-a703-49bc-b441-57ad0a468015",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/a627cdce-7c25-47f1-b246-a6b43d8fca86",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/ee968bb9-ce52-4f4b-be63-c92b025c621b",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/d086b9f8-626b-4099-b343-232e1f9e6460",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/e4985309-94e2-4b84-826f-6e2bff6915d1",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/79518f90-4052-4cae-b7c2-3694fc44d731",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/c3c3d67d-556e-431d-b30a-08a4521cda01",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/3616bcbf-256d-48d7-a14c-df25fd4c94d9",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/5fc16749-c4f8-4cef-944e-948573e8e7d6",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/9b1d12b3-8dd7-4c1a-8e09-f62580830291",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/f26dd613-db9a-456c-94d2-2d45ea57c944",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/64491749-5cff-4441-b703-3eba4ca09bb1",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/6c0b8932-e26d-48ee-b8f8-da8779d1cd7a",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/70bcbefd-24e0-4c40-981a-19bd5a317c82",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/02626140-bd1d-4fce-aa5c-e827a1ac81ef",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/13329064-a7c6-4021-b358-9509c317b0e8",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/c5882e7a-6bf4-4c58-8c23-58e743da364e",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/9b94c775-3393-4bd7-acbf-8e3035614498",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/d8be0871-f4d3-42fc-8615-c4e525c6f691",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/9328d067-9b08-4aa7-bff8-e42443dbfbcf",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/c898b67a-0448-4bc5-b322-e92d300a29eb",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/4e52c1df-c7ab-4c49-bc8c-9e02fee2ef22",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/1b2889b0-bfe2-481d-af34-41e41f03f01d",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/f2b9ab47-d27c-428d-9496-fe79769f4877",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/13cd04f9-de44-4aaf-be7a-dc19cc9a0d9e",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/648cc7b5-6ac2-4626-b51c-49c200a15a8a",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/e8922ec1-2342-42a5-9127-7d2a393b3a2b",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/e25284fb-0e45-42a1-988c-ccf3b1ee63d1",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/6dd8f10c-3b7e-49cb-ade1-f439dabc8fc0",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/0ca8fb21-9134-497a-a010-6f568b0925db",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/857200ea-dc0e-49de-bdbd-690008b4f365",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/e34b8870-efeb-4d08-993b-05af0a8789a9",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/18dfe65d-7866-48dc-89a1-4ba21475e5b4",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/12734176-7656-48b4-b094-848773505f80",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/3b133765-f249-49d0-b2ba-aad8e45281fb",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/9c463cde-9496-4200-9a57-864e43d4142c",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/ef6b1682-d4d4-44e2-b739-8a9eb22503a8",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/416f7416-6d55-41e3-a1a3-0311a0417282",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/07fdca05-7610-41ce-a574-aa93f2f86a43",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/8df4282a-733b-4d37-9f0e-d018e95cd7e6",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/d89c2c82-a7ee-4ae3-b4bb-a36770923742",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/28961d6a-2838-46c4-b0e0-97e1ee383c67",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/da22ca2d-7d6b-4fbf-a9ee-f5b83153c62a",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/1902015c-033c-4057-a4e2-ed4b1838aa80",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/fc5684f6-23c3-4740-a405-e9c03ed15c1f",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/176caee0-667c-4f8c-a05f-d4461a5987d8",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/1b3356a9-a672-4b51-aedb-785729be4ec2",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/40ae8c24-e1b1-4784-a190-c763a253fdc4",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/9de2f93f-7141-4f62-a20d-44b7062e849d",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/0c219d93-f700-4afe-bdb9-78f7d70d57f4",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/1dc69abd-d538-4378-b9db-b00737f3f18a",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/206e7ac3-c882-4a96-89ab-e3edc9f987e7",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/f8346d75-749e-47ca-a9fe-4b680ce41e07",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/9201c927-f421-43cf-97c3-813caed3ebb2",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/ffd291a6-23cd-49d5-ad79-9e9aa15493f8",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/d8dec580-1eb4-45a6-ba57-7da6188d1227",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/856ec524-5b39-43bf-b9f8-72c770fdd9dc",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/9a350441-bc70-4158-a37c-ec6b1d67f856",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/03bc9220-e66f-4fbf-90b3-c59653d8445d",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/571b6f20-cd49-4200-9cb5-24ef2ff19341",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/4c967dac-555c-4a47-9e8f-321cffd8f770",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/b57e3582-77d9-43fe-9b89-80a2d9d7d589",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/e35fba00-af98-4283-b4bc-416ccf2098b5",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/017ac6c2-6d8d-40e0-9a79-e4f486df4766",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/8f275223-e8a5-4f32-be9e-5e2396331854",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/6c06c92d-9468-431d-9267-b0843dab37c7",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/324c481c-91b0-4bac-aa73-33b872f4c155",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/0c4774f1-3015-452a-a635-ae1236e9c7e1",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/16fd8bb7-f96f-4836-a14f-16ac3168c294",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/be14df5b-973d-4eae-8b69-7066493063a7",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/9d8d20cc-c6be-468e-a141-ee42df204ef7",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/0ca3c8b2-47db-4ae0-90cd-55e144c0554e",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/e47b9b64-34b7-4297-b9ae-347eea111d1c",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/b1b8df8b-1699-4b35-8464-b3c28c0f014f",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/5317ff42-8b65-40ca-b3f3-f14871aa1ccc",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/aa10700d-fbfb-465f-aa58-719e1ae224c7",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/9a460357-2e7e-43a6-a75f-9c54d838fbbd",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/177f0a7c-d1d8-49e9-ad9d-a9b41b52e290",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/92824b50-37bf-409a-b15e-8527a4734582",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/1f26fb65-6969-4fe9-94ff-d56839931363",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/4710c5cc-8b2e-4585-9ab6-215b2336d253",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/ea7343aa-14f3-48b2-b414-611a25c2453a",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/99da7fee-d9c0-4dc7-a878-4afb92bb86cd",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/b6558b63-9860-435d-a491-920aaaa50a44",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/31ae33ce-f1d5-4303-abb9-af6516f5698c",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/66e91a2d-a260-4a19-ac51-209023657b33",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/e3a79231-3c03-4a2a-ab2c-8dc26e7bc4be",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/73206d70-6139-4604-bf63-0e4dc79f94b1",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/623c7ab9-9aac-42b5-94c2-55138506d125",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/6981bc98-2ae9-4417-9243-4fccf8768945",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/6e666b54-98b0-49be-9792-d238b6000ebc",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/c44ac4d0-416c-4851-aead-4d961df82df3",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/599e73e5-845f-4266-a06f-a7586b3419b3",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/98216791-6726-4300-9061-4ea6d2fbf7f3",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/2618b15f-bd08-42e9-b471-fc017ad65039",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/70c58906-aa0f-4bd0-a12c-1d259c69134a",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/2fe92cbe-d73a-4f8a-90f1-7ffcd0d74b2a",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/30444161-b6be-44bc-a9f5-ad99baf9597a",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/85a544e2-864f-4c84-9482-d9d7657e0cf9",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/85474cd0-c1cd-4f29-85d6-67306925b607",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/6f006751-c678-42f0-8f68-34137d829a85",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/57d2d471-7baf-495c-8b96-5a14cb0e2c5f",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/c84ee602-9e00-461e-97ac-d16f2db7b703",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/071f52e9-f5a0-41db-9973-353d0ab0ff3c",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/3c1dd6c6-646b-42b6-894f-5a711f3d11fd",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/6353b3b4-4519-4924-9be3-6e51fc1a2014",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/0dc1a92c-4b79-47e8-bfe4-c34e319e86d6",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/322b9612-a85f-4618-a0bb-64093c05e1d7",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/946cd021-345c-472b-91eb-87afbbdce39b",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/4a441c5e-c370-49f9-a756-8a3454e544c0",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/2caa5298-c4d3-4c37-b175-dcc4b2cdd896",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/8834ace8-e979-4b85-b591-fdd8d21f0e2f",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/c93eaa3d-95b8-4b50-be92-cbcf81518cde",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/596a6daf-204d-4dcf-8333-5e8997ea00a7",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/ae200630-6d83-4760-8847-4b35bff14e17",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/590ded4a-dc0d-438e-ba67-5d10de4b6720",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/f42a9b38-666c-43f6-b237-f5c029984dc2",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/de44c791-1201-4988-ab0b-ca873811f928",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/f8662695-edf1-4108-95e1-2c4281246e36",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/fd5a1bff-b170-4213-ade5-5183049896e7",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/0371031d-e436-4642-81f8-0b62c0d636a1",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/c14feb1b-54c0-45d4-bd9b-2c21cbb5b88c",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/567bc2bf-62f5-4a7c-9f20-2dfae7713f09",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/8fcd967d-d143-4348-82aa-85cf946046c1",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/ffc6e109-d916-438c-bc0b-701a37179aa9",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/3b03c23e-9cfd-4d5d-8178-2049b9d15540",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/06e6b49d-4fe4-4001-8348-03746d93c9f0",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/7ff347df-eee9-4406-bcd3-6764728da505",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/0226de27-3e4c-4fc1-a61c-f667f4c79674",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/7bf20195-1a63-4883-9c63-cb7b55dc7ff0",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/4a8fe1d2-984c-4a1f-b8ad-04b8123e6cfd",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/338846b4-c61a-4e14-864f-59de2db00b5f",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/64b2334d-9cf6-45d6-8465-446596c89fe2",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/8a0793da-33a7-4773-b1b9-5b67ba582110",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/1f54f371-9e67-4bde-9559-4cea224b8459",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/bd3d00ff-8331-405b-a221-b9b99ae3f286",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/600f46e9-50f4-41d3-b96d-7ce132441d3d",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/2d61139a-a3fc-4b96-be3e-0085701575cf",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/ca9e7dbb-ecb8-4159-b983-53be6eebcd38",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/e6ed4508-2859-438c-9e52-89a34878b296",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/73595fa2-baa2-4242-97f0-6ccf2df5c058",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/69e6c0a7-3d55-459c-9b8b-a9b3ec8b41d4",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/1a00fbc9-eb48-4a12-a2fb-cf0a5f175736",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/aa4cb3b0-0c8d-465b-8143-33497ae8d49f",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/f4b0621f-bd9a-49ac-8b5e-d88f019390a5",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/28c5c401-7fc3-4e0b-9464-c36ae334dafc",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/8c43e30e-1854-4d6b-9672-b7ecb14eb99f",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/d6aabf70-6c2b-4d8b-b7af-07dec825eb5c",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/77713771-49aa-4f16-a490-6fe016faa3b8",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/fd2b686a-6021-4c0a-8e62-4585b15ac96f",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/ba7ababf-55f1-4608-8e2a-c45d2f79972b",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/c159a4a6-2765-4669-8ab0-028533b3a57f",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/b5deb6d4-f77f-482c-a677-242e51b9ea36",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/7120c82e-303e-4f80-824c-31e1320d702c",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/0fe5a6af-7c70-45af-a911-adbf967d3e15",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/e164a780-9b41-479d-a170-6295b498d351",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/242ac51c-4982-4b6d-a18e-83899d4aab04",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/ece3912d-aa41-460d-be86-bb5d69add9c9",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/c1a0f54b-2b21-4e5e-8f18-ca5545d82364",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/253b68be-8225-468a-a354-bcc22bb8727c",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/95e888bd-ae8c-447e-a96e-aae757b6b08e",
                "cord-dicoms-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/211834f8-18ab-4c43-856c-c54c6ae8f6b4",
            ],
            "width": 256,
            "height": 256,
        }
    },
    "object_answers": {"ai7DhsOA": {"objectHash": "ai7DhsOA", "classifications": []}},
    "classification_answers": {},
    "object_actions": {
        "ai7DhsOA": {
            "objectHash": "ai7DhsOA",
            "actions": [
                {
                    "name": "is occluded?",
                    "range": [[86, 86], [88, 88]],
                    "value": "is_occluded?",
                    "answers": [{"name": "yes", "value": "yes", "featureHash": "25a13ecf"}],
                    "dynamic": True,
                    "trackHash": "794bd3f1-c60e-4212-9ca8-1a24c3a5e7c4",
                    "featureHash": "f72182d1",
                    "shouldPropagate": False,
                    "manualAnnotation": True,
                }
            ],
        }
    },
    "label_status": "LABEL_IN_PROGRESS",
}
