LABEL_ROW_METADATA_BLURB = [
    {
        "label_hash": "44e1bdfb-3c45-4edb-8a71-a969f22fd632",
        "task_uuid": "ec176f56-6156-400d-97a2-68e8707e89a1",
        "branch_name": "main",
        "label_status": "LABEL_IN_PROGRESS",
        "created_at": "2023-03-21T09:58:08.472959",
        "last_edited_at": "2023-03-21T11:03:52.573279",
        "data_hash": "9b45984a-0046-4389-ba0d-b73b6b35ee82",
        "dataset_hash": "6a8a9b04-b173-44a7-b746-558eaa468132",
        "dataset_title": "Test dataset",
        "data_title": "sample.mp4",
        "data_type": "VIDEO",
        "is_shadow_data": False,
        "frames_per_second": 23.976023976023978,
        "duration": 29.07071,
        "number_of_frames": 697,
        "data_link": "cord-videos-dev/CcJU09GkdjcLCslKtd6bEqi48ZA2/9b45984a-0046-4389-ba0d-b73b6b35ee82",
        "file_type": "video/mp4",
        "file_size": "5468354.0",
        "width": 1280,
        "height": 720,
        "is_optimised_image_group": "None",
        "is_image_sequence": "None",
        "annotation_task_status": "ASSIGNED",
    },
    {
        "label_hash": "2321fd7d-99cd-4d85-b371-9a9f59cf79a7",
        "task_uuid": "ec176f56-6156-400d-97a2-68e8707e89a2",
        "branch_name": "main",
        "label_status": "LABEL_IN_PROGRESS",
        "created_at": "2023-03-21T10:25:48.821571",
        "last_edited_at": "2023-03-21T11:51:19.785354",
        "data_hash": "b13c4f55-1eae-4832-93e8-83b030ef17b0",
        "dataset_hash": "6a8a9b04-b173-44a7-b746-558eaa468132",
        "dataset_title": "Test dataset",
        "data_title": "Screenshot 2023-03-16 at 13.04.59.png",
        "data_type": "IMAGE",
        "is_shadow_data": False,
        "frames_per_second": "None",
        "duration": "None",
        "number_of_frames": 1,
        "data_link": "cord-images-dev/CcJU09GkdjcLCslKtd6bEqi48ZA2/b13c4f55-1eae-4832-93e8-83b030ef17b0",
        "file_type": "image/png",
        "file_size": "13154.0",
        "width": 304,
        "height": 220,
        "is_optimised_image_group": "None",
        "is_image_sequence": "None",
        "annotation_task_status": "QUEUED",
    },
    {
        "label_hash": "f6dcda1a-8e0a-45b2-a3c5-d7ebfe93ad8a",
        "task_uuid": "ec176f56-6156-400d-97a2-68e8707e89a3",
        "branch_name": "main",
        "label_status": "LABEL_IN_PROGRESS",
        "created_at": "2023-03-21T12:02:42.287150",
        "last_edited_at": "2023-03-21T12:02:42.287150",
        "data_hash": "f53546bf-9c1e-47d5-bc20-282a4c187977",
        "dataset_hash": "6a8a9b04-b173-44a7-b746-558eaa468132",
        "dataset_title": "Test dataset",
        "data_title": "mega-image-group",
        "data_type": "IMG_GROUP",
        "is_shadow_data": False,
        "frames_per_second": "None",
        "duration": "None",
        "number_of_frames": 4,
        "data_link": "None",
        "file_type": "None",
        "file_size": "None",
        "width": "None",
        "height": "None",
        "is_optimised_image_group": False,
        "is_image_sequence": False,
        "annotation_task_status": "QUEUED",
    },
]

LABEL_ROW_BLURB = [
    {
        "label_hash": "2321fd7d-99cd-4d85-b371-9a9f59cf79a7",
        "branch_name": "main",
        "created_at": "2023-03-21 10:25:48",
        "last_edited_at": "2023-03-21 11:51:19",
        "dataset_hash": "6a8a9b04-b173-44a7-b746-558eaa468132",
        "dataset_title": "Test dataset",
        "data_title": "Screenshot 2023-03-16 at 13.04.59.png",
        "data_hash": "b13c4f55-1eae-4832-93e8-83b030ef17b0",
        "data_type": "image",
        "is_image_sequence": "None",
        "video_link": "None",
        "data_units": {
            "b13c4f55-1eae-4832-93e8-83b030ef17b0": {
                "data_hash": "b13c4f55-1eae-4832-93e8-83b030ef17b0",
                "data_title": "Screenshot 2023-03-16 at 13.04.59.png",
                "data_type": "image/png",
                "data_sequence": 0,
                "labels": {
                    "objects": [
                        {
                            "name": "Pear",
                            "color": "#E27300",
                            "shape": "bounding_box",
                            "value": "pear",
                            "createdAt": "Tue, 21 Mar 2023 11:21:51 GMT",
                            "createdBy": "sergei@encord.com",
                            "confidence": 1,
                            "objectHash": "8/VCHNzS",
                            "featureHash": "no8RyWRY",
                            "manualAnnotation": True,
                            "boundingBox": {"h": 0.1836, "w": 0.093, "x": 0.2051, "y": 0.3293},
                        },
                        {
                            "name": "Pear",
                            "color": "#E27300",
                            "shape": "bounding_box",
                            "value": "pear",
                            "createdAt": "Tue, 21 Mar 2023 11:21:56 GMT",
                            "createdBy": "sergei@encord.com",
                            "confidence": 1,
                            "objectHash": "uGsbuPaf",
                            "featureHash": "no8RyWRY",
                            "manualAnnotation": True,
                            "boundingBox": {"h": 0.178, "w": 0.0903, "x": 0.4376, "y": 0.3367},
                        },
                    ],
                    "classifications": [
                        {
                            "name": "hot dog",
                            "value": "hot_dog",
                            "createdAt": "Tue, 21 Mar 2023 11:23:36 GMT",
                            "createdBy": "sergei@encord.com",
                            "confidence": 1,
                            "featureHash": "4BjoumKd",
                            "lastEditedAt": "Tue, 21 Mar 2023 11:23:36 GMT",
                            "classificationHash": "j8oMRZ8f",
                            "manualAnnotation": True,
                        }
                    ],
                },
                "data_link": "https://storage.googleapis.com/encord-local-dev.appspot.com/cord-images-dev/CcJU09GkdjcLCslKtd6bEqi48ZA2/b13c4f55-1eae-4832-93e8-83b030ef17b0?X-Goog-Algorithm=GOOG4-RSA-SHA256&X-Goog-Credential=firebase-adminsdk-efw44%40encord-local-dev.iam.gserviceaccount.com%2F20230328%2Fauto%2Fstorage%2Fgoog4_request&X-Goog-Date=20230328T153206Z&X-Goog-Expires=604800&X-Goog-SignedHeaders=host&X-Goog-Signature=69a8f2fca41edc7d81d3d2719e3ad188cee29fb5ac3302f24e0e93cf60cb6ec38df6b39203ede30bca981c347722345ed13848a22fe0b63da9de44cd5ecb5b4d85a11ac595d927df7b354a93a5523bb1282cf8b4fa5abb3d2c5e41112f0002faf5c07d577f9241d6d23695c503c7a34b12733bea4827d1e6c5a4c4797607e47193beebb038e2debfd650033df9ed90db44e2aa853f10a1cfd55d7e288685e9c6b0e4812993fd089f114e7d8f7bfb78e4fae52b8946d6946807aba148b5514f9855d669f1e476cd3315ed699377c7db5947358b96666fd0b6c24eb47bb1f354fc70b48644a91427922927b9db85353d04f4024e71fa6cc162a6a591add123b814",
                "width": 304,
                "height": 220,
            }
        },
        "object_answers": {
            "8/VCHNzS": {"objectHash": "8/VCHNzS", "classifications": []},
            "uGsbuPaf": {"objectHash": "uGsbuPaf", "classifications": []},
        },
        "classification_answers": {
            "j8oMRZ8f": {
                "classificationHash": "j8oMRZ8f",
                "classifications": [
                    {
                        "name": "hot dog",
                        "value": "hot_dog",
                        "answers": [{"name": "not hot dog", "value": "not_hot_dog", "featureHash": "MpKwvogL"}],
                        "featureHash": "t/prlg4Z",
                        "manualAnnotation": True,
                    }
                ],
            }
        },
        "object_actions": {},
        "label_status": "LABEL_IN_PROGRESS",
        "export_history": [
            {
                "export_hash": "a5570813-ad77-4f4d-b507-bdda3ff4db8d",
                "exported_at": "Tue, 21 Mar 2023 10:25:49 UTC",
                "user_email": "sergei@encord.com",
            }
        ],
        "export_hash": "56042be4-3c8e-4a6e-a916-37d31da58617",
        "exported_at": "Tue, 28 Mar 2023 14:32:14 UTC",
        "annotation_task_status": "QUEUED",
    },
    {
        "label_hash": "f6dcda1a-8e0a-45b2-a3c5-d7ebfe93ad8a",
        "branch_name": "main",
        "created_at": "2023-03-21 12:02:42",
        "last_edited_at": "2023-03-21 12:02:42",
        "dataset_hash": "6a8a9b04-b173-44a7-b746-558eaa468132",
        "dataset_title": "Test dataset",
        "data_title": "mega-image-group",
        "data_hash": "f53546bf-9c1e-47d5-bc20-282a4c187977",
        "data_type": "img_group",
        "is_image_sequence": False,
        "video_link": "None",
        "data_units": {
            "b06893e3-d7d2-4aa9-83b0-d91c9acc51be": {
                "data_hash": "b06893e3-d7d2-4aa9-83b0-d91c9acc51be",
                "data_title": "Screenshot 2023-03-14 at 11.41.48.png",
                "data_link": "https://storage.googleapis.com/encord-local-dev.appspot.com/cord-images-dev/CcJU09GkdjcLCslKtd6bEqi48ZA2/3fb973bf-50fc-4428-8149-c0b7cd23d92f?X-Goog-Algorithm=GOOG4-RSA-SHA256&X-Goog-Credential=firebase-adminsdk-efw44%40encord-local-dev.iam.gserviceaccount.com%2F20230328%2Fauto%2Fstorage%2Fgoog4_request&X-Goog-Date=20230328T153207Z&X-Goog-Expires=604800&X-Goog-SignedHeaders=host&X-Goog-Signature=9a079800c779ab1242a7f7e6115155769199a40af88df53339ad38212171e8d7ea70fd5c82376dd2c90767f6e06f72b6cd728ee1d455a9e4b9180f213e2b6e94e3526d60f1877cf419adae20435ec8a2a44629c3dc2166fc0871c9cff9cd9f8cdec5ffe2ba1548ea5d9b276697a9c347b7a728de32cb6bec89708cd9b38d4330bbc81f28f128d3a0f18ac7036137b77be385cce4f422916e08b21fd4db8670d26e149ffff266356b2884c39f278f2ee196bfaff5dd91db8bb1f0a049a30a917aef3ca8e73219c3dbea572e0ea3c518bada6020d2bbb265b9bf64897070b1abbb323c10a752e99d60a828b4169a1da3629db4f4c2b66c20424689fccdd4fcf8b6",
                "data_type": "image/png",
                "data_sequence": "0",
                "width": 376,
                "height": 304,
                "labels": {"objects": [], "classifications": []},
            },
            "714a7e19-5802-447a-bfa8-8850ff906999": {
                "data_hash": "714a7e19-5802-447a-bfa8-8850ff906999",
                "data_title": "Screenshot 2023-03-14 at 11.41.49.png",
                "data_link": "https://storage.googleapis.com/encord-local-dev.appspot.com/cord-images-dev/CcJU09GkdjcLCslKtd6bEqi48ZA2/47121fd5-fce3-4688-9027-81bafb9060e4?X-Goog-Algorithm=GOOG4-RSA-SHA256&X-Goog-Credential=firebase-adminsdk-efw44%40encord-local-dev.iam.gserviceaccount.com%2F20230328%2Fauto%2Fstorage%2Fgoog4_request&X-Goog-Date=20230328T153207Z&X-Goog-Expires=604800&X-Goog-SignedHeaders=host&X-Goog-Signature=2ef78f7ff647325221c6d01ca41417e6ae072ec0b1370da3fedae85c594dd0ed3fb0da2f7a11973e0f71f8702cf33ac06fbecf1ddaa4dd594cc46e5e0876563e978f4ae7450bf6992aa568715038e8f2d590ed521e1732d727250cfe9df81c9ec0534c05a61b85562f05a5d53d6e33f5e309cd2fbf02f2b0638d0030d0c553cbae0c480b11da23082d740703202813e00f7301297a37070b6fce8f63c9f6ad1845e70a3b36fae48b63a9ce572fc14bc5907a3efd881076ff9fbc7eee16e9d9e51427d5c289b49edf82279419d96e561288e59653a55f816f9a3723bb767acc6c0b8d06c059303258ac19d7468c72da9e4729320304a89a774641cc1c5d07fe03",
                "data_type": "image/png",
                "data_sequence": "1",
                "width": 418,
                "height": 258,
                "labels": {"objects": [], "classifications": []},
            },
            "7b1dcb67-ca49-421b-9fc5-1fa52f538aab": {
                "data_hash": "7b1dcb67-ca49-421b-9fc5-1fa52f538aab",
                "data_title": "Screenshot 2023-03-16 at 13.04.51.png",
                "data_link": "https://storage.googleapis.com/encord-local-dev.appspot.com/cord-images-dev/CcJU09GkdjcLCslKtd6bEqi48ZA2/8f998937-8a24-413a-b332-c34fd7e45de1?X-Goog-Algorithm=GOOG4-RSA-SHA256&X-Goog-Credential=firebase-adminsdk-efw44%40encord-local-dev.iam.gserviceaccount.com%2F20230328%2Fauto%2Fstorage%2Fgoog4_request&X-Goog-Date=20230328T153207Z&X-Goog-Expires=604800&X-Goog-SignedHeaders=host&X-Goog-Signature=3cc9e75481df91885530ae08fc5ecb2a13fb9829abca778464ad33eb2c1a87280cfd6997450c5b35786184882aee7b81688d45d49a6f0fa7c15c8664145e47d80b0b267ab5ea00538fe02711372fa30bc25887fe2b8a5265a15c0e2b0a42e5d61238ade7291386324d8bc28d0fd520016170491ec09bc98bd69ac27c1d99e55a00c4bde63c7bf89087aebea58a7f239432ef5d648bc2b48a55d052a784fb74fcbd98b322740e6c53b23a59577c3e77e462d51a8e16c5837f6ec9a8b542d8178c7a96a2a8b2e1734facde0f7d003e2397d0b7fead1716602443bfa5c7f356ab5be9744e53e0534353b89bc0ee46e2cad65efa4e63ac2ad2f90920626f8a4383ef",
                "data_type": "image/png",
                "data_sequence": "2",
                "width": 226,
                "height": 144,
                "labels": {"objects": [], "classifications": []},
            },
            "041408a2-c887-451b-a961-872f6a319e41": {
                "data_hash": "041408a2-c887-451b-a961-872f6a319e41",
                "data_title": "Screenshot 2023-03-16 at 13.04.58.png",
                "data_link": "https://storage.googleapis.com/encord-local-dev.appspot.com/cord-images-dev/CcJU09GkdjcLCslKtd6bEqi48ZA2/a856107e-af19-46d3-8453-6b0d19a93b0e?X-Goog-Algorithm=GOOG4-RSA-SHA256&X-Goog-Credential=firebase-adminsdk-efw44%40encord-local-dev.iam.gserviceaccount.com%2F20230328%2Fauto%2Fstorage%2Fgoog4_request&X-Goog-Date=20230328T153207Z&X-Goog-Expires=604800&X-Goog-SignedHeaders=host&X-Goog-Signature=2f3af79a9467c9a0978654eda9588d65c01ed49205b47cad76d48475ac622974e28632050b597b7902367b3ab8d970688e2c46dfe009c03825ec82c4d968d2cbe8ada3c919cda4afe6991d943defa567e657fed9ff79cadce6ab55c7b5fbed5ba481dbd0f7917378ceeebecb8c6f194c4508c21bd3c87a5e7c92ad1c23af5484ea953f65ce979280414b33589f4a9128a26664c8dcdd6546e0603c4e66087b622d35d41187326fba585117350817e49459df0ab0a4a600d7bb4d7da4cf16ff21f41532a382014903ae9eb7737d7e0e54c78293ba8e92e3a9095ee9e296d3f1e73558464c8daa92f484423c88051ace24d7551cb77f7d5df078355a81818d6186",
                "data_type": "image/png",
                "data_sequence": "3",
                "width": 252,
                "height": 294,
                "labels": {"objects": [], "classifications": []},
            },
        },
        "object_answers": {},
        "classification_answers": {},
        "object_actions": {},
        "label_status": "LABEL_IN_PROGRESS",
        "export_history": [],
        "export_hash": "9778ee89-6c31-40ec-a67c-61bba6fcbb49",
        "exported_at": "Tue, 28 Mar 2023 14:32:15 UTC",
        "annotation_task_status": "QUEUED",
    },
    {
        "label_hash": "44e1bdfb-3c45-4edb-8a71-a969f22fd632",
        "branch_name": "main",
        "created_at": "2023-03-21 09:58:08",
        "last_edited_at": "2023-03-22 19:02:27",
        "dataset_hash": "6a8a9b04-b173-44a7-b746-558eaa468132",
        "dataset_title": "Test dataset",
        "data_title": "sample.mp4",
        "data_hash": "9b45984a-0046-4389-ba0d-b73b6b35ee82",
        "data_type": "video",
        "is_image_sequence": "None",
        "video_link": "https://storage.googleapis.com/encord-local-dev.appspot.com/cord-videos-dev/CcJU09GkdjcLCslKtd6bEqi48ZA2/9b45984a-0046-4389-ba0d-b73b6b35ee82?X-Goog-Algorithm=GOOG4-RSA-SHA256&X-Goog-Credential=firebase-adminsdk-efw44%40encord-local-dev.iam.gserviceaccount.com%2F20230328%2Fauto%2Fstorage%2Fgoog4_request&X-Goog-Date=20230328T153208Z&X-Goog-Expires=604800&X-Goog-SignedHeaders=host&X-Goog-Signature=07aa2e0a51f13576be1be021072fd283f080b1bd26fb839a56b06165338bf3733b0051cce21eb27656728dcf8785f682d432781f3d1d638aa3bb150a492a62a20990449eaf2e02059d0ab835f67e9449c8637e47f36fbc1c0610eb06905a5b4cd1788df76228cf98f8beaf2e8b960374b5d40c90a062ecd9d49420829a6c4c78ee2ede62af00d2addc988488ffd638f633493fb4a14bf2067a6a036f90af728aef32700b5254d52026c69b30524cbe70959fae66ee5b6265579cfc6074ded8db9bfa8ca5ed432c2ad8ae9c1996a3b29efbcabf5cde024cce0a3ed25a69ff52b3c593bade583ef305a2f023585732e8c4362939d4e5a572faeb0492a41d574a2d",
        "data_units": {
            "9b45984a-0046-4389-ba0d-b73b6b35ee82": {
                "data_hash": "9b45984a-0046-4389-ba0d-b73b6b35ee82",
                "data_title": "sample.mp4",
                "data_type": "video/mp4",
                "data_sequence": 0,
                "labels": {
                    "0": {"objects": [], "classifications": []},
                    "1": {
                        "objects": [
                            {
                                "name": "Apple",
                                "color": "#D33115",
                                "shape": "bounding_box",
                                "value": "apple",
                                "createdAt": "Wed, 22 Mar 2023 18:00:13 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "objectHash": "cY1cfw0G",
                                "featureHash": "qWm5E3j4",
                                "manualAnnotation": True,
                                "boundingBox": {"h": 0.2712, "w": 0.1549, "x": 0.0238, "y": 0.3007},
                            },
                            {
                                "name": "Apple",
                                "color": "#D33115",
                                "shape": "bounding_box",
                                "value": "apple",
                                "createdAt": "Wed, 22 Mar 2023 18:00:17 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "objectHash": "IFgHza0m",
                                "featureHash": "qWm5E3j4",
                                "manualAnnotation": True,
                                "boundingBox": {"h": 0.2589, "w": 0.1664, "x": 0.4353, "y": 0.4302},
                            },
                            {
                                "name": "Apple",
                                "color": "#D33115",
                                "shape": "bounding_box",
                                "value": "apple",
                                "createdAt": "Wed, 22 Mar 2023 18:00:21 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "objectHash": "obAZPhln",
                                "featureHash": "qWm5E3j4",
                                "manualAnnotation": True,
                                "boundingBox": {"h": 0.3185, "w": 0.1884, "x": 0.6087, "y": 0.3993},
                            },
                        ],
                        "classifications": [],
                    },
                    "2": {"objects": [], "classifications": []},
                    "290": {
                        "objects": [],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                    "291": {
                        "objects": [],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                    "292": {
                        "objects": [],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                    "293": {
                        "objects": [],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                    "294": {
                        "objects": [],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                    "295": {
                        "objects": [],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                    "296": {
                        "objects": [],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                    "297": {
                        "objects": [],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                    "298": {
                        "objects": [],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                    "299": {
                        "objects": [],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                    "300": {
                        "objects": [
                            {
                                "name": "Apple",
                                "color": "#D33115",
                                "shape": "bounding_box",
                                "value": "apple",
                                "createdAt": "Tue, 21 Mar 2023 10:29:55 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "objectHash": "cY1cfw0G",
                                "featureHash": "qWm5E3j4",
                                "manualAnnotation": True,
                                "boundingBox": {"h": 0.0944, "w": 0.0526, "x": 0.2919, "y": 0.8575},
                            },
                            {
                                "name": "Apple",
                                "color": "#D33115",
                                "shape": "bounding_box",
                                "value": "apple",
                                "createdAt": "Tue, 21 Mar 2023 10:30:04 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "objectHash": "IFgHza0m",
                                "featureHash": "qWm5E3j4",
                                "manualAnnotation": True,
                                "boundingBox": {"h": 0.0834, "w": 0.0541, "x": 0.4507, "y": 0.8722},
                            },
                            {
                                "name": "Apple",
                                "color": "#D33115",
                                "shape": "bounding_box",
                                "value": "apple",
                                "createdAt": "Tue, 21 Mar 2023 10:30:09 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "objectHash": "obAZPhln",
                                "featureHash": "qWm5E3j4",
                                "manualAnnotation": True,
                                "boundingBox": {"h": 0.0972, "w": 0.0541, "x": 0.5899, "y": 0.8722},
                            },
                        ],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                    "301": {
                        "objects": [],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                    "302": {
                        "objects": [],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                    "303": {
                        "objects": [],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                    "304": {
                        "objects": [],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                    "305": {
                        "objects": [],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                    "306": {
                        "objects": [],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                    "307": {
                        "objects": [],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                    "308": {
                        "objects": [],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                    "309": {
                        "objects": [],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                    "310": {
                        "objects": [],
                        "classifications": [
                            {
                                "name": "hot dog",
                                "value": "hot_dog",
                                "createdAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "createdBy": "sergei@encord.com",
                                "confidence": 1,
                                "featureHash": "4BjoumKd",
                                "lastEditedAt": "Tue, 21 Mar 2023 10:33:59 GMT",
                                "classificationHash": "+GqFZjI0",
                                "manualAnnotation": True,
                            }
                        ],
                    },
                },
                "data_fps": 23.976023976023978,
                "data_duration": 29.07071,
                "data_link": "https://storage.googleapis.com/encord-local-dev.appspot.com/cord-videos-dev/CcJU09GkdjcLCslKtd6bEqi48ZA2/9b45984a-0046-4389-ba0d-b73b6b35ee82?X-Goog-Algorithm=GOOG4-RSA-SHA256&X-Goog-Credential=firebase-adminsdk-efw44%40encord-local-dev.iam.gserviceaccount.com%2F20230328%2Fauto%2Fstorage%2Fgoog4_request&X-Goog-Date=20230328T153208Z&X-Goog-Expires=604800&X-Goog-SignedHeaders=host&X-Goog-Signature=07aa2e0a51f13576be1be021072fd283f080b1bd26fb839a56b06165338bf3733b0051cce21eb27656728dcf8785f682d432781f3d1d638aa3bb150a492a62a20990449eaf2e02059d0ab835f67e9449c8637e47f36fbc1c0610eb06905a5b4cd1788df76228cf98f8beaf2e8b960374b5d40c90a062ecd9d49420829a6c4c78ee2ede62af00d2addc988488ffd638f633493fb4a14bf2067a6a036f90af728aef32700b5254d52026c69b30524cbe70959fae66ee5b6265579cfc6074ded8db9bfa8ca5ed432c2ad8ae9c1996a3b29efbcabf5cde024cce0a3ed25a69ff52b3c593bade583ef305a2f023585732e8c4362939d4e5a572faeb0492a41d574a2d",
                "width": 1280,
                "height": 720,
            }
        },
        "object_answers": {
            "cY1cfw0G": {"objectHash": "cY1cfw0G", "classifications": []},
            "IFgHza0m": {"objectHash": "IFgHza0m", "classifications": []},
            "obAZPhln": {"objectHash": "obAZPhln", "classifications": []},
        },
        "classification_answers": {
            "+GqFZjI0": {
                "classificationHash": "+GqFZjI0",
                "classifications": [
                    {
                        "name": "hot dog",
                        "value": "hot_dog",
                        "answers": [{"name": "hot dog", "value": "hot_dog", "featureHash": "8fjrfCJy"}],
                        "featureHash": "t/prlg4Z",
                        "manualAnnotation": True,
                    }
                ],
            }
        },
        "object_actions": {},
        "label_status": "LABEL_IN_PROGRESS",
        "export_history": [
            {
                "export_hash": "b8354f9c-26f4-46ac-8207-1ff72b2552f4",
                "exported_at": "Tue, 21 Mar 2023 10:23:19 UTC",
                "user_email": "sergei@encord.com",
            }
        ],
        "export_hash": "069e80bc-3325-475f-8051-434aef7bc87b",
        "exported_at": "Tue, 28 Mar 2023 14:32:16 UTC",
        "annotation_task_status": "ASSIGNED",
    },
]

LABEL_ROW_METADATA_BLURB.sort(key=lambda x: x["data_hash"])
LABEL_ROW_BLURB.sort(key=lambda x: x["data_hash"])
