from typing import Any, Dict

labels: Dict[str, Any] = {
    "label_hash": "1b4398aa-1d4d-4873-8470-2ac9fa373ac0",
    "branch_name": "main",
    "created_at": "Thu, 09 Feb 2023 14:12:03 UTC",
    "last_edited_at": "Thu, 09 Feb 2023 14:12:03 UTC",
    "data_hash": "aaa6bc82-9f89-4545-adbb-f271bf28cf99",
    "annotation_task_status": "QUEUED",
    "is_shadow_data": False,
    "dataset_hash": "d947e847-88c8-4762-aee5-53dc7eeab852",
    "dataset_title": "Tracking bug dataset",
    "data_title": "failing_video_new.mp4",
    "data_type": "video",
    "data_units": {
        "cd63592b-a9e4-47d7-8563-aaed75c5afdc": {
            "data_hash": "cd63592b-a9e4-47d7-8563-aaed75c5afdc",
            "data_title": "failing_video_new.mp4",
            "data_type": "video/mp4",
            "data_sequence": 0,
            "labels": {
                "0": {
                    "objects": [
                        {
                            "name": "Epiglottis ",
                            "color": "#D33115",
                            "shape": "bounding_box",
                            "value": "epiglottis_",
                            "createdAt": "Mon, 11 Jul 2022 17:10:51 UTC",
                            "createdBy": "denis@cord.tech",
                            "confidence": 1,
                            "objectHash": "428fba2b",
                            "featureHash": "249c9370",
                            "lastEditedAt": "Mon, 09 Jan 2023 08:19:16 UTC",
                            "lastEditedBy": "denis@cord.tech",
                            "manualAnnotation": True,
                            "boundingBox": {"h": 0.0986, "w": 0.0859, "x": 0.2964, "y": 0.2516},
                        },
                        {
                            "name": "point",
                            "color": "#68BC00",
                            "point": {"0": {"x": 0.4243, "y": 0.3458}},
                            "shape": "point",
                            "value": "point",
                            "createdAt": "Mon, 11 Jul 2022 17:10:52 UTC",
                            "createdBy": "denis@cord.tech",
                            "lastEditedAt": "Mon, 11 Jul 2022 17:10:52 UTC",
                            "lastEditedBy": "denis@cord.tech",
                            "confidence": 1,
                            "objectHash": "82724bb2",
                            "featureHash": "d02c6e13",
                            "manualAnnotation": True,
                        },
                        {
                            "name": "Epiglottis ",
                            "color": "#D33115",
                            "shape": "bounding_box",
                            "value": "epiglottis_",
                            "createdAt": "Mon, 09 Jan 2023 08:18:27 UTC",
                            "createdBy": "denis@cord.tech",
                            "confidence": 1,
                            "objectHash": "u8BIOLmY",
                            "featureHash": "249c9370",
                            "lastEditedAt": "Mon, 09 Jan 2023 08:19:10 UTC",
                            "lastEditedBy": "denis@cord.tech",
                            "manualAnnotation": True,
                            "boundingBox": {"h": 0.052, "w": 0.0626, "x": 0.3052, "y": 0.4969},
                        },
                        {
                            "name": "Epiglottis ",
                            "color": "#D33115",
                            "shape": "bounding_box",
                            "value": "epiglottis_",
                            "createdAt": "Mon, 09 Jan 2023 08:18:28 UTC",
                            "createdBy": "denis@cord.tech",
                            "lastEditedAt": "Mon, 09 Jan 2023 08:18:28 UTC",
                            "lastEditedBy": "denis@cord.tech",
                            "confidence": 1,
                            "objectHash": "/ghwDXVK",
                            "featureHash": "249c9370",
                            "manualAnnotation": True,
                            "boundingBox": {"h": 0.0914, "w": 0.0986, "x": 0.5313, "y": 0.5914},
                        },
                    ],
                    "classifications": [],
                },
                "1": {
                    "objects": [
                        {
                            "name": "Epiglottis ",
                            "color": "#D33115",
                            "shape": "bounding_box",
                            "value": "epiglottis_",
                            "createdAt": "Mon, 11 Jul 2022 17:11:05 UTC",
                            "createdBy": "denis@cord.tech",
                            "lastEditedAt": "Mon, 11 Jul 2022 17:11:05 UTC",
                            "lastEditedBy": "denis@cord.tech",
                            "confidence": 1,
                            "objectHash": "428fba2b",
                            "featureHash": "249c9370",
                            "manualAnnotation": False,
                            "boundingBox": {"h": 0.0979, "w": 0.0844, "x": 0.2641, "y": 0.2417},
                        },
                        {
                            "name": "Epiglottis ",
                            "color": "#D33115",
                            "shape": "bounding_box",
                            "value": "epiglottis_",
                            "createdAt": "Mon, 09 Jan 2023 08:19:12 UTC",
                            "createdBy": "denis@cord.tech",
                            "isDeleted": False,
                            "confidence": 1,
                            "objectHash": "u8BIOLmY",
                            "featureHash": "249c9370",
                            "lastEditedAt": "Mon, 09 Jan 2023 08:19:12 UTC",
                            "lastEditedBy": "denis@cord.tech",
                            "manualAnnotation": True,
                            "boundingBox": {"h": 0.052, "w": 0.0626, "x": 0.3052, "y": 0.4969},
                        },
                    ],
                    "classifications": [],
                },
                "2": {
                    "objects": [
                        {
                            "name": "Epiglottis ",
                            "color": "#D33115",
                            "shape": "bounding_box",
                            "value": "epiglottis_",
                            "createdAt": "Mon, 11 Jul 2022 17:11:05 UTC",
                            "createdBy": "denis@cord.tech",
                            "lastEditedAt": "Mon, 11 Jul 2022 17:11:05 UTC",
                            "lastEditedBy": "denis@cord.tech",
                            "confidence": 1,
                            "objectHash": "428fba2b",
                            "featureHash": "249c9370",
                            "manualAnnotation": False,
                            "boundingBox": {"h": 0.0979, "w": 0.0844, "x": 0.2641, "y": 0.2375},
                        }
                    ],
                    "classifications": [],
                },
                "3": {
                    "objects": [
                        {
                            "name": "Epiglottis ",
                            "color": "#D33115",
                            "shape": "bounding_box",
                            "value": "epiglottis_",
                            "createdAt": "Mon, 11 Jul 2022 17:11:05 UTC",
                            "createdBy": "denis@cord.tech",
                            "lastEditedAt": "Mon, 11 Jul 2022 17:11:05 UTC",
                            "lastEditedBy": "denis@cord.tech",
                            "confidence": 1,
                            "objectHash": "428fba2b",
                            "featureHash": "249c9370",
                            "manualAnnotation": False,
                            "boundingBox": {"h": 0.0979, "w": 0.0844, "x": 0.2687, "y": 0.2375},
                        }
                    ],
                    "classifications": [],
                },
            },
            "data_fps": 25.0,
            "data_duration": 153.16,
            "data_link": "cord-videos-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/cd63592b-a9e4-47d7-8563-aaed75c5afdc",
            "width": 640,
            "height": 480,
        }
    },
    "object_answers": {
        "428fba2b": {"objectHash": "428fba2b", "classifications": []},
        "82724bb2": {"objectHash": "82724bb2", "classifications": []},
        "u8BIOLmY": {"objectHash": "u8BIOLmY", "classifications": []},
        "/ghwDXVK": {"objectHash": "/ghwDXVK", "classifications": []},
    },
    "classification_answers": {},
    "object_actions": {},
    "label_status": "LABELLED",
}

ontology: Dict[str, Any] = {
    "objects": [
        {"id": "1", "name": "Epiglottis ", "color": "#D33115", "shape": "bounding_box", "featureNodeHash": "249c9370"},
        {"id": "2", "name": "Larynx", "color": "#E27300", "shape": "bounding_box", "featureNodeHash": "e3c87d43"},
        {"id": "3", "name": "Oesophagus ", "color": "#16406C", "shape": "bounding_box", "featureNodeHash": "c6eb717a"},
        {"id": "4", "name": "Z-line ", "color": "#FE9200", "shape": "polyline", "featureNodeHash": "8b64f336"},
        {"id": "5", "name": "Stomach", "color": "#FCDC00", "shape": "bounding_box", "featureNodeHash": "f44083a3"},
        {"id": "6", "name": "Antrum ", "color": "#DBDF00", "shape": "bounding_box", "featureNodeHash": "7f3f3ed6"},
        {"id": "7", "name": "Incisura ", "color": "#A4DD00", "shape": "polygon", "featureNodeHash": "8dd583bb"},
        {"id": "8", "name": "D1", "color": "#68CCCA", "shape": "bounding_box", "featureNodeHash": "58bcccb6"},
        {"id": "9", "name": "D2", "color": "#73D8FF", "shape": "bounding_box", "featureNodeHash": "761eff9d"},
        {"id": "10", "name": "LES", "color": "#AEA1FF", "shape": "bounding_box", "featureNodeHash": "c01997bb"},
        {
            "id": "11",
            "name": "Pyloric opening ",
            "color": "#FCC400",
            "shape": "bounding_box",
            "featureNodeHash": "a96af107",
        },
        {"id": "12", "name": "Fundus ", "color": "#B0BC00", "shape": "bounding_box", "featureNodeHash": "f2870195"},
        {"id": "13", "name": "point", "color": "#68BC00", "shape": "point", "featureNodeHash": "d02c6e13"},
    ],
    "classifications": [
        {
            "id": "1",
            "featureNodeHash": "ebbaf6b6",
            "attributes": [
                {
                    "id": "1.1",
                    "name": "Stomach",
                    "type": "radio",
                    "featureNodeHash": "6e23d0b8",
                    "required": False,
                    "dynamic": False,
                    "options": [
                        {"id": "1.1.1", "label": "Fundus", "value": "fundus", "featureNodeHash": "a48fdc54"},
                        {"id": "1.1.2", "label": "Antrum ", "value": "antrum_", "featureNodeHash": "7103db43"},
                    ],
                }
            ],
        },
        {
            "id": "2",
            "featureNodeHash": "7d8b28e8",
            "attributes": [
                {
                    "id": "2.1",
                    "name": "Fundus ",
                    "type": "radio",
                    "featureNodeHash": "a179f3a2",
                    "required": False,
                    "dynamic": False,
                }
            ],
        },
        {
            "id": "3",
            "featureNodeHash": "7f14717c",
            "attributes": [
                {
                    "id": "3.1",
                    "name": "",
                    "type": "radio",
                    "featureNodeHash": "bcb6c6c6",
                    "required": False,
                    "dynamic": False,
                    "options": [
                        {"id": "3.1.1", "label": "Radio One", "value": "radio_one", "featureNodeHash": "b954d23c"},
                        {"id": "3.1.2", "label": "Radio Two", "value": "radio_two", "featureNodeHash": "a6400563"},
                    ],
                }
            ],
        },
    ],
}
