# Label row constants

LABELS = "labels"
OBJECTS = "objects"
CLASSIFICATIONS = "classifications"
OBJECT_HASH = "objectHash"
CLASSIFICATION_HASH = "classificationHash"
OBJECT_ANSWERS = "object_answers"
CLASSIFICATION_ANSWERS = "classification_answers"


# Labeling algorithm names
INTERPOLATION = "interpolation"


# Type of Cord API key
TYPE_PROJECT = "project"
TYPE_DATASET = "dataset"
TYPE_ONTOLOGY = "ontology"
