labels = {
    "label_hash": "003959e1-a63f-4e08-9f3c-916d1e807ed6",
    "branch_name": "main",
    "created_at": "Thu, 09 Feb 2023 14:12:03 UTC",
    "last_edited_at": "Thu, 09 Feb 2023 14:12:03 UTC",
    "data_hash": "aaa6bc82-9f89-4545-adbb-f271bf28cf99",
    "annotation_task_status": "QUEUED",
    "is_shadow_data": False,
    "dataset_hash": "b0d93919-a5e8-4418-8dd5-2c51e3977de8",
    "dataset_title": "Dataset with 2 frame video",
    "data_title": "two-frame-video.mp4",
    "data_type": "video",
    "data_units": {
        "cd57cf5c-2541-4a46-a836-444540ee987a": {
            "data_hash": "cd57cf5c-2541-4a46-a836-444540ee987a",
            "data_title": "two-frame-video.mp4",
            "data_type": "video/mp4",
            "data_sequence": 0,
            "labels": {
                "0": {
                    "objects": [
                        {
                            "name": "box",
                            "color": "#D33115",
                            "shape": "bounding_box",
                            "value": "box",
                            "createdAt": "Tue, 17 Jan 2023 17:23:10 UTC",
                            "createdBy": "denis@cord.tech",
                            "confidence": 1,
                            "objectHash": "0gCzNuLS",
                            "lastEditedAt": "Wed, 18 Jan 2023 17:23:24 UTC",
                            "featureHash": "LJNV5PVK",
                            "manualAnnotation": True,
                            "boundingBox": {"h": 0.1291, "w": 0.1296, "x": 0.4287, "y": 0.2615},
                        },
                        {
                            "name": "box 2",
                            "color": "#E27300",
                            "shape": "bounding_box",
                            "value": "box_2",
                            "createdAt": "Tue, 17 Jan 2023 17:23:36 UTC",
                            "createdBy": "denis@cord.tech",
                            "lastEditedAt": "Wed, 18 Jan 2023 17:23:26 UTC",
                            "confidence": 1,
                            "objectHash": "Wpc+TmG+",
                            "featureHash": "GaAKWvvg",
                            "manualAnnotation": True,
                            "boundingBox": {"h": 0.0926, "w": 0.0929, "x": 0.5637, "y": 0.5477},
                        },
                    ],
                    "classifications": [],
                },
                "1": {
                    "objects": [
                        {
                            "name": "box",
                            "color": "#D33115",
                            "shape": "bounding_box",
                            "value": "box",
                            "createdAt": "Tue, 17 Jan 2023 17:23:21 UTC",
                            "createdBy": "denis@cord.tech",
                            "isDeleted": False,
                            "confidence": 1,
                            "objectHash": "0gCzNuLS",
                            "featureHash": "LJNV5PVK",
                            "lastEditedAt": "Tue, 17 Jan 2023 17:23:22 UTC",
                            "lastEditedBy": "denis@cord.tech",
                            "manualAnnotation": True,
                            "boundingBox": {"h": 0.1291, "w": 0.1296, "x": 0.4449, "y": 0.2489},
                        },
                        {
                            "name": "box 2",
                            "color": "#E27300",
                            "shape": "bounding_box",
                            "value": "box_2",
                            "createdAt": "Tue, 17 Jan 2023 17:23:38 UTC",
                            "createdBy": "denis@cord.tech",
                            "isDeleted": False,
                            "confidence": 1,
                            "objectHash": "Wpc+TmG+",
                            "featureHash": "GaAKWvvg",
                            "lastEditedAt": "Tue, 17 Jan 2023 17:23:40 UTC",
                            "lastEditedBy": "denis@cord.tech",
                            "manualAnnotation": True,
                            "boundingBox": {"h": 0.0926, "w": 0.0929, "x": 0.5799, "y": 0.5505},
                        },
                    ],
                    "classifications": [],
                },
            },
            "data_fps": 25.0,
            "data_duration": 0.08,
            "data_link": "cord-videos-dev/lFW59RQ9jcT4vHZeG14m8QWJKug1/cd57cf5c-2541-4a46-a836-444540ee987a",
            "width": 1200,
            "height": 924,
        }
    },
    "object_answers": {
        "0gCzNuLS": {"objectHash": "0gCzNuLS", "classifications": []},
        "Wpc+TmG+": {"objectHash": "Wpc+TmG+", "classifications": []},
    },
    "classification_answers": {},
    "object_actions": {
        "0gCzNuLS": {
            "objectHash": "0gCzNuLS",
            "actions": [
                {
                    "name": "dynamic text",
                    "range": [[0, 0]],
                    "value": "dynamic_text",
                    "answers": "dynamic text",
                    "dynamic": True,
                    "trackHash": "fbb97dda-1e66-48f9-b749-af2f83dab9fc",
                    "featureHash": "5RGh3YIU",
                    "shouldPropagate": False,
                    "manualAnnotation": True,
                },
                {
                    "name": "dynamic classification",
                    "range": [[0, 0]],
                    "value": "dynamic_classification",
                    "answers": [{"name": "classification 1", "value": "classification_1", "featureHash": "aOQGJvce"}],
                    "dynamic": True,
                    "trackHash": "9b3e2e91-3c4a-45dd-a142-b9e53642f1c3",
                    "featureHash": "ZJoiBceM",
                    "shouldPropagate": False,
                    "manualAnnotation": True,
                },
                {
                    "name": "dynamic radio",
                    "range": [[0, 0]],
                    "value": "dynamic_radio",
                    "answers": [{"name": "radio 1", "value": "radio_1", "featureHash": "ps0dwXfI"}],
                    "dynamic": True,
                    "trackHash": "6c2e03f4-1450-48a3-8f9f-6761af3006a3",
                    "featureHash": "OMpf1zPf",
                    "shouldPropagate": False,
                    "manualAnnotation": True,
                },
                {
                    "name": "dynamic text",
                    "range": [[1, 1]],
                    "value": "dynamic_text",
                    "answers": "dynamic text next frame",
                    "dynamic": True,
                    "trackHash": "e138b677-03d5-48f6-a4d7-806964e60339",
                    "featureHash": "5RGh3YIU",
                    "shouldPropagate": False,
                    "manualAnnotation": True,
                },
                {
                    "name": "dynamic radio",
                    "range": [[1, 1]],
                    "value": "dynamic_radio",
                    "answers": [{"name": "radio 2", "value": "radio_2", "featureHash": "IwCHSdeL"}],
                    "dynamic": True,
                    "trackHash": "05dc3b48-19fc-402b-8323-301ca52f410c",
                    "featureHash": "OMpf1zPf",
                    "shouldPropagate": False,
                    "manualAnnotation": True,
                },
                {
                    "name": "dynamic classification",
                    "range": [[1, 1]],
                    "value": "dynamic_classification",
                    "answers": [
                        {"name": "classification 2", "value": "classification_2", "featureHash": "tyjScPrk"},
                        {"name": "classification 1", "value": "classification_1", "featureHash": "aOQGJvce"},
                    ],
                    "dynamic": True,
                    "trackHash": "69b2a3d0-3db4-41d9-ba2a-d200aecd3d23",
                    "featureHash": "ZJoiBceM",
                    "shouldPropagate": False,
                    "manualAnnotation": True,
                },
            ],
        },
        "Wpc+TmG+": {
            "objectHash": "Wpc+TmG+",
            "actions": [
                {
                    "name": "radio 2",
                    "range": [[1, 1]],
                    "value": "radio_2",
                    "answers": [{"name": "radio 2 2", "value": "radio_2_2", "featureHash": "J/I/karX"}],
                    "dynamic": True,
                    "trackHash": "2e21dbab-e3b3-4a39-8fd2-def4c7745b4f",
                    "featureHash": "TWPByH4G",
                    "shouldPropagate": False,
                    "manualAnnotation": True,
                }
            ],
        },
    },
    "label_status": "LABEL_IN_PROGRESS",
}
