import datetime
from typing import Dict, List
from uuid import UUID

LABELS_LIST: List[Dict] = [
    {
        "label_hash": "f29b9eeb-23d0-43ae-adfd-70618072e5fe",
        "created_at": datetime.datetime(2023, 12, 1, 10, 29, 57, 901639, tzinfo=datetime.timezone.utc),
        "last_edited_at": datetime.datetime(2023, 12, 1, 10, 40, 52, 936914, tzinfo=datetime.timezone.utc),
        "dataset_hash": "682ab35e-adcb-4502-bd3e-18500dfaace6",
        "dataset_title": "COCO - export dataset",
        "data_title": "dicom",
        "data_hash": "87ffc8da-f005-45a3-b89f-e6086bd90fa7",
        "data_type": "dicom",
        "is_image_sequence": None,
        "video_link": None,
        "data_units": {
            "87ffc8da-f005-45a3-b89f-e6086bd90fa7": {
                "data_hash": "87ffc8da-f005-45a3-b89f-e6086bd90fa7",
                "data_title": "dicom",
                "data_type": "application/dicom",
                "data_sequence": 0,
                "labels": {
                    "0": {
                        "objects": [
                            {
                                "featureHash": "ImO9dtQh",
                                "objectHash": "R7OjJwum",
                                "name": "box",
                                "value": "box",
                                "color": "#D33115",
                                "shape": "bounding_box",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:30:02 GMT",
                                "manualAnnotation": True,
                                "boundingBox": {"x": 0.2396, "y": 0.1736, "w": 0.1012, "h": 0.1299},
                            },
                            {
                                "featureHash": "NBMDpwcd",
                                "objectHash": "aKjphpff",
                                "name": "rotatable box",
                                "value": "rotatable_box",
                                "color": "#E27300",
                                "shape": "rotatable_bounding_box",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:30:04 GMT",
                                "lastEditedBy": "adam@encord.com",
                                "lastEditedAt": "Fri, 01 Dec 2023 10:30:05 GMT",
                                "manualAnnotation": True,
                                "rotatableBoundingBox": {
                                    "x": 0.4249,
                                    "y": 0.1938,
                                    "w": 0.0895,
                                    "h": 0.1001,
                                    "theta": 19.2854,
                                },
                            },
                            {
                                "featureHash": "gr3562OV",
                                "objectHash": "4xsGCIXj",
                                "name": "polygon",
                                "value": "polygon",
                                "color": "#16406C",
                                "shape": "polygon",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:37:00 GMT",
                                "polygon": {
                                    "0": {"x": 0.5984, "y": 0.2387},
                                    "1": {"x": 0.564, "y": 0.3065},
                                    "2": {"x": 0.6775, "y": 0.309},
                                    "3": {"x": 0.642, "y": 0.25},
                                    "4": {"x": 0.6256, "y": 0.2602},
                                },
                                "manualAnnotation": True,
                            },
                            {
                                "featureHash": "SKRR+bNg",
                                "objectHash": "Gjx8EgkI",
                                "name": "polyline",
                                "value": "polyline",
                                "color": "#FE9200",
                                "shape": "polyline",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:37:05 GMT",
                                "polyline": {
                                    "0": {"x": 0.3924, "y": 0.3455},
                                    "1": {"x": 0.3755, "y": 0.4046},
                                    "2": {"x": 0.4725, "y": 0.458},
                                    "3": {"x": 0.5301, "y": 0.3974},
                                    "4": {"x": 0.4993, "y": 0.3599},
                                    "5": {"x": 0.4443, "y": 0.345},
                                },
                                "manualAnnotation": True,
                            },
                            {
                                "featureHash": "hN0/lF+8",
                                "objectHash": "2gjDymr4",
                                "name": "bitmask",
                                "value": "bitmask",
                                "color": "#FCDC00",
                                "shape": "bitmask",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:37:09 GMT",
                                "bitmask": {
                                    "rleString": "QUc39d?5M2M3N2N2N101l@J[>7bAOZ>n0N1N3N1O1O0O2O001O001O01O00001O0O2O001O1N2O2M2N2N2N2N3K6K5J7I6EiZh3",
                                    "top": 0,
                                    "left": 0,
                                    "width": 512,
                                    "height": 512,
                                },
                                "manualAnnotation": True,
                            },
                            {
                                "featureHash": "bhkdPLGR",
                                "objectHash": "/bxlR5g2",
                                "name": "keypoint",
                                "value": "keypoint",
                                "color": "#DBDF00",
                                "shape": "point",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:37:12 GMT",
                                "point": {"0": {"x": 0.4993, "y": 0.4996}},
                                "manualAnnotation": True,
                            },
                            {
                                "featureHash": "68gUGGu7",
                                "objectHash": "g2H23XHg",
                                "name": "skeleton",
                                "value": "skeleton",
                                "color": "#A4DD00",
                                "shape": "skeleton",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:37:14 GMT",
                                "skeleton": {
                                    "0": {
                                        "x": 0.426,
                                        "y": 0.6347,
                                        "name": "point_0",
                                        "color": "#000000",
                                        "value": "point_0",
                                        "featureHash": "A1LNYvDC",
                                        "invisible": True,
                                    },
                                    "1": {
                                        "x": 0.3986,
                                        "y": 0.6109,
                                        "name": "point_1",
                                        "color": "#000000",
                                        "value": "point_1",
                                        "featureHash": "Ld3dbiBd",
                                        "occluded": True,
                                    },
                                    "2": {
                                        "x": 0.3609,
                                        "y": 0.6364,
                                        "name": "point_2",
                                        "color": "#000000",
                                        "value": "point_2",
                                        "featureHash": "yUixMqk3",
                                    },
                                    "3": {
                                        "x": 0.3989,
                                        "y": 0.5832,
                                        "name": "point_3",
                                        "color": "#000000",
                                        "value": "point_3",
                                        "featureHash": "sAMAlWjC",
                                    },
                                    "4": {
                                        "x": 0.4275,
                                        "y": 0.5938,
                                        "name": "point_4",
                                        "color": "#000000",
                                        "value": "point_4",
                                        "featureHash": "lVG9gScy",
                                    },
                                    "5": {
                                        "x": 0.3515,
                                        "y": 0.5909,
                                        "name": "point_5",
                                        "color": "#000000",
                                        "value": "point_5",
                                        "featureHash": "jKtJ9nSZ",
                                    },
                                    "6": {
                                        "x": 0.397,
                                        "y": 0.5624,
                                        "name": "point_6",
                                        "color": "#000000",
                                        "value": "point_6",
                                        "featureHash": "XTl9TVhz",
                                        "invisible": True,
                                        "visible": False,
                                        "occluded": False,
                                    },
                                },
                                "lastEditedBy": "adam@encord.com",
                                "lastEditedAt": "Fri, 01 Dec 2023 10:40:12 GMT",
                                "manualAnnotation": True,
                            },
                        ],
                        "classifications": [
                            {
                                "featureHash": "R3daKWYA",
                                "classificationHash": "4XKkAkEU",
                                "name": "radio",
                                "value": "radio",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:37:25 GMT",
                                "lastEditedAt": "Fri, 01 Dec 2023 10:37:25 GMT",
                                "manualAnnotation": True,
                            },
                            {
                                "featureHash": "is0CLEV9",
                                "classificationHash": "49BSB0GZ",
                                "name": "checklist",
                                "value": "checklist",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:37:29 GMT",
                                "lastEditedAt": "Fri, 01 Dec 2023 10:37:29 GMT",
                                "manualAnnotation": True,
                            },
                            {
                                "featureHash": "NW40sdPd",
                                "classificationHash": "x8HlsBZw",
                                "name": "text",
                                "value": "text",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:37:33 GMT",
                                "lastEditedAt": "Fri, 01 Dec 2023 10:37:33 GMT",
                                "manualAnnotation": True,
                            },
                        ],
                        "metadata": {
                            "dicom_instance_uid": "1.3.6.1.4.1.5962.99.1.1761388472.1291962045.1616669124536.2802.0",
                            "multiframe_frame_number": None,
                            "file_uri": "cord-dicoms-dev/fOG7LpSlbyVNLFE1tKOFN1GMOBE2/851fecfe-34cc-4b1e-b40c-35ed7b028668",
                            "width": 512,
                            "height": 512,
                        },
                    },
                    "1": {"objects": [], "classifications": []},
                },
                "metadata": {
                    "patient_id": "NOID",
                    "study_uid": "1.3.6.1.4.1.5962.99.1.1761388472.1291962045.1616669124536.2592.0",
                    "series_uid": "1.3.6.1.4.1.5962.99.1.1761388472.1291962045.1616669124536.2702.0",
                },
                "data_links": ["cord-dicoms-dev/fOG7LpSlbyVNLFE1tKOFN1GMOBE2/851fecfe-34cc-4b1e-b40c-35ed7b028668"],
                "width": 512,
                "height": 512,
            }
        },
        "object_answers": {
            "R7OjJwum": {
                "objectHash": "R7OjJwum",
                "classifications": [
                    {
                        "name": "box text",
                        "value": "box_text",
                        "answers": "wfwfwfw",
                        "featureHash": "E6Wai5ZG",
                        "manualAnnotation": True,
                    }
                ],
            },
            "aKjphpff": {
                "objectHash": "aKjphpff",
                "classifications": [
                    {
                        "name": "rotatable box radio",
                        "value": "rotatable_box_radio",
                        "answers": [
                            {
                                "name": "rotatable box radio option 0",
                                "value": "rotatable_box_radio_option_0",
                                "featureHash": "SIEdjcuH",
                            }
                        ],
                        "featureHash": "LCek15f3",
                        "manualAnnotation": True,
                    }
                ],
            },
            "4xsGCIXj": {"objectHash": "4xsGCIXj", "classifications": []},
            "Gjx8EgkI": {"objectHash": "Gjx8EgkI", "classifications": []},
            "2gjDymr4": {"objectHash": "2gjDymr4", "classifications": []},
            "/bxlR5g2": {"objectHash": "/bxlR5g2", "classifications": []},
            "g2H23XHg": {"objectHash": "g2H23XHg", "classifications": []},
        },
        "classification_answers": {
            "4XKkAkEU": {
                "classificationHash": "4XKkAkEU",
                "classifications": [
                    {
                        "name": "radio nested text",
                        "value": "radio_nested_text",
                        "answers": "5ggerg",
                        "featureHash": "tY6bNKl3",
                        "manualAnnotation": True,
                    },
                    {
                        "name": "radio nested checklist",
                        "value": "radio_nested_checklist",
                        "answers": [{"name": "opt 0", "value": "opt_0", "featureHash": "6n60OH3Q"}],
                        "featureHash": "JE/BiaGw",
                        "manualAnnotation": True,
                    },
                    {
                        "name": "radio nested radio",
                        "value": "radio_nested_radio",
                        "answers": [{"name": "opt 0", "value": "opt_0", "featureHash": "z29i8QS0"}],
                        "featureHash": "MVDBTicG",
                        "manualAnnotation": True,
                    },
                    {
                        "name": "radio",
                        "value": "radio",
                        "answers": [{"name": "radio 1", "value": "radio_1", "featureHash": "gxCMit/w"}],
                        "featureHash": "s+3ehT7T",
                        "manualAnnotation": True,
                    },
                ],
            },
            "49BSB0GZ": {
                "classificationHash": "49BSB0GZ",
                "classifications": [
                    {
                        "name": "checklist",
                        "value": "checklist",
                        "answers": [{"name": "checklist 0", "value": "checklist_0", "featureHash": "Irh8Wgjq"}],
                        "featureHash": "YtqQrGVm",
                        "manualAnnotation": True,
                    }
                ],
            },
            "x8HlsBZw": {
                "classificationHash": "x8HlsBZw",
                "classifications": [
                    {
                        "name": "text",
                        "value": "text",
                        "answers": "egegeg",
                        "featureHash": "hBo6zZds",
                        "manualAnnotation": True,
                    }
                ],
            },
        },
        "object_actions": {
            "R7OjJwum": {
                "objectHash": "R7OjJwum",
                "actions": [
                    {
                        "name": "box checklist",
                        "range": [[0, 0]],
                        "value": "box_checklist",
                        "answers": [
                            {"name": "box checklist", "value": "box_checklist_option_1", "featureHash": "teq8aIDY"}
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "UHclwXeD",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    },
                    {
                        "name": "box checklist",
                        "range": [[0, 0]],
                        "value": "box_checklist",
                        "answers": [
                            {"name": "box checklist", "value": "box_checklist_option_0", "featureHash": "lBbzV4El"}
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "UHclwXeD",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    },
                    {
                        "name": "box radio",
                        "range": [[0, 0]],
                        "value": "box_radio",
                        "answers": [{"name": "box radio", "value": "box_radio_option_0", "featureHash": "pCZJZTnj"}],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "u+4bIbCR",
                        "shouldPropagate": True,
                        "manualAnnotation": True,
                    },
                ],
            },
            "4xsGCIXj": {
                "objectHash": "4xsGCIXj",
                "actions": [
                    {
                        "name": "polygon checklist",
                        "range": [[0, 0]],
                        "value": "polygon_checklist",
                        "answers": [
                            {
                                "name": "polygon checklist option 0",
                                "value": "polygon_checklist_option_0",
                                "featureHash": "8kDCDHWL",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "PhRGDJdU",
                        "shouldPropagate": True,
                        "manualAnnotation": True,
                    },
                    {
                        "name": "polygon checklist",
                        "range": [[0, 0]],
                        "value": "polygon_checklist",
                        "answers": [
                            {
                                "name": "polygon checklist option 1",
                                "value": "polygon_checklist_option_1",
                                "featureHash": "sj7I7lsB",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "PhRGDJdU",
                        "shouldPropagate": True,
                        "manualAnnotation": True,
                    },
                ],
            },
            "Gjx8EgkI": {
                "objectHash": "Gjx8EgkI",
                "actions": [
                    {
                        "name": "polygon text",
                        "range": [[0, 0]],
                        "value": "polygon_text",
                        "answers": "fwfwe",
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "8wiMXlVz",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
            "/bxlR5g2": {
                "objectHash": "/bxlR5g2",
                "actions": [
                    {
                        "name": "keypoint text",
                        "range": [[0, 0]],
                        "value": "keypoint_text",
                        "answers": "gergg",
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "73XckWFd",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
            "g2H23XHg": {
                "objectHash": "g2H23XHg",
                "actions": [
                    {
                        "name": "skeleton checklist",
                        "range": [[0, 0]],
                        "value": "skeleton_checklist",
                        "answers": [
                            {
                                "name": "skeleton checklist",
                                "value": "skeleton_checklist_option_0",
                                "featureHash": "qL8VXCXm",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "51k+sOtO",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
        },
        "label_status": "LABEL_IN_PROGRESS",
        "export_history": [
            {
                "export_hash": UUID("c4e34ce6-d2e1-4e0b-9ef0-81a7c3232dae"),
                "exported_at": "Fri, 01 Dec 2023 11:18:10 UTC",
                "user_email": "adam@encord.com",
            },
            {
                "export_hash": UUID("aedeaa87-ac76-4faa-b73b-72f3b282e66a"),
                "exported_at": "Fri, 01 Dec 2023 11:17:24 UTC",
                "user_email": "adam@encord.com",
            },
        ],
        "export_hash": UUID("c4e34ce6-d2e1-4e0b-9ef0-81a7c3232dae"),
        "exported_at": "Fri, 01 Dec 2023 11:18:10 UTC",
    },
    {
        "label_hash": "542f8da4-553b-452a-87de-9c80df2bdab4",
        "created_at": datetime.datetime(2023, 12, 1, 10, 45, 19, 856278, tzinfo=datetime.timezone.utc),
        "last_edited_at": datetime.datetime(2023, 12, 1, 11, 6, 48, 272401, tzinfo=datetime.timezone.utc),
        "dataset_hash": "682ab35e-adcb-4502-bd3e-18500dfaace6",
        "dataset_title": "COCO - export dataset",
        "data_title": "image-sequence",
        "data_hash": "96f3385a-8009-426b-8d26-6085fa39c76d",
        "data_type": "img_group",
        "is_image_sequence": True,
        "video_link": "cord-videos-dev/fOG7LpSlbyVNLFE1tKOFN1GMOBE2/image-sequence-6feec2f5.mp4",
        "data_units": {
            "c7c18bd0-bf07-4f5b-a8a8-f402b346097a": {
                "data_hash": "c7c18bd0-bf07-4f5b-a8a8-f402b346097a",
                "data_title": "1.png",
                "data_link": "cord-images-dev/fOG7LpSlbyVNLFE1tKOFN1GMOBE2/e7a67a81-af54-4d6b-9838-ff11bba0d95c",
                "data_type": "image/png",
                "data_sequence": 0,
                "width": 400,
                "height": 400,
                "labels": {
                    "objects": [
                        {
                            "featureHash": "ImO9dtQh",
                            "objectHash": "Or2a460b",
                            "name": "box",
                            "value": "box",
                            "color": "#D33115",
                            "shape": "bounding_box",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:45:38 GMT",
                            "manualAnnotation": True,
                            "boundingBox": {"x": 0.0449, "y": 0.1913, "w": 0.1165, "h": 0.129},
                        },
                        {
                            "featureHash": "NBMDpwcd",
                            "objectHash": "EZ89BXK+",
                            "name": "rotatable box",
                            "value": "rotatable_box",
                            "color": "#E27300",
                            "shape": "rotatable_bounding_box",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:45:40 GMT",
                            "lastEditedBy": "adam@encord.com",
                            "lastEditedAt": "Fri, 01 Dec 2023 10:45:40 GMT",
                            "manualAnnotation": True,
                            "rotatableBoundingBox": {
                                "x": 0.2363,
                                "y": 0.1913,
                                "w": 0.0804,
                                "h": 0.1276,
                                "theta": 16.6182,
                            },
                        },
                        {
                            "featureHash": "gr3562OV",
                            "objectHash": "K9lwknkQ",
                            "name": "polygon",
                            "value": "polygon",
                            "color": "#16406C",
                            "shape": "polygon",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:45:44 GMT",
                            "polygon": {
                                "0": {"x": 0.4443, "y": 0.1941},
                                "1": {"x": 0.3708, "y": 0.2426},
                                "2": {"x": 0.3708, "y": 0.3134},
                                "3": {"x": 0.4277, "y": 0.33},
                                "4": {"x": 0.461, "y": 0.2523},
                                "5": {"x": 0.4665, "y": 0.2149},
                            },
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "SKRR+bNg",
                            "objectHash": "EoZuR/9p",
                            "name": "polyline",
                            "value": "polyline",
                            "color": "#FE9200",
                            "shape": "polyline",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:45:47 GMT",
                            "polyline": {
                                "0": {"x": 0.5262, "y": 0.2066},
                                "1": {"x": 0.5053, "y": 0.2829},
                                "2": {"x": 0.5123, "y": 0.3286},
                                "3": {"x": 0.5622, "y": 0.3633},
                                "4": {"x": 0.6163, "y": 0.3494},
                                "5": {"x": 0.6246, "y": 0.4105},
                                "6": {"x": 0.5858, "y": 0.4465},
                            },
                            "lastEditedBy": "adam@encord.com",
                            "lastEditedAt": "Fri, 01 Dec 2023 10:46:57 GMT",
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "hN0/lF+8",
                            "objectHash": "6kA+Tvfx",
                            "name": "bitmask",
                            "value": "bitmask",
                            "color": "#FCDC00",
                            "shape": "bitmask",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:45:50 GMT",
                            "bitmask": {
                                "rleString": "nSo0:T<4L4N1M3O1N1O2O001N100000001O0000000010O01O001O1O010O0010O0010O0010O001O010O001O1O01O01O000000000000000000O1000O10000000000000000000001N10001N2O0O2N2N3L4M3KZXn2",
                                "top": 0,
                                "left": 0,
                                "width": 400,
                                "height": 400,
                            },
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "bhkdPLGR",
                            "objectHash": "nyOrUeAW",
                            "name": "keypoint",
                            "value": "keypoint",
                            "color": "#DBDF00",
                            "shape": "point",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:45:52 GMT",
                            "point": {"0": {"x": 0.8202, "y": 0.2288}},
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "68gUGGu7",
                            "objectHash": "WrYyw+oP",
                            "name": "skeleton",
                            "value": "skeleton",
                            "color": "#A4DD00",
                            "shape": "skeleton",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:45:55 GMT",
                            "skeleton": {
                                "0": {
                                    "x": 0.8957,
                                    "y": 0.3768,
                                    "name": "point_0",
                                    "color": "#000000",
                                    "value": "point_0",
                                    "featureHash": "A1LNYvDC",
                                },
                                "1": {
                                    "x": 0.8697,
                                    "y": 0.334,
                                    "name": "point_1",
                                    "color": "#000000",
                                    "value": "point_1",
                                    "featureHash": "Ld3dbiBd",
                                },
                                "2": {
                                    "x": 0.834,
                                    "y": 0.3798,
                                    "name": "point_2",
                                    "color": "#000000",
                                    "value": "point_2",
                                    "featureHash": "yUixMqk3",
                                },
                                "3": {
                                    "x": 0.8701,
                                    "y": 0.2842,
                                    "name": "point_3",
                                    "color": "#000000",
                                    "value": "point_3",
                                    "featureHash": "sAMAlWjC",
                                },
                                "4": {
                                    "x": 0.8972,
                                    "y": 0.3033,
                                    "name": "point_4",
                                    "color": "#000000",
                                    "value": "point_4",
                                    "featureHash": "lVG9gScy",
                                },
                                "5": {
                                    "x": 0.8251,
                                    "y": 0.298,
                                    "name": "point_5",
                                    "color": "#000000",
                                    "value": "point_5",
                                    "featureHash": "jKtJ9nSZ",
                                },
                                "6": {
                                    "x": 0.8682,
                                    "y": 0.2467,
                                    "name": "point_6",
                                    "color": "#000000",
                                    "value": "point_6",
                                    "featureHash": "XTl9TVhz",
                                },
                            },
                            "manualAnnotation": True,
                        },
                    ],
                    "classifications": [
                        {
                            "featureHash": "R3daKWYA",
                            "classificationHash": "5IVfSbtu",
                            "name": "radio",
                            "value": "radio",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:46:02 GMT",
                            "lastEditedAt": "Fri, 01 Dec 2023 10:46:02 GMT",
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "is0CLEV9",
                            "classificationHash": "6joN7GfG",
                            "name": "checklist",
                            "value": "checklist",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:46:05 GMT",
                            "lastEditedAt": "Fri, 01 Dec 2023 10:46:05 GMT",
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "NW40sdPd",
                            "classificationHash": "73JLqScv",
                            "name": "text",
                            "value": "text",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:46:07 GMT",
                            "lastEditedAt": "Fri, 01 Dec 2023 10:46:07 GMT",
                            "manualAnnotation": True,
                        },
                    ],
                },
            },
            "839d6a14-a063-494a-96e5-3cb46124158e": {
                "data_hash": "839d6a14-a063-494a-96e5-3cb46124158e",
                "data_title": "2.png",
                "data_link": "cord-images-dev/fOG7LpSlbyVNLFE1tKOFN1GMOBE2/576558d7-b111-4f5d-939e-81c3d99a236a",
                "data_type": "image/png",
                "data_sequence": 1,
                "width": 400,
                "height": 400,
                "labels": {
                    "classifications": [
                        {
                            "featureHash": "R3daKWYA",
                            "classificationHash": "5IVfSbtu",
                            "name": "radio",
                            "value": "radio",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:46:02 GMT",
                            "lastEditedAt": "Fri, 01 Dec 2023 10:46:02 GMT",
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "is0CLEV9",
                            "classificationHash": "6joN7GfG",
                            "name": "checklist",
                            "value": "checklist",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:46:05 GMT",
                            "lastEditedAt": "Fri, 01 Dec 2023 10:46:05 GMT",
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "NW40sdPd",
                            "classificationHash": "73JLqScv",
                            "name": "text",
                            "value": "text",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:46:07 GMT",
                            "lastEditedAt": "Fri, 01 Dec 2023 10:46:07 GMT",
                            "manualAnnotation": True,
                        },
                    ],
                    "objects": [
                        {
                            "featureHash": "ImO9dtQh",
                            "objectHash": "RUlxBBGp",
                            "name": "box",
                            "value": "box",
                            "color": "#D33115",
                            "shape": "bounding_box",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:47:06 GMT",
                            "manualAnnotation": True,
                            "boundingBox": {"x": 0.0726, "y": 0.3467, "w": 0.0749, "h": 0.0929},
                        },
                        {
                            "featureHash": "NBMDpwcd",
                            "objectHash": "KwpUEmos",
                            "name": "rotatable box",
                            "value": "rotatable_box",
                            "color": "#E27300",
                            "shape": "rotatable_bounding_box",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:47:07 GMT",
                            "lastEditedBy": "adam@encord.com",
                            "lastEditedAt": "Fri, 01 Dec 2023 10:47:08 GMT",
                            "manualAnnotation": True,
                            "rotatableBoundingBox": {
                                "x": 0.2515,
                                "y": 0.3591,
                                "w": 0.0555,
                                "h": 0.0638,
                                "theta": 15.0434,
                            },
                        },
                        {
                            "featureHash": "gr3562OV",
                            "objectHash": "Aya79dpB",
                            "name": "polygon",
                            "value": "polygon",
                            "color": "#16406C",
                            "shape": "polygon",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:47:10 GMT",
                            "polygon": {
                                "0": {"x": 0.4443, "y": 0.3689},
                                "1": {"x": 0.3694, "y": 0.4756},
                                "2": {"x": 0.436, "y": 0.5186},
                                "3": {"x": 0.5539, "y": 0.4659},
                            },
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "SKRR+bNg",
                            "objectHash": "Zy5PjiQu",
                            "name": "polyline",
                            "value": "polyline",
                            "color": "#FE9200",
                            "shape": "polyline",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:47:13 GMT",
                            "polyline": {
                                "0": {"x": 0.7259, "y": 0.391},
                                "1": {"x": 0.6191, "y": 0.5117},
                                "2": {"x": 0.6343, "y": 0.5464},
                                "3": {"x": 0.7078, "y": 0.6074},
                                "4": {"x": 0.7273, "y": 0.5603},
                                "5": {"x": 0.7217, "y": 0.5297},
                            },
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "hN0/lF+8",
                            "objectHash": "1oSpiaDM",
                            "name": "bitmask",
                            "value": "bitmask",
                            "color": "#FCDC00",
                            "shape": "bitmask",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:47:15 GMT",
                            "bitmask": {
                                "rleString": "ePn1;S<4L4N0O2N2N2O1N2O1O1N101O001O001O010O0001O001O100O1O1O00001O01O000000000000010O00000000001O00001O01O01O01O0001O01O000O101O001N101N2N2N2N3M3L`_R2",
                                "top": 0,
                                "left": 0,
                                "width": 400,
                                "height": 400,
                            },
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "bhkdPLGR",
                            "objectHash": "3lLDdvLz",
                            "name": "keypoint",
                            "value": "keypoint",
                            "color": "#DBDF00",
                            "shape": "point",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:47:17 GMT",
                            "point": {"0": {"x": 0.9006, "y": 0.4535}},
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "68gUGGu7",
                            "objectHash": "8M1VEyNi",
                            "name": "skeleton",
                            "value": "skeleton",
                            "color": "#A4DD00",
                            "shape": "skeleton",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:47:29 GMT",
                            "skeleton": {
                                "0": {
                                    "x": 0.9663,
                                    "y": 0.6885,
                                    "name": "point_0",
                                    "color": "#000000",
                                    "value": "point_0",
                                    "featureHash": "A1LNYvDC",
                                },
                                "1": {
                                    "x": 0.9258,
                                    "y": 0.6533,
                                    "name": "point_1",
                                    "color": "#000000",
                                    "value": "point_1",
                                    "featureHash": "Ld3dbiBd",
                                },
                                "2": {
                                    "x": 0.8702,
                                    "y": 0.6909,
                                    "name": "point_2",
                                    "color": "#000000",
                                    "value": "point_2",
                                    "featureHash": "yUixMqk3",
                                },
                                "3": {
                                    "x": 0.9263,
                                    "y": 0.6122,
                                    "name": "point_3",
                                    "color": "#000000",
                                    "value": "point_3",
                                    "featureHash": "sAMAlWjC",
                                },
                                "4": {
                                    "x": 0.9686,
                                    "y": 0.628,
                                    "name": "point_4",
                                    "color": "#000000",
                                    "value": "point_4",
                                    "featureHash": "lVG9gScy",
                                },
                                "5": {
                                    "x": 0.8563,
                                    "y": 0.6236,
                                    "name": "point_5",
                                    "color": "#000000",
                                    "value": "point_5",
                                    "featureHash": "jKtJ9nSZ",
                                },
                                "6": {
                                    "x": 0.9234,
                                    "y": 0.5813,
                                    "name": "point_6",
                                    "color": "#000000",
                                    "value": "point_6",
                                    "featureHash": "XTl9TVhz",
                                },
                            },
                            "lastEditedBy": "adam@encord.com",
                            "lastEditedAt": "Fri, 01 Dec 2023 10:47:32 GMT",
                            "manualAnnotation": True,
                        },
                    ],
                },
            },
        },
        "object_answers": {
            "Or2a460b": {
                "objectHash": "Or2a460b",
                "classifications": [
                    {
                        "name": "box text",
                        "value": "box_text",
                        "answers": "wefwfw",
                        "featureHash": "E6Wai5ZG",
                        "manualAnnotation": True,
                    }
                ],
            },
            "EZ89BXK+": {
                "objectHash": "EZ89BXK+",
                "classifications": [
                    {
                        "name": "rotatable box radio",
                        "value": "rotatable_box_radio",
                        "answers": [
                            {
                                "name": "rotatable box radio option 0",
                                "value": "rotatable_box_radio_option_0",
                                "featureHash": "SIEdjcuH",
                            }
                        ],
                        "featureHash": "LCek15f3",
                        "manualAnnotation": True,
                    }
                ],
            },
            "K9lwknkQ": {"objectHash": "K9lwknkQ", "classifications": []},
            "EoZuR/9p": {"objectHash": "EoZuR/9p", "classifications": []},
            "6kA+Tvfx": {"objectHash": "6kA+Tvfx", "classifications": []},
            "nyOrUeAW": {"objectHash": "nyOrUeAW", "classifications": []},
            "WrYyw+oP": {"objectHash": "WrYyw+oP", "classifications": []},
            "RUlxBBGp": {
                "objectHash": "RUlxBBGp",
                "classifications": [
                    {
                        "name": "box text",
                        "value": "box_text",
                        "answers": "erge",
                        "featureHash": "E6Wai5ZG",
                        "manualAnnotation": True,
                    }
                ],
            },
            "KwpUEmos": {
                "objectHash": "KwpUEmos",
                "classifications": [
                    {
                        "name": "rotatable box radio",
                        "value": "rotatable_box_radio",
                        "answers": [
                            {
                                "name": "rotatable box radio option 0",
                                "value": "rotatable_box_radio_option_0",
                                "featureHash": "SIEdjcuH",
                            }
                        ],
                        "featureHash": "LCek15f3",
                        "manualAnnotation": True,
                    }
                ],
            },
            "Aya79dpB": {"objectHash": "Aya79dpB", "classifications": []},
            "Zy5PjiQu": {"objectHash": "Zy5PjiQu", "classifications": []},
            "1oSpiaDM": {"objectHash": "1oSpiaDM", "classifications": []},
            "3lLDdvLz": {"objectHash": "3lLDdvLz", "classifications": []},
            "8M1VEyNi": {"objectHash": "8M1VEyNi", "classifications": []},
        },
        "classification_answers": {
            "5IVfSbtu": {
                "classificationHash": "5IVfSbtu",
                "classifications": [
                    {
                        "name": "radio",
                        "value": "radio",
                        "answers": [{"name": "radio 0", "value": "radio_0", "featureHash": "jBISfIky"}],
                        "featureHash": "s+3ehT7T",
                        "manualAnnotation": True,
                    }
                ],
            },
            "6joN7GfG": {
                "classificationHash": "6joN7GfG",
                "classifications": [
                    {
                        "name": "checklist",
                        "value": "checklist",
                        "answers": [{"name": "checklist 0", "value": "checklist_0", "featureHash": "Irh8Wgjq"}],
                        "featureHash": "YtqQrGVm",
                        "manualAnnotation": True,
                    }
                ],
            },
            "73JLqScv": {
                "classificationHash": "73JLqScv",
                "classifications": [
                    {
                        "name": "text",
                        "value": "text",
                        "answers": "rthrth",
                        "featureHash": "hBo6zZds",
                        "manualAnnotation": True,
                    }
                ],
            },
        },
        "object_actions": {
            "Or2a460b": {
                "objectHash": "Or2a460b",
                "actions": [
                    {
                        "name": "box checklist",
                        "range": [[0, 0]],
                        "value": "box_checklist",
                        "answers": [
                            {"name": "box checklist", "value": "box_checklist_option_1", "featureHash": "teq8aIDY"}
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "UHclwXeD",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    },
                    {
                        "name": "box radio",
                        "range": [[0, 0]],
                        "value": "box_radio",
                        "answers": [{"name": "box radio", "value": "box_radio_option_0", "featureHash": "pCZJZTnj"}],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "u+4bIbCR",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    },
                ],
            },
            "K9lwknkQ": {
                "objectHash": "K9lwknkQ",
                "actions": [
                    {
                        "name": "polygon checklist",
                        "range": [[0, 0]],
                        "value": "polygon_checklist",
                        "answers": [
                            {
                                "name": "polygon checklist",
                                "value": "polygon_checklist_option_0",
                                "featureHash": "8kDCDHWL",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "PhRGDJdU",
                        "shouldPropagate": True,
                        "manualAnnotation": True,
                    },
                    {
                        "name": "polygon checklist",
                        "range": [[0, 0]],
                        "value": "polygon_checklist",
                        "answers": [
                            {
                                "name": "polygon checklist",
                                "value": "polygon_checklist_option_1",
                                "featureHash": "sj7I7lsB",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "PhRGDJdU",
                        "shouldPropagate": True,
                        "manualAnnotation": True,
                    },
                ],
            },
            "EoZuR/9p": {
                "objectHash": "EoZuR/9p",
                "actions": [
                    {
                        "name": "polygon text",
                        "range": [[0, 0]],
                        "value": "polygon_text",
                        "answers": "fwfwef",
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "8wiMXlVz",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
            "6kA+Tvfx": {
                "objectHash": "6kA+Tvfx",
                "actions": [
                    {
                        "name": "bitmask radio",
                        "range": [[0, 0]],
                        "value": "bitmask_radio",
                        "answers": [
                            {"name": "bitmask radio", "value": "bitmask_radio_option_1", "featureHash": "a9ZztiRl"}
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "7tC1hS87",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
            "WrYyw+oP": {
                "objectHash": "WrYyw+oP",
                "actions": [
                    {
                        "name": "skeleton checklist",
                        "range": [[0, 0]],
                        "value": "skeleton_checklist",
                        "answers": [
                            {
                                "name": "skeleton checklist",
                                "value": "skeleton_checklist_option_0",
                                "featureHash": "qL8VXCXm",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "51k+sOtO",
                        "shouldPropagate": True,
                        "manualAnnotation": True,
                    },
                    {
                        "name": "skeleton checklist",
                        "range": [[0, 0]],
                        "value": "skeleton_checklist",
                        "answers": [
                            {
                                "name": "skeleton checklist",
                                "value": "skeleton_checklist_option_1",
                                "featureHash": "YHqgS4Mu",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "51k+sOtO",
                        "shouldPropagate": True,
                        "manualAnnotation": True,
                    },
                ],
            },
            "RUlxBBGp": {
                "objectHash": "RUlxBBGp",
                "actions": [
                    {
                        "name": "box checklist",
                        "range": [[1, 1]],
                        "value": "box_checklist",
                        "answers": [
                            {"name": "box checklist", "value": "box_checklist_option_0", "featureHash": "lBbzV4El"}
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "UHclwXeD",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    },
                    {
                        "name": "box radio",
                        "range": [[1, 1]],
                        "value": "box_radio",
                        "answers": [{"name": "box radio", "value": "box_radio_option_1", "featureHash": "wTSXji2I"}],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "u+4bIbCR",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    },
                ],
            },
            "Aya79dpB": {
                "objectHash": "Aya79dpB",
                "actions": [
                    {
                        "name": "polygon checklist",
                        "range": [[1, 1]],
                        "value": "polygon_checklist",
                        "answers": [
                            {
                                "name": "polygon checklist",
                                "value": "polygon_checklist_option_1",
                                "featureHash": "sj7I7lsB",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "PhRGDJdU",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
            "Zy5PjiQu": {
                "objectHash": "Zy5PjiQu",
                "actions": [
                    {
                        "name": "polygon text",
                        "range": [[1, 1]],
                        "value": "polygon_text",
                        "answers": "egeg",
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "8wiMXlVz",
                        "shouldPropagate": True,
                        "manualAnnotation": True,
                    }
                ],
            },
            "1oSpiaDM": {
                "objectHash": "1oSpiaDM",
                "actions": [
                    {
                        "name": "bitmask radio",
                        "range": [[1, 1]],
                        "value": "bitmask_radio",
                        "answers": [
                            {"name": "bitmask radio", "value": "bitmask_radio_option_0", "featureHash": "exM6kLRQ"}
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "7tC1hS87",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
            "3lLDdvLz": {
                "objectHash": "3lLDdvLz",
                "actions": [
                    {
                        "name": "keypoint text",
                        "range": [[1, 1]],
                        "value": "keypoint_text",
                        "answers": "hrhr",
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "73XckWFd",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
            "8M1VEyNi": {
                "objectHash": "8M1VEyNi",
                "actions": [
                    {
                        "name": "skeleton checklist",
                        "range": [[1, 1]],
                        "value": "skeleton_checklist",
                        "answers": [
                            {
                                "name": "skeleton checklist",
                                "value": "skeleton_checklist_option_1",
                                "featureHash": "YHqgS4Mu",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "51k+sOtO",
                        "shouldPropagate": True,
                        "manualAnnotation": True,
                    }
                ],
            },
        },
        "label_status": "LABEL_IN_PROGRESS",
        "export_history": [
            {
                "export_hash": UUID("fa5b7a58-7773-4814-8753-d1ed48e07fbf"),
                "exported_at": "Fri, 01 Dec 2023 11:18:11 UTC",
                "user_email": "adam@encord.com",
            },
            {
                "export_hash": UUID("546dbaf9-1b62-49cc-8d20-45cbca0dcd12"),
                "exported_at": "Fri, 01 Dec 2023 11:17:24 UTC",
                "user_email": "adam@encord.com",
            },
        ],
        "export_hash": UUID("fa5b7a58-7773-4814-8753-d1ed48e07fbf"),
        "exported_at": "Fri, 01 Dec 2023 11:18:11 UTC",
    },
    {
        "label_hash": "a97f86f8-3af8-478c-9280-7b80afbf5ffc",
        "created_at": datetime.datetime(2023, 12, 1, 10, 34, 23, 390038, tzinfo=datetime.timezone.utc),
        "last_edited_at": datetime.datetime(2023, 12, 1, 10, 45, 17, 20824, tzinfo=datetime.timezone.utc),
        "dataset_hash": "682ab35e-adcb-4502-bd3e-18500dfaace6",
        "dataset_title": "COCO - export dataset",
        "data_title": "video.mp4",
        "data_hash": "9f4a92e8-c53a-4689-8531-f44e6bc7b03b",
        "data_type": "video",
        "is_image_sequence": None,
        "video_link": "cord-videos-dev/fOG7LpSlbyVNLFE1tKOFN1GMOBE2/9f4a92e8-c53a-4689-8531-f44e6bc7b03b",
        "data_units": {
            "9f4a92e8-c53a-4689-8531-f44e6bc7b03b": {
                "data_hash": "9f4a92e8-c53a-4689-8531-f44e6bc7b03b",
                "data_title": "video.mp4",
                "data_type": "video/mp4",
                "data_sequence": 0,
                "labels": {
                    "0": {
                        "objects": [
                            {
                                "featureHash": "ImO9dtQh",
                                "objectHash": "JnrA7H0x",
                                "name": "box",
                                "value": "box",
                                "color": "#D33115",
                                "shape": "bounding_box",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:41:00 GMT",
                                "manualAnnotation": True,
                                "boundingBox": {"x": 0.0479, "y": 0.2146, "w": 0.1507, "h": 0.1365},
                            },
                            {
                                "featureHash": "NBMDpwcd",
                                "objectHash": "I2uztqvP",
                                "name": "rotatable box",
                                "value": "rotatable_box",
                                "color": "#E27300",
                                "shape": "rotatable_bounding_box",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:41:02 GMT",
                                "lastEditedBy": "adam@encord.com",
                                "lastEditedAt": "Fri, 01 Dec 2023 10:41:02 GMT",
                                "manualAnnotation": True,
                                "rotatableBoundingBox": {
                                    "x": 0.445,
                                    "y": 0.2642,
                                    "w": 0.1011,
                                    "h": 0.1933,
                                    "theta": 28.6819,
                                },
                            },
                            {
                                "featureHash": "gr3562OV",
                                "objectHash": "e4Fh0Atj",
                                "name": "polygon",
                                "value": "polygon",
                                "color": "#16406C",
                                "shape": "polygon",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:41:07 GMT",
                                "polygon": {
                                    "0": {"x": 0.8794, "y": 0.3387},
                                    "1": {"x": 0.7553, "y": 0.4061},
                                    "2": {"x": 0.7855, "y": 0.5355},
                                    "3": {"x": 0.8493, "y": 0.539},
                                    "4": {"x": 0.9007, "y": 0.4646},
                                    "5": {"x": 0.8706, "y": 0.3883},
                                    "6": {"x": 0.9184, "y": 0.367},
                                },
                                "manualAnnotation": True,
                            },
                            {
                                "featureHash": "SKRR+bNg",
                                "objectHash": "MJto5XSv",
                                "name": "polyline",
                                "value": "polyline",
                                "color": "#FE9200",
                                "shape": "polyline",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:41:10 GMT",
                                "polyline": {
                                    "0": {"x": 0.273, "y": 0.4539},
                                    "1": {"x": 0.1578, "y": 0.5497},
                                    "2": {"x": 0.2606, "y": 0.5905},
                                    "3": {"x": 0.3138, "y": 0.5709},
                                    "4": {"x": 0.3652, "y": 0.5018},
                                },
                                "manualAnnotation": True,
                            },
                            {
                                "featureHash": "hN0/lF+8",
                                "objectHash": "f0MmrCk0",
                                "name": "bitmask",
                                "value": "bitmask",
                                "color": "#FCDC00",
                                "shape": "bitmask",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:41:12 GMT",
                                "bitmask": {
                                    "rleString": "ffg2c0h;8I5K6K4M4L2M4M3M3M2O2N1O2N1O1N3N1O1O100O1O100O10O10O10O100O10O01O2N1O1N2N2L5M201N101N2N2N2N1O3M2N3M4J8\\O_DLVW`1",
                                    "top": 0,
                                    "left": 0,
                                    "width": 400,
                                    "height": 400,
                                },
                                "manualAnnotation": True,
                            },
                            {
                                "featureHash": "bhkdPLGR",
                                "objectHash": "u3X0x0di",
                                "name": "keypoint",
                                "value": "keypoint",
                                "color": "#DBDF00",
                                "shape": "point",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:41:14 GMT",
                                "point": {"0": {"x": 0.8032, "y": 0.6543}},
                                "manualAnnotation": True,
                            },
                            {
                                "featureHash": "68gUGGu7",
                                "objectHash": "YK1gFlRi",
                                "name": "skeleton",
                                "value": "skeleton",
                                "color": "#A4DD00",
                                "shape": "skeleton",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:41:17 GMT",
                                "skeleton": {
                                    "0": {
                                        "x": 0.1097,
                                        "y": 0.7504,
                                        "name": "point_0",
                                        "color": "#000000",
                                        "value": "point_0",
                                        "featureHash": "A1LNYvDC",
                                    },
                                    "1": {
                                        "x": 0.0783,
                                        "y": 0.7139,
                                        "name": "point_1",
                                        "color": "#000000",
                                        "value": "point_1",
                                        "featureHash": "Ld3dbiBd",
                                    },
                                    "2": {
                                        "x": 0.0353,
                                        "y": 0.7529,
                                        "name": "point_2",
                                        "color": "#000000",
                                        "value": "point_2",
                                        "featureHash": "yUixMqk3",
                                    },
                                    "3": {
                                        "x": 0.0788,
                                        "y": 0.6714,
                                        "name": "point_3",
                                        "color": "#000000",
                                        "value": "point_3",
                                        "featureHash": "sAMAlWjC",
                                    },
                                    "4": {
                                        "x": 0.1115,
                                        "y": 0.6877,
                                        "name": "point_4",
                                        "color": "#000000",
                                        "value": "point_4",
                                        "featureHash": "lVG9gScy",
                                    },
                                    "5": {
                                        "x": 0.0246,
                                        "y": 0.6832,
                                        "name": "point_5",
                                        "color": "#000000",
                                        "value": "point_5",
                                        "featureHash": "jKtJ9nSZ",
                                    },
                                    "6": {
                                        "x": 0.0765,
                                        "y": 0.6394,
                                        "name": "point_6",
                                        "color": "#000000",
                                        "value": "point_6",
                                        "featureHash": "XTl9TVhz",
                                    },
                                },
                                "manualAnnotation": True,
                            },
                        ],
                        "classifications": [
                            {
                                "featureHash": "R3daKWYA",
                                "classificationHash": "EAfsy1+h",
                                "name": "radio",
                                "value": "radio",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:41:30 GMT",
                                "lastEditedAt": "Fri, 01 Dec 2023 10:41:30 GMT",
                                "manualAnnotation": True,
                            },
                            {
                                "featureHash": "is0CLEV9",
                                "classificationHash": "qWuVpAY6",
                                "name": "checklist",
                                "value": "checklist",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:41:34 GMT",
                                "lastEditedAt": "Fri, 01 Dec 2023 10:41:34 GMT",
                                "manualAnnotation": True,
                            },
                            {
                                "featureHash": "NW40sdPd",
                                "classificationHash": "X9BTFJ38",
                                "name": "text",
                                "value": "text",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:41:37 GMT",
                                "lastEditedAt": "Fri, 01 Dec 2023 10:41:37 GMT",
                                "manualAnnotation": True,
                            },
                        ],
                    },
                    "1": {
                        "classifications": [
                            {
                                "featureHash": "R3daKWYA",
                                "classificationHash": "EAfsy1+h",
                                "name": "radio",
                                "value": "radio",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:41:30 GMT",
                                "lastEditedAt": "Fri, 01 Dec 2023 10:41:30 GMT",
                                "manualAnnotation": True,
                            },
                            {
                                "featureHash": "is0CLEV9",
                                "classificationHash": "qWuVpAY6",
                                "name": "checklist",
                                "value": "checklist",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:41:34 GMT",
                                "lastEditedAt": "Fri, 01 Dec 2023 10:41:34 GMT",
                                "manualAnnotation": True,
                            },
                            {
                                "featureHash": "NW40sdPd",
                                "classificationHash": "X9BTFJ38",
                                "name": "text",
                                "value": "text",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:41:37 GMT",
                                "lastEditedAt": "Fri, 01 Dec 2023 10:41:37 GMT",
                                "manualAnnotation": True,
                            },
                        ],
                        "objects": [
                            {
                                "featureHash": "ImO9dtQh",
                                "objectHash": "JnrA7H0x",
                                "name": "box",
                                "value": "box",
                                "color": "#D33115",
                                "shape": "bounding_box",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:41:48 GMT",
                                "manualAnnotation": True,
                                "boundingBox": {"x": 0.3759, "y": 0.3741, "w": 0.1578, "h": 0.1188},
                            },
                            {
                                "featureHash": "NBMDpwcd",
                                "objectHash": "I2uztqvP",
                                "name": "rotatable box",
                                "value": "rotatable_box",
                                "color": "#E27300",
                                "shape": "rotatable_bounding_box",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:41:54 GMT",
                                "lastEditedBy": "adam@encord.com",
                                "lastEditedAt": "Fri, 01 Dec 2023 10:41:55 GMT",
                                "manualAnnotation": True,
                                "rotatableBoundingBox": {
                                    "x": 0.6915,
                                    "y": 0.4628,
                                    "w": 0.133,
                                    "h": 0.0993,
                                    "theta": 32.0179,
                                },
                            },
                            {
                                "featureHash": "gr3562OV",
                                "objectHash": "e4Fh0Atj",
                                "name": "polygon",
                                "value": "polygon",
                                "color": "#16406C",
                                "shape": "polygon",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:41:59 GMT",
                                "polygon": {
                                    "0": {"x": 0.1862, "y": 0.4078},
                                    "1": {"x": 0.0745, "y": 0.4805},
                                    "2": {"x": 0.1383, "y": 0.5426},
                                    "3": {"x": 0.2429, "y": 0.5656},
                                    "4": {"x": 0.2553, "y": 0.5018},
                                },
                                "manualAnnotation": True,
                            },
                            {
                                "featureHash": "SKRR+bNg",
                                "objectHash": "MJto5XSv",
                                "name": "polyline",
                                "value": "polyline",
                                "color": "#FE9200",
                                "shape": "polyline",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:42:06 GMT",
                                "polyline": {
                                    "0": {"x": 0.1028, "y": 0.6188},
                                    "1": {"x": 0.1543, "y": 0.6631},
                                    "2": {"x": 0.234, "y": 0.6578},
                                    "3": {"x": 0.3138, "y": 0.6206},
                                    "4": {"x": 0.4326, "y": 0.6366},
                                    "5": {"x": 0.4433, "y": 0.6454},
                                },
                                "manualAnnotation": True,
                            },
                            {
                                "featureHash": "hN0/lF+8",
                                "objectHash": "f0MmrCk0",
                                "name": "bitmask",
                                "value": "bitmask",
                                "color": "#FCDC00",
                                "shape": "bitmask",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:42:10 GMT",
                                "bitmask": {
                                    "rleString": "ock2;R<6L2M4M2M3O1N4M2M2O2M2O001N2O001O001O00000000001OO2O0000001N101O1N1O2O1N2N3M3L5K5J6I^j_1",
                                    "top": 0,
                                    "left": 0,
                                    "width": 400,
                                    "height": 400,
                                },
                                "manualAnnotation": True,
                            },
                            {
                                "featureHash": "bhkdPLGR",
                                "objectHash": "u3X0x0di",
                                "name": "keypoint",
                                "value": "keypoint",
                                "color": "#DBDF00",
                                "shape": "point",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:42:14 GMT",
                                "point": {"0": {"x": 0.1436, "y": 0.36}},
                                "manualAnnotation": True,
                            },
                            {
                                "featureHash": "68gUGGu7",
                                "objectHash": "YK1gFlRi",
                                "name": "skeleton",
                                "value": "skeleton",
                                "color": "#A4DD00",
                                "shape": "skeleton",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 10:43:02 GMT",
                                "skeleton": {
                                    "0": {
                                        "x": 0.4022,
                                        "y": 0.5885,
                                        "name": "point_0",
                                        "color": "#000000",
                                        "value": "point_0",
                                        "featureHash": "A1LNYvDC",
                                    },
                                    "1": {
                                        "x": 0.3708,
                                        "y": 0.568,
                                        "name": "point_1",
                                        "color": "#000000",
                                        "value": "point_1",
                                        "featureHash": "Ld3dbiBd",
                                    },
                                    "2": {
                                        "x": 0.3278,
                                        "y": 0.5899,
                                        "name": "point_2",
                                        "color": "#000000",
                                        "value": "point_2",
                                        "featureHash": "yUixMqk3",
                                    },
                                    "3": {
                                        "x": 0.3713,
                                        "y": 0.5441,
                                        "name": "point_3",
                                        "color": "#000000",
                                        "value": "point_3",
                                        "featureHash": "sAMAlWjC",
                                    },
                                    "4": {
                                        "x": 0.404,
                                        "y": 0.5532,
                                        "name": "point_4",
                                        "color": "#000000",
                                        "value": "point_4",
                                        "featureHash": "lVG9gScy",
                                    },
                                    "5": {
                                        "x": 0.3171,
                                        "y": 0.5507,
                                        "name": "point_5",
                                        "color": "#000000",
                                        "value": "point_5",
                                        "featureHash": "jKtJ9nSZ",
                                    },
                                    "6": {
                                        "x": 0.369,
                                        "y": 0.5261,
                                        "name": "point_6",
                                        "color": "#000000",
                                        "value": "point_6",
                                        "featureHash": "XTl9TVhz",
                                    },
                                },
                                "manualAnnotation": True,
                            },
                        ],
                    },
                },
                "data_fps": 25.0,
                "data_duration": 0.08,
                "data_link": "cord-videos-dev/fOG7LpSlbyVNLFE1tKOFN1GMOBE2/9f4a92e8-c53a-4689-8531-f44e6bc7b03b",
                "width": 400,
                "height": 400,
            }
        },
        "object_answers": {
            "JnrA7H0x": {"objectHash": "JnrA7H0x", "classifications": []},
            "I2uztqvP": {"objectHash": "I2uztqvP", "classifications": []},
            "e4Fh0Atj": {"objectHash": "e4Fh0Atj", "classifications": []},
            "MJto5XSv": {"objectHash": "MJto5XSv", "classifications": []},
            "f0MmrCk0": {"objectHash": "f0MmrCk0", "classifications": []},
            "u3X0x0di": {"objectHash": "u3X0x0di", "classifications": []},
            "YK1gFlRi": {"objectHash": "YK1gFlRi", "classifications": []},
        },
        "classification_answers": {
            "EAfsy1+h": {
                "classificationHash": "EAfsy1+h",
                "classifications": [
                    {
                        "name": "radio nested text",
                        "value": "radio_nested_text",
                        "answers": "wfw",
                        "featureHash": "tY6bNKl3",
                        "manualAnnotation": True,
                    },
                    {
                        "name": "radio nested checklist",
                        "value": "radio_nested_checklist",
                        "answers": [
                            {"name": "opt 1", "value": "opt_1", "featureHash": "HhB+tsH2"},
                            {"name": "opt 0", "value": "opt_0", "featureHash": "6n60OH3Q"},
                        ],
                        "featureHash": "JE/BiaGw",
                        "manualAnnotation": True,
                    },
                    {
                        "name": "radio nested radio",
                        "value": "radio_nested_radio",
                        "answers": [{"name": "opt 0", "value": "opt_0", "featureHash": "z29i8QS0"}],
                        "featureHash": "MVDBTicG",
                        "manualAnnotation": True,
                    },
                    {
                        "name": "radio",
                        "value": "radio",
                        "answers": [{"name": "radio 1", "value": "radio_1", "featureHash": "gxCMit/w"}],
                        "featureHash": "s+3ehT7T",
                        "manualAnnotation": True,
                    },
                ],
            },
            "qWuVpAY6": {
                "classificationHash": "qWuVpAY6",
                "classifications": [
                    {
                        "name": "checklist",
                        "value": "checklist",
                        "answers": [
                            {"name": "checklist 0", "value": "checklist_0", "featureHash": "Irh8Wgjq"},
                            {"name": "checklist 1", "value": "checklist_1", "featureHash": "fd/FLN0x"},
                        ],
                        "featureHash": "YtqQrGVm",
                        "manualAnnotation": True,
                    }
                ],
            },
            "X9BTFJ38": {
                "classificationHash": "X9BTFJ38",
                "classifications": [
                    {
                        "name": "text",
                        "value": "text",
                        "answers": "ewfwfw",
                        "featureHash": "hBo6zZds",
                        "manualAnnotation": True,
                    }
                ],
            },
        },
        "object_actions": {},
        "label_status": "LABEL_IN_PROGRESS",
        "export_history": [
            {
                "export_hash": UUID("ec712441-866e-41bc-9a06-80eddf5fa824"),
                "exported_at": "Fri, 01 Dec 2023 11:18:12 UTC",
                "user_email": "adam@encord.com",
            },
            {
                "export_hash": UUID("5078f693-bec1-413c-a115-2980d15459ab"),
                "exported_at": "Fri, 01 Dec 2023 11:17:24 UTC",
                "user_email": "adam@encord.com",
            },
        ],
        "export_hash": UUID("ec712441-866e-41bc-9a06-80eddf5fa824"),
        "exported_at": "Fri, 01 Dec 2023 11:18:12 UTC",
    },
    {
        "label_hash": "4bcf4d76-0496-475a-890a-0efd2a2d8292",
        "created_at": datetime.datetime(2023, 12, 1, 10, 48, 23, 857630, tzinfo=datetime.timezone.utc),
        "last_edited_at": datetime.datetime(2023, 12, 1, 11, 6, 25, 920875, tzinfo=datetime.timezone.utc),
        "dataset_hash": "682ab35e-adcb-4502-bd3e-18500dfaace6",
        "dataset_title": "COCO - export dataset",
        "data_title": "image-group",
        "data_hash": "80b1f7c3-bbab-489d-be61-26ddabe27c32",
        "data_type": "img_group",
        "is_image_sequence": False,
        "video_link": None,
        "data_units": {
            "de5d8787-683d-41d5-9356-1944bb07aadf": {
                "data_hash": "de5d8787-683d-41d5-9356-1944bb07aadf",
                "data_title": "1.png",
                "data_link": "cord-images-dev/fOG7LpSlbyVNLFE1tKOFN1GMOBE2/a07d3ef6-91f3-4184-a7f6-a36c0324ca1d",
                "data_type": "image/png",
                "data_sequence": 0,
                "width": 400,
                "height": 400,
                "labels": {
                    "objects": [
                        {
                            "featureHash": "ImO9dtQh",
                            "objectHash": "esSwqOk3",
                            "name": "box",
                            "value": "box",
                            "color": "#D33115",
                            "shape": "bounding_box",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:48:29 GMT",
                            "manualAnnotation": True,
                            "boundingBox": {"x": 0.117, "y": 0.2199, "w": 0.1028, "h": 0.1649},
                        },
                        {
                            "featureHash": "NBMDpwcd",
                            "objectHash": "IkdWJi/L",
                            "name": "rotatable box",
                            "value": "rotatable_box",
                            "color": "#E27300",
                            "shape": "rotatable_bounding_box",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:48:30 GMT",
                            "lastEditedBy": "adam@encord.com",
                            "lastEditedAt": "Fri, 01 Dec 2023 10:48:31 GMT",
                            "manualAnnotation": True,
                            "rotatableBoundingBox": {
                                "x": 0.3759,
                                "y": 0.3014,
                                "w": 0.0638,
                                "h": 0.0532,
                                "theta": 32.8422,
                            },
                        },
                        {
                            "featureHash": "gr3562OV",
                            "objectHash": "AxVrCSDf",
                            "name": "polygon",
                            "value": "polygon",
                            "color": "#16406C",
                            "shape": "polygon",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:48:33 GMT",
                            "polygon": {
                                "0": {"x": 0.5798, "y": 0.3156},
                                "1": {"x": 0.4823, "y": 0.4344},
                                "2": {"x": 0.5372, "y": 0.5231},
                                "3": {"x": 0.6259, "y": 0.5461},
                                "4": {"x": 0.6223, "y": 0.422},
                                "5": {"x": 0.6099, "y": 0.4025},
                            },
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "SKRR+bNg",
                            "objectHash": "rGvWCYXp",
                            "name": "polyline",
                            "value": "polyline",
                            "color": "#FE9200",
                            "shape": "polyline",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:48:36 GMT",
                            "polyline": {
                                "0": {"x": 0.7145, "y": 0.2997},
                                "1": {"x": 0.7216, "y": 0.4007},
                                "2": {"x": 0.8138, "y": 0.4646},
                                "3": {"x": 0.7837, "y": 0.5249},
                                "4": {"x": 0.75, "y": 0.5656},
                                "5": {"x": 0.7482, "y": 0.594},
                            },
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "hN0/lF+8",
                            "objectHash": "iyiu8kWG",
                            "name": "bitmask",
                            "value": "bitmask",
                            "color": "#FCDC00",
                            "shape": "bitmask",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:48:38 GMT",
                            "bitmask": {
                                "rleString": "R^^18U<7J4L3N2N2N2N2O1N101N10001N100000000000000000001O00000000010O0000001O01O01O000001O0001O01O0O010000O10000O10O0100O01000O01000O010000O010O01000O10O10O10000O10000O2O00001N100O2O1N1O2O2L3N2N3L5JWZX2",
                                "top": 0,
                                "left": 0,
                                "width": 400,
                                "height": 400,
                            },
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "bhkdPLGR",
                            "objectHash": "jW3Y8Hwo",
                            "name": "keypoint",
                            "value": "keypoint",
                            "color": "#DBDF00",
                            "shape": "point",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:48:39 GMT",
                            "point": {"0": {"x": 0.1454, "y": 0.5107}},
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "68gUGGu7",
                            "objectHash": "Jnvhu8Kt",
                            "name": "skeleton",
                            "value": "skeleton",
                            "color": "#A4DD00",
                            "shape": "skeleton",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:48:46 GMT",
                            "skeleton": {
                                "0": {
                                    "x": 0.3246,
                                    "y": 0.7114,
                                    "name": "point_0",
                                    "color": "#000000",
                                    "value": "point_0",
                                    "featureHash": "A1LNYvDC",
                                },
                                "1": {
                                    "x": 0.2766,
                                    "y": 0.6676,
                                    "name": "point_1",
                                    "color": "#000000",
                                    "value": "point_1",
                                    "featureHash": "Ld3dbiBd",
                                },
                                "2": {
                                    "x": 0.2108,
                                    "y": 0.7145,
                                    "name": "point_2",
                                    "color": "#000000",
                                    "value": "point_2",
                                    "featureHash": "yUixMqk3",
                                },
                                "3": {
                                    "x": 0.2773,
                                    "y": 0.6165,
                                    "name": "point_3",
                                    "color": "#000000",
                                    "value": "point_3",
                                    "featureHash": "sAMAlWjC",
                                },
                                "4": {
                                    "x": 0.3274,
                                    "y": 0.6361,
                                    "name": "point_4",
                                    "color": "#000000",
                                    "value": "point_4",
                                    "featureHash": "lVG9gScy",
                                },
                                "5": {
                                    "x": 0.1944,
                                    "y": 0.6307,
                                    "name": "point_5",
                                    "color": "#000000",
                                    "value": "point_5",
                                    "featureHash": "jKtJ9nSZ",
                                },
                                "6": {
                                    "x": 0.2739,
                                    "y": 0.578,
                                    "name": "point_6",
                                    "color": "#000000",
                                    "value": "point_6",
                                    "featureHash": "XTl9TVhz",
                                },
                            },
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "ImO9dtQh",
                            "objectHash": "lbWBe6oj",
                            "name": "box",
                            "value": "box",
                            "color": "#D33115",
                            "shape": "bounding_box",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:05:36 GMT",
                            "manualAnnotation": True,
                            "boundingBox": {"x": 0.8351, "y": 0.6277, "w": 0.078, "h": 0.0993},
                        },
                        {
                            "featureHash": "NBMDpwcd",
                            "objectHash": "96c/yk/d",
                            "name": "rotatable box",
                            "value": "rotatable_box",
                            "color": "#E27300",
                            "shape": "rotatable_bounding_box",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:05:38 GMT",
                            "lastEditedBy": "adam@encord.com",
                            "lastEditedAt": "Fri, 01 Dec 2023 11:05:39 GMT",
                            "manualAnnotation": True,
                            "rotatableBoundingBox": {
                                "x": 0.711,
                                "y": 0.6702,
                                "w": 0.0656,
                                "h": 0.094,
                                "theta": 29.0502,
                            },
                        },
                        {
                            "featureHash": "gr3562OV",
                            "objectHash": "6cc/uT9b",
                            "name": "polygon",
                            "value": "polygon",
                            "color": "#16406C",
                            "shape": "polygon",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:05:42 GMT",
                            "polygon": {
                                "0": {"x": 0.6418, "y": 0.672},
                                "1": {"x": 0.5656, "y": 0.7713},
                                "2": {"x": 0.6046, "y": 0.7784},
                                "3": {"x": 0.656, "y": 0.7518},
                                "4": {"x": 0.6454, "y": 0.7465},
                                "5": {"x": 0.6472, "y": 0.7217},
                            },
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "SKRR+bNg",
                            "objectHash": "D6vPWMDX",
                            "name": "polyline",
                            "value": "polyline",
                            "color": "#FE9200",
                            "shape": "polyline",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:05:46 GMT",
                            "polyline": {
                                "0": {"x": 0.5284, "y": 0.6383},
                                "1": {"x": 0.4982, "y": 0.7022},
                                "2": {"x": 0.523, "y": 0.7465},
                                "3": {"x": 0.4787, "y": 0.7678},
                                "4": {"x": 0.4574, "y": 0.7855},
                            },
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "hN0/lF+8",
                            "objectHash": "4D+z/QQ1",
                            "name": "bitmask",
                            "value": "bitmask",
                            "color": "#FCDC00",
                            "shape": "bitmask",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:05:49 GMT",
                            "bitmask": {
                                "rleString": "^Vb3;S<4L4L4M2N2N2O0O2N2O0O2O00000O2O00000001O0O10001O0O101N2O0O2N2N2N3L4L5Jdok0",
                                "top": 0,
                                "left": 0,
                                "width": 400,
                                "height": 400,
                            },
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "bhkdPLGR",
                            "objectHash": "MYbEJpg1",
                            "name": "keypoint",
                            "value": "keypoint",
                            "color": "#DBDF00",
                            "shape": "point",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:05:51 GMT",
                            "point": {"0": {"x": 0.2642, "y": 0.7819}},
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "68gUGGu7",
                            "objectHash": "d+yjcHNs",
                            "name": "skeleton",
                            "value": "skeleton",
                            "color": "#A4DD00",
                            "shape": "skeleton",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:05:53 GMT",
                            "skeleton": {
                                "0": {
                                    "x": 0.1302,
                                    "y": 0.7905,
                                    "name": "point_0",
                                    "color": "#000000",
                                    "value": "point_0",
                                    "featureHash": "A1LNYvDC",
                                },
                                "1": {
                                    "x": 0.1097,
                                    "y": 0.7706,
                                    "name": "point_1",
                                    "color": "#000000",
                                    "value": "point_1",
                                    "featureHash": "Ld3dbiBd",
                                },
                                "2": {
                                    "x": 0.0817,
                                    "y": 0.7919,
                                    "name": "point_2",
                                    "color": "#000000",
                                    "value": "point_2",
                                    "featureHash": "yUixMqk3",
                                },
                                "3": {
                                    "x": 0.11,
                                    "y": 0.7473,
                                    "name": "point_3",
                                    "color": "#000000",
                                    "value": "point_3",
                                    "featureHash": "sAMAlWjC",
                                },
                                "4": {
                                    "x": 0.1314,
                                    "y": 0.7562,
                                    "name": "point_4",
                                    "color": "#000000",
                                    "value": "point_4",
                                    "featureHash": "lVG9gScy",
                                },
                                "5": {
                                    "x": 0.0747,
                                    "y": 0.7538,
                                    "name": "point_5",
                                    "color": "#000000",
                                    "value": "point_5",
                                    "featureHash": "jKtJ9nSZ",
                                },
                                "6": {
                                    "x": 0.1086,
                                    "y": 0.7298,
                                    "name": "point_6",
                                    "color": "#000000",
                                    "value": "point_6",
                                    "featureHash": "XTl9TVhz",
                                },
                            },
                            "manualAnnotation": True,
                        },
                    ],
                    "classifications": [
                        {
                            "featureHash": "R3daKWYA",
                            "classificationHash": "TweHydj2",
                            "name": "radio",
                            "value": "radio",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:53:38 GMT",
                            "lastEditedAt": "Fri, 01 Dec 2023 10:53:38 GMT",
                            "manualAnnotation": True,
                        }
                    ],
                },
            },
            "2962623e-f58b-421c-ab8f-e3d577effe86": {
                "data_hash": "2962623e-f58b-421c-ab8f-e3d577effe86",
                "data_title": "2.png",
                "data_link": "cord-images-dev/fOG7LpSlbyVNLFE1tKOFN1GMOBE2/d411a847-7f0e-4603-896a-373b98a6923a",
                "data_type": "image/png",
                "data_sequence": 1,
                "width": 400,
                "height": 400,
                "labels": {
                    "objects": [
                        {
                            "featureHash": "ImO9dtQh",
                            "objectHash": "PoCcR6A4",
                            "name": "box",
                            "value": "box",
                            "color": "#D33115",
                            "shape": "bounding_box",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:02:12 GMT",
                            "manualAnnotation": True,
                            "boundingBox": {"x": 0.108, "y": 0.354, "w": 0.1394, "h": 0.1663},
                        },
                        {
                            "featureHash": "NBMDpwcd",
                            "objectHash": "IkdWJi/L",
                            "name": "rotatable box",
                            "value": "rotatable_box",
                            "color": "#E27300",
                            "shape": "rotatable_bounding_box",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:02:25 GMT",
                            "lastEditedBy": "adam@encord.com",
                            "lastEditedAt": "Fri, 01 Dec 2023 11:02:26 GMT",
                            "manualAnnotation": True,
                            "rotatableBoundingBox": {
                                "x": 0.3745,
                                "y": 0.4152,
                                "w": 0.1149,
                                "h": 0.1002,
                                "theta": 31.32,
                            },
                        },
                        {
                            "featureHash": "gr3562OV",
                            "objectHash": "AxVrCSDf",
                            "name": "polygon",
                            "value": "polygon",
                            "color": "#16406C",
                            "shape": "polygon",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:02:32 GMT",
                            "polygon": {
                                "0": {"x": 0.7094, "y": 0.4029},
                                "1": {"x": 0.6043, "y": 0.5643},
                                "2": {"x": 0.6899, "y": 0.579},
                                "3": {"x": 0.7706, "y": 0.5032},
                                "4": {"x": 0.7706, "y": 0.491},
                                "5": {"x": 0.6948, "y": 0.4445},
                                "6": {"x": 0.7877, "y": 0.4152},
                            },
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "SKRR+bNg",
                            "objectHash": "g+NeRdSm",
                            "name": "polyline",
                            "value": "polyline",
                            "color": "#FE9200",
                            "shape": "polyline",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:02:41 GMT",
                            "polyline": {
                                "0": {"x": 0.8904, "y": 0.4568},
                                "1": {"x": 0.8586, "y": 0.5375},
                                "2": {"x": 0.9222, "y": 0.6328},
                                "3": {"x": 0.8341, "y": 0.6793},
                                "4": {"x": 0.7559, "y": 0.6646},
                            },
                            "lastEditedBy": "adam@encord.com",
                            "lastEditedAt": "Fri, 01 Dec 2023 11:02:41 GMT",
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "hN0/lF+8",
                            "objectHash": "c0Tg67JF",
                            "name": "bitmask",
                            "value": "bitmask",
                            "color": "#FCDC00",
                            "shape": "bitmask",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:02:49 GMT",
                            "bitmask": {
                                "rleString": "][h2=o;7K4L4M2N2N2N3M1O2N2O0O2O1N10001N10001N100000000000000001O000O101O0O101N101N101N2N2N2O1M3N2N3L4L6Hg[`1",
                                "top": 0,
                                "left": 0,
                                "width": 400,
                                "height": 400,
                            },
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "bhkdPLGR",
                            "objectHash": "qLgBwmdc",
                            "name": "keypoint",
                            "value": "keypoint",
                            "color": "#DBDF00",
                            "shape": "point",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:02:51 GMT",
                            "point": {"0": {"x": 0.5505, "y": 0.4421}},
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "68gUGGu7",
                            "objectHash": "4OBsyrhi",
                            "name": "skeleton",
                            "value": "skeleton",
                            "color": "#A4DD00",
                            "shape": "skeleton",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:02:54 GMT",
                            "skeleton": {
                                "0": {
                                    "x": 0.823,
                                    "y": 0.405,
                                    "name": "point_0",
                                    "color": "#000000",
                                    "value": "point_0",
                                    "featureHash": "A1LNYvDC",
                                },
                                "1": {
                                    "x": 0.7948,
                                    "y": 0.3775,
                                    "name": "point_1",
                                    "color": "#000000",
                                    "value": "point_1",
                                    "featureHash": "Ld3dbiBd",
                                },
                                "2": {
                                    "x": 0.7561,
                                    "y": 0.407,
                                    "name": "point_2",
                                    "color": "#000000",
                                    "value": "point_2",
                                    "featureHash": "yUixMqk3",
                                },
                                "3": {
                                    "x": 0.7952,
                                    "y": 0.3455,
                                    "name": "point_3",
                                    "color": "#000000",
                                    "value": "point_3",
                                    "featureHash": "sAMAlWjC",
                                },
                                "4": {
                                    "x": 0.8246,
                                    "y": 0.3578,
                                    "name": "point_4",
                                    "color": "#000000",
                                    "value": "point_4",
                                    "featureHash": "lVG9gScy",
                                },
                                "5": {
                                    "x": 0.7464,
                                    "y": 0.3544,
                                    "name": "point_5",
                                    "color": "#000000",
                                    "value": "point_5",
                                    "featureHash": "jKtJ9nSZ",
                                },
                                "6": {
                                    "x": 0.7932,
                                    "y": 0.3214,
                                    "name": "point_6",
                                    "color": "#000000",
                                    "value": "point_6",
                                    "featureHash": "XTl9TVhz",
                                },
                            },
                            "manualAnnotation": True,
                        },
                    ],
                    "classifications": [
                        {
                            "featureHash": "R3daKWYA",
                            "classificationHash": "gKnYYU/b",
                            "name": "radio",
                            "value": "radio",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:53:55 GMT",
                            "lastEditedAt": "Fri, 01 Dec 2023 10:53:55 GMT",
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "is0CLEV9",
                            "classificationHash": "YQLFbbZU",
                            "name": "checklist",
                            "value": "checklist",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:54:06 GMT",
                            "lastEditedAt": "Fri, 01 Dec 2023 10:54:06 GMT",
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "NW40sdPd",
                            "classificationHash": "Xiw5OQsm",
                            "name": "text",
                            "value": "text",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 10:54:18 GMT",
                            "lastEditedAt": "Fri, 01 Dec 2023 10:54:18 GMT",
                            "manualAnnotation": True,
                        },
                    ],
                },
            },
        },
        "object_answers": {
            "esSwqOk3": {
                "objectHash": "esSwqOk3",
                "classifications": [
                    {
                        "name": "box text",
                        "value": "box_text",
                        "answers": "ergeg",
                        "featureHash": "E6Wai5ZG",
                        "manualAnnotation": True,
                    }
                ],
            },
            "IkdWJi/L": {
                "objectHash": "IkdWJi/L",
                "classifications": [
                    {
                        "name": "rotatable box radio",
                        "value": "rotatable_box_radio",
                        "answers": [
                            {
                                "name": "rotatable box radio option 0",
                                "value": "rotatable_box_radio_option_0",
                                "featureHash": "SIEdjcuH",
                            }
                        ],
                        "featureHash": "LCek15f3",
                        "manualAnnotation": True,
                    }
                ],
            },
            "AxVrCSDf": {"objectHash": "AxVrCSDf", "classifications": []},
            "rGvWCYXp": {"objectHash": "rGvWCYXp", "classifications": []},
            "iyiu8kWG": {"objectHash": "iyiu8kWG", "classifications": []},
            "jW3Y8Hwo": {"objectHash": "jW3Y8Hwo", "classifications": []},
            "Jnvhu8Kt": {"objectHash": "Jnvhu8Kt", "classifications": []},
            "PoCcR6A4": {
                "objectHash": "PoCcR6A4",
                "classifications": [
                    {
                        "name": "box text",
                        "value": "box_text",
                        "answers": "geg",
                        "featureHash": "E6Wai5ZG",
                        "manualAnnotation": True,
                    }
                ],
            },
            "g+NeRdSm": {"objectHash": "g+NeRdSm", "classifications": []},
            "c0Tg67JF": {"objectHash": "c0Tg67JF", "classifications": []},
            "qLgBwmdc": {"objectHash": "qLgBwmdc", "classifications": []},
            "4OBsyrhi": {"objectHash": "4OBsyrhi", "classifications": []},
            "lbWBe6oj": {
                "objectHash": "lbWBe6oj",
                "classifications": [
                    {
                        "name": "box text",
                        "value": "box_text",
                        "answers": "wfwf",
                        "featureHash": "E6Wai5ZG",
                        "manualAnnotation": True,
                    }
                ],
            },
            "96c/yk/d": {
                "objectHash": "96c/yk/d",
                "classifications": [
                    {
                        "name": "rotatable box radio",
                        "value": "rotatable_box_radio",
                        "answers": [
                            {
                                "name": "rotatable box radio option 0",
                                "value": "rotatable_box_radio_option_0",
                                "featureHash": "SIEdjcuH",
                            }
                        ],
                        "featureHash": "LCek15f3",
                        "manualAnnotation": True,
                    }
                ],
            },
            "6cc/uT9b": {"objectHash": "6cc/uT9b", "classifications": []},
            "D6vPWMDX": {"objectHash": "D6vPWMDX", "classifications": []},
            "4D+z/QQ1": {"objectHash": "4D+z/QQ1", "classifications": []},
            "MYbEJpg1": {"objectHash": "MYbEJpg1", "classifications": []},
            "d+yjcHNs": {"objectHash": "d+yjcHNs", "classifications": []},
        },
        "classification_answers": {
            "TweHydj2": {
                "classificationHash": "TweHydj2",
                "classifications": [
                    {
                        "name": "radio nested text",
                        "value": "radio_nested_text",
                        "answers": "hrhr",
                        "featureHash": "tY6bNKl3",
                        "manualAnnotation": True,
                    },
                    {
                        "name": "radio nested checklist",
                        "value": "radio_nested_checklist",
                        "answers": [{"name": "opt 0", "value": "opt_0", "featureHash": "6n60OH3Q"}],
                        "featureHash": "JE/BiaGw",
                        "manualAnnotation": True,
                    },
                    {
                        "name": "radio nested radio",
                        "value": "radio_nested_radio",
                        "answers": [{"name": "opt 0", "value": "opt_0", "featureHash": "z29i8QS0"}],
                        "featureHash": "MVDBTicG",
                        "manualAnnotation": True,
                    },
                    {
                        "name": "radio",
                        "value": "radio",
                        "answers": [{"name": "radio 1", "value": "radio_1", "featureHash": "gxCMit/w"}],
                        "featureHash": "s+3ehT7T",
                        "manualAnnotation": True,
                    },
                ],
            },
            "gKnYYU/b": {
                "classificationHash": "gKnYYU/b",
                "classifications": [
                    {
                        "name": "radio nested text",
                        "value": "radio_nested_text",
                        "answers": "gwfwefw",
                        "featureHash": "tY6bNKl3",
                        "manualAnnotation": True,
                    },
                    {
                        "name": "radio nested radio",
                        "value": "radio_nested_radio",
                        "answers": [{"name": "opt 0", "value": "opt_0", "featureHash": "z29i8QS0"}],
                        "featureHash": "MVDBTicG",
                        "manualAnnotation": True,
                    },
                    {
                        "name": "radio",
                        "value": "radio",
                        "answers": [{"name": "radio 1", "value": "radio_1", "featureHash": "gxCMit/w"}],
                        "featureHash": "s+3ehT7T",
                        "manualAnnotation": True,
                    },
                ],
            },
            "YQLFbbZU": {
                "classificationHash": "YQLFbbZU",
                "classifications": [
                    {
                        "name": "checklist",
                        "value": "checklist",
                        "answers": [{"name": "checklist 0", "value": "checklist_0", "featureHash": "Irh8Wgjq"}],
                        "featureHash": "YtqQrGVm",
                        "manualAnnotation": True,
                    }
                ],
            },
            "Xiw5OQsm": {
                "classificationHash": "Xiw5OQsm",
                "classifications": [
                    {
                        "name": "text",
                        "value": "text",
                        "answers": "wfwfwf",
                        "featureHash": "hBo6zZds",
                        "manualAnnotation": True,
                    }
                ],
            },
        },
        "object_actions": {
            "esSwqOk3": {
                "objectHash": "esSwqOk3",
                "actions": [
                    {
                        "name": "box checklist",
                        "range": [[0, 0]],
                        "value": "box_checklist",
                        "answers": [
                            {"name": "box checklist", "value": "box_checklist_option_0", "featureHash": "lBbzV4El"}
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "UHclwXeD",
                        "shouldPropagate": True,
                        "manualAnnotation": True,
                    },
                    {
                        "name": "box radio",
                        "range": [[0, 0]],
                        "value": "box_radio",
                        "answers": [{"name": "box radio", "value": "box_radio_option_0", "featureHash": "pCZJZTnj"}],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "u+4bIbCR",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    },
                ],
            },
            "AxVrCSDf": {
                "objectHash": "AxVrCSDf",
                "actions": [
                    {
                        "name": "polygon checklist",
                        "range": [[0, 1]],
                        "value": "polygon_checklist",
                        "answers": [
                            {
                                "name": "polygon checklist",
                                "value": "polygon_checklist_option_0",
                                "featureHash": "8kDCDHWL",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "PhRGDJdU",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    },
                    {
                        "name": "polygon checklist",
                        "range": [[0, 0]],
                        "value": "polygon_checklist",
                        "answers": [
                            {
                                "name": "polygon checklist",
                                "value": "polygon_checklist_option_1",
                                "featureHash": "sj7I7lsB",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "PhRGDJdU",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    },
                ],
            },
            "rGvWCYXp": {
                "objectHash": "rGvWCYXp",
                "actions": [
                    {
                        "name": "polygon text",
                        "range": [[0, 0]],
                        "value": "polygon_text",
                        "answers": "gergreg",
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "8wiMXlVz",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
            "iyiu8kWG": {
                "objectHash": "iyiu8kWG",
                "actions": [
                    {
                        "name": "bitmask radio",
                        "range": [[0, 0]],
                        "value": "bitmask_radio",
                        "answers": [
                            {
                                "name": "bitmask radio option 0",
                                "value": "bitmask_radio_option_0",
                                "featureHash": "exM6kLRQ",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "7tC1hS87",
                        "shouldPropagate": True,
                        "manualAnnotation": True,
                    }
                ],
            },
            "jW3Y8Hwo": {
                "objectHash": "jW3Y8Hwo",
                "actions": [
                    {
                        "name": "keypoint text",
                        "range": [[0, 0]],
                        "value": "keypoint_text",
                        "answers": "ewge",
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "73XckWFd",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
            "Jnvhu8Kt": {
                "objectHash": "Jnvhu8Kt",
                "actions": [
                    {
                        "name": "skeleton checklist",
                        "range": [[0, 0]],
                        "value": "skeleton_checklist",
                        "answers": [
                            {
                                "name": "skeleton checklist option 0",
                                "value": "skeleton_checklist_option_0",
                                "featureHash": "qL8VXCXm",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "51k+sOtO",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
            "PoCcR6A4": {
                "objectHash": "PoCcR6A4",
                "actions": [
                    {
                        "name": "box checklist",
                        "range": [[1, 1]],
                        "value": "box_checklist",
                        "answers": [
                            {"name": "box checklist", "value": "box_checklist_option_0", "featureHash": "lBbzV4El"}
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "UHclwXeD",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    },
                    {
                        "name": "box checklist",
                        "range": [[1, 1]],
                        "value": "box_checklist",
                        "answers": [
                            {"name": "box checklist", "value": "box_checklist_option_1", "featureHash": "teq8aIDY"}
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "UHclwXeD",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    },
                    {
                        "name": "box radio",
                        "range": [[1, 1]],
                        "value": "box_radio",
                        "answers": [{"name": "box radio", "value": "box_radio_option_0", "featureHash": "pCZJZTnj"}],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "u+4bIbCR",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    },
                ],
            },
            "g+NeRdSm": {
                "objectHash": "g+NeRdSm",
                "actions": [
                    {
                        "name": "polygon text",
                        "range": [[1, 1]],
                        "value": "polygon_text",
                        "answers": "gege",
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "8wiMXlVz",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
            "c0Tg67JF": {
                "objectHash": "c0Tg67JF",
                "actions": [
                    {
                        "name": "bitmask radio",
                        "range": [[1, 1]],
                        "value": "bitmask_radio",
                        "answers": [
                            {
                                "name": "bitmask radio option 0",
                                "value": "bitmask_radio_option_0",
                                "featureHash": "exM6kLRQ",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "7tC1hS87",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
            "qLgBwmdc": {
                "objectHash": "qLgBwmdc",
                "actions": [
                    {
                        "name": "keypoint text",
                        "range": [[1, 1]],
                        "value": "keypoint_text",
                        "answers": "geg",
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "73XckWFd",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
            "4OBsyrhi": {
                "objectHash": "4OBsyrhi",
                "actions": [
                    {
                        "name": "skeleton checklist",
                        "range": [[1, 1]],
                        "value": "skeleton_checklist",
                        "answers": [
                            {
                                "name": "skeleton checklist option 0",
                                "value": "skeleton_checklist_option_0",
                                "featureHash": "qL8VXCXm",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "51k+sOtO",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
            "lbWBe6oj": {
                "objectHash": "lbWBe6oj",
                "actions": [
                    {
                        "name": "box checklist",
                        "range": [[0, 0]],
                        "value": "box_checklist",
                        "answers": [
                            {
                                "name": "box checklist option 0",
                                "value": "box_checklist_option_0",
                                "featureHash": "lBbzV4El",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "UHclwXeD",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    },
                    {
                        "name": "box radio",
                        "range": [[0, 0]],
                        "value": "box_radio",
                        "answers": [
                            {"name": "box radio option 0", "value": "box_radio_option_0", "featureHash": "pCZJZTnj"}
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "u+4bIbCR",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    },
                ],
            },
            "6cc/uT9b": {
                "objectHash": "6cc/uT9b",
                "actions": [
                    {
                        "name": "polygon checklist",
                        "range": [[0, 0]],
                        "value": "polygon_checklist",
                        "answers": [
                            {
                                "name": "polygon checklist option 0",
                                "value": "polygon_checklist_option_0",
                                "featureHash": "8kDCDHWL",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "PhRGDJdU",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    },
                    {
                        "name": "polygon checklist",
                        "range": [[0, 0]],
                        "value": "polygon_checklist",
                        "answers": [
                            {
                                "name": "polygon checklist option 1",
                                "value": "polygon_checklist_option_1",
                                "featureHash": "sj7I7lsB",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "PhRGDJdU",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    },
                ],
            },
            "D6vPWMDX": {
                "objectHash": "D6vPWMDX",
                "actions": [
                    {
                        "name": "polygon text",
                        "range": [[0, 0]],
                        "value": "polygon_text",
                        "answers": "fwef",
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "8wiMXlVz",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
            "4D+z/QQ1": {
                "objectHash": "4D+z/QQ1",
                "actions": [
                    {
                        "name": "bitmask radio",
                        "range": [[0, 0]],
                        "value": "bitmask_radio",
                        "answers": [
                            {
                                "name": "bitmask radio option 0",
                                "value": "bitmask_radio_option_0",
                                "featureHash": "exM6kLRQ",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "7tC1hS87",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
            "d+yjcHNs": {
                "objectHash": "d+yjcHNs",
                "actions": [
                    {
                        "name": "skeleton checklist",
                        "range": [[0, 0]],
                        "value": "skeleton_checklist",
                        "answers": [
                            {
                                "name": "skeleton checklist option 1",
                                "value": "skeleton_checklist_option_1",
                                "featureHash": "YHqgS4Mu",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "51k+sOtO",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
        },
        "label_status": "LABEL_IN_PROGRESS",
        "export_history": [
            {
                "export_hash": UUID("e87210aa-01c2-498e-9622-b83716c3ead7"),
                "exported_at": "Fri, 01 Dec 2023 11:18:13 UTC",
                "user_email": "adam@encord.com",
            },
            {
                "export_hash": UUID("f0a4192d-cdf6-49ec-b7c1-88420c1448f5"),
                "exported_at": "Fri, 01 Dec 2023 11:17:24 UTC",
                "user_email": "adam@encord.com",
            },
        ],
        "export_hash": UUID("e87210aa-01c2-498e-9622-b83716c3ead7"),
        "exported_at": "Fri, 01 Dec 2023 11:18:13 UTC",
    },
    {
        "label_hash": "affa40cd-c95e-4262-a5ee-6bfaf3415d48",
        "created_at": datetime.datetime(2023, 12, 1, 11, 3, 20, 718308, tzinfo=datetime.timezone.utc),
        "last_edited_at": datetime.datetime(2023, 12, 1, 11, 5, 14, 693460, tzinfo=datetime.timezone.utc),
        "dataset_hash": "682ab35e-adcb-4502-bd3e-18500dfaace6",
        "dataset_title": "COCO - export dataset",
        "data_title": "image.png",
        "data_hash": "9cee5450-b2a2-47cb-a9e9-2eb5ec8499dd",
        "data_type": "image",
        "is_image_sequence": None,
        "video_link": None,
        "data_units": {
            "9cee5450-b2a2-47cb-a9e9-2eb5ec8499dd": {
                "data_hash": "9cee5450-b2a2-47cb-a9e9-2eb5ec8499dd",
                "data_title": "image.png",
                "data_type": "image/png",
                "data_sequence": 0,
                "labels": {
                    "objects": [
                        {
                            "featureHash": "ImO9dtQh",
                            "objectHash": "P/9LI504",
                            "name": "box",
                            "value": "box",
                            "color": "#D33115",
                            "shape": "bounding_box",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:03:24 GMT",
                            "lastEditedBy": "adam@encord.com",
                            "lastEditedAt": "Fri, 01 Dec 2023 11:03:48 GMT",
                            "manualAnnotation": True,
                            "boundingBox": {"x": 0.0877, "y": 0.2134, "w": 0.1221, "h": 0.1667},
                        },
                        {
                            "featureHash": "NBMDpwcd",
                            "objectHash": "DYLkbPO4",
                            "name": "rotatable box",
                            "value": "rotatable_box",
                            "color": "#E27300",
                            "shape": "rotatable_bounding_box",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:03:25 GMT",
                            "lastEditedBy": "adam@encord.com",
                            "lastEditedAt": "Fri, 01 Dec 2023 11:03:28 GMT",
                            "manualAnnotation": True,
                            "rotatableBoundingBox": {
                                "x": 0.3624,
                                "y": 0.2604,
                                "w": 0.0493,
                                "h": 0.2324,
                                "theta": 14.8743,
                            },
                        },
                        {
                            "featureHash": "gr3562OV",
                            "objectHash": "sNRMQRZa",
                            "name": "polygon",
                            "value": "polygon",
                            "color": "#16406C",
                            "shape": "polygon",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:03:27 GMT",
                            "polygon": {
                                "0": {"x": 0.5877, "y": 0.2956},
                                "1": {"x": 0.5243, "y": 0.481},
                                "2": {"x": 0.5877, "y": 0.5069},
                                "3": {"x": 0.63, "y": 0.4364},
                                "4": {"x": 0.6511, "y": 0.42},
                            },
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "SKRR+bNg",
                            "objectHash": "G0HipOAZ",
                            "name": "polyline",
                            "value": "polyline",
                            "color": "#FE9200",
                            "shape": "polyline",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:03:32 GMT",
                            "polyline": {
                                "0": {"x": 0.7966, "y": 0.3073},
                                "1": {"x": 0.7332, "y": 0.42},
                                "2": {"x": 0.8013, "y": 0.5397},
                                "3": {"x": 0.7262, "y": 0.6219},
                                "4": {"x": 0.6628, "y": 0.6125},
                            },
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "hN0/lF+8",
                            "objectHash": "S8y9TRAJ",
                            "name": "bitmask",
                            "value": "bitmask",
                            "color": "#FCDC00",
                            "shape": "bitmask",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:03:35 GMT",
                            "bitmask": {
                                "rleString": "`Xf1=P<6K4L4M2N3M2N2N1O2N2O1N101N100O2O0O10001N10000O10000O010O1000O01000O100O010O10000O10O01000000O10O10000000O1000001O000000001N10001N101N101N2N2N1O3M2N2N3L4L5J[TW2",
                                "top": 0,
                                "left": 0,
                                "width": 400,
                                "height": 400,
                            },
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "bhkdPLGR",
                            "objectHash": "oOPOjjAI",
                            "name": "keypoint",
                            "value": "keypoint",
                            "color": "#DBDF00",
                            "shape": "point",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:03:36 GMT",
                            "point": {"0": {"x": 0.1135, "y": 0.474}},
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "68gUGGu7",
                            "objectHash": "jXUPS9nV",
                            "name": "skeleton",
                            "value": "skeleton",
                            "color": "#A4DD00",
                            "shape": "skeleton",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:03:39 GMT",
                            "skeleton": {
                                "0": {
                                    "x": 0.1409,
                                    "y": 0.7322,
                                    "name": "point_0",
                                    "color": "#000000",
                                    "value": "point_0",
                                    "featureHash": "A1LNYvDC",
                                },
                                "1": {
                                    "x": 0.1002,
                                    "y": 0.6854,
                                    "name": "point_1",
                                    "color": "#000000",
                                    "value": "point_1",
                                    "featureHash": "Ld3dbiBd",
                                },
                                "2": {
                                    "x": 0.0444,
                                    "y": 0.7354,
                                    "name": "point_2",
                                    "color": "#000000",
                                    "value": "point_2",
                                    "featureHash": "yUixMqk3",
                                },
                                "3": {
                                    "x": 0.1008,
                                    "y": 0.6309,
                                    "name": "point_3",
                                    "color": "#000000",
                                    "value": "point_3",
                                    "featureHash": "sAMAlWjC",
                                },
                                "4": {
                                    "x": 0.1432,
                                    "y": 0.6518,
                                    "name": "point_4",
                                    "color": "#000000",
                                    "value": "point_4",
                                    "featureHash": "lVG9gScy",
                                },
                                "5": {
                                    "x": 0.0305,
                                    "y": 0.6461,
                                    "name": "point_5",
                                    "color": "#000000",
                                    "value": "point_5",
                                    "featureHash": "jKtJ9nSZ",
                                },
                                "6": {
                                    "x": 0.0979,
                                    "y": 0.5899,
                                    "name": "point_6",
                                    "color": "#000000",
                                    "value": "point_6",
                                    "featureHash": "XTl9TVhz",
                                },
                            },
                            "manualAnnotation": True,
                        },
                    ],
                    "classifications": [
                        {
                            "featureHash": "R3daKWYA",
                            "classificationHash": "vYxKD2Hc",
                            "name": "radio",
                            "value": "radio",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:05:04 GMT",
                            "lastEditedAt": "Fri, 01 Dec 2023 11:05:04 GMT",
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "is0CLEV9",
                            "classificationHash": "DR9AdW+s",
                            "name": "checklist",
                            "value": "checklist",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:05:07 GMT",
                            "lastEditedAt": "Fri, 01 Dec 2023 11:05:07 GMT",
                            "manualAnnotation": True,
                        },
                        {
                            "featureHash": "NW40sdPd",
                            "classificationHash": "+D7fEWJJ",
                            "name": "text",
                            "value": "text",
                            "confidence": 1,
                            "createdBy": "adam@encord.com",
                            "createdAt": "Fri, 01 Dec 2023 11:05:10 GMT",
                            "lastEditedAt": "Fri, 01 Dec 2023 11:05:10 GMT",
                            "manualAnnotation": True,
                        },
                    ],
                },
                "data_link": "cord-images-dev/fOG7LpSlbyVNLFE1tKOFN1GMOBE2/9cee5450-b2a2-47cb-a9e9-2eb5ec8499dd",
                "width": 400,
                "height": 400,
            }
        },
        "object_answers": {
            "P/9LI504": {
                "objectHash": "P/9LI504",
                "classifications": [
                    {
                        "name": "box text",
                        "value": "box_text",
                        "answers": "4rfw",
                        "featureHash": "E6Wai5ZG",
                        "manualAnnotation": True,
                    }
                ],
            },
            "DYLkbPO4": {
                "objectHash": "DYLkbPO4",
                "classifications": [
                    {
                        "name": "rotatable box radio",
                        "value": "rotatable_box_radio",
                        "answers": [
                            {
                                "name": "rotatable box radio option 0",
                                "value": "rotatable_box_radio_option_0",
                                "featureHash": "SIEdjcuH",
                            }
                        ],
                        "featureHash": "LCek15f3",
                        "manualAnnotation": True,
                    }
                ],
            },
            "sNRMQRZa": {"objectHash": "sNRMQRZa", "classifications": []},
            "G0HipOAZ": {"objectHash": "G0HipOAZ", "classifications": []},
            "S8y9TRAJ": {"objectHash": "S8y9TRAJ", "classifications": []},
            "oOPOjjAI": {"objectHash": "oOPOjjAI", "classifications": []},
            "jXUPS9nV": {"objectHash": "jXUPS9nV", "classifications": []},
        },
        "classification_answers": {
            "vYxKD2Hc": {
                "classificationHash": "vYxKD2Hc",
                "classifications": [
                    {
                        "name": "radio nested text",
                        "value": "radio_nested_text",
                        "answers": "gge",
                        "featureHash": "tY6bNKl3",
                        "manualAnnotation": True,
                    },
                    {
                        "name": "radio nested checklist",
                        "value": "radio_nested_checklist",
                        "answers": [{"name": "opt 0", "value": "opt_0", "featureHash": "6n60OH3Q"}],
                        "featureHash": "JE/BiaGw",
                        "manualAnnotation": True,
                    },
                    {
                        "name": "radio nested radio",
                        "value": "radio_nested_radio",
                        "answers": [{"name": "opt 0", "value": "opt_0", "featureHash": "z29i8QS0"}],
                        "featureHash": "MVDBTicG",
                        "manualAnnotation": True,
                    },
                    {
                        "name": "radio",
                        "value": "radio",
                        "answers": [{"name": "radio 1", "value": "radio_1", "featureHash": "gxCMit/w"}],
                        "featureHash": "s+3ehT7T",
                        "manualAnnotation": True,
                    },
                ],
            },
            "DR9AdW+s": {
                "classificationHash": "DR9AdW+s",
                "classifications": [
                    {
                        "name": "checklist",
                        "value": "checklist",
                        "answers": [
                            {"name": "checklist 0", "value": "checklist_0", "featureHash": "Irh8Wgjq"},
                            {"name": "checklist 1", "value": "checklist_1", "featureHash": "fd/FLN0x"},
                        ],
                        "featureHash": "YtqQrGVm",
                        "manualAnnotation": True,
                    }
                ],
            },
            "+D7fEWJJ": {
                "classificationHash": "+D7fEWJJ",
                "classifications": [
                    {
                        "name": "text",
                        "value": "text",
                        "answers": "ergeg",
                        "featureHash": "hBo6zZds",
                        "manualAnnotation": True,
                    }
                ],
            },
        },
        "object_actions": {
            "P/9LI504": {
                "objectHash": "P/9LI504",
                "actions": [
                    {
                        "name": "box checklist",
                        "range": [[0, 0]],
                        "value": "box_checklist",
                        "answers": [
                            {"name": "box checklist", "value": "box_checklist_option_0", "featureHash": "lBbzV4El"}
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "UHclwXeD",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    },
                    {
                        "name": "box radio",
                        "range": [[0, 0]],
                        "value": "box_radio",
                        "answers": [{"name": "box radio", "value": "box_radio_option_0", "featureHash": "pCZJZTnj"}],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "u+4bIbCR",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    },
                ],
            },
            "sNRMQRZa": {
                "objectHash": "sNRMQRZa",
                "actions": [
                    {
                        "name": "polygon checklist",
                        "range": [[0, 0]],
                        "value": "polygon_checklist",
                        "answers": [
                            {
                                "name": "polygon checklist",
                                "value": "polygon_checklist_option_0",
                                "featureHash": "8kDCDHWL",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "PhRGDJdU",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
            "G0HipOAZ": {
                "objectHash": "G0HipOAZ",
                "actions": [
                    {
                        "name": "polygon text",
                        "range": [[0, 0]],
                        "value": "polygon_text",
                        "answers": "ggeeeg",
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "8wiMXlVz",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
            "S8y9TRAJ": {
                "objectHash": "S8y9TRAJ",
                "actions": [
                    {
                        "name": "bitmask radio",
                        "range": [[0, 0]],
                        "value": "bitmask_radio",
                        "answers": [
                            {"name": "bitmask radio", "value": "bitmask_radio_option_0", "featureHash": "exM6kLRQ"}
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "7tC1hS87",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    }
                ],
            },
            "jXUPS9nV": {
                "objectHash": "jXUPS9nV",
                "actions": [
                    {
                        "name": "skeleton checklist",
                        "range": [[0, 0]],
                        "value": "skeleton_checklist",
                        "answers": [
                            {
                                "name": "skeleton checklist",
                                "value": "skeleton_checklist_option_0",
                                "featureHash": "qL8VXCXm",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "51k+sOtO",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    },
                    {
                        "name": "skeleton checklist",
                        "range": [[0, 0]],
                        "value": "skeleton_checklist",
                        "answers": [
                            {
                                "name": "skeleton checklist",
                                "value": "skeleton_checklist_option_1",
                                "featureHash": "YHqgS4Mu",
                            }
                        ],
                        "dynamic": True,
                        "trackHash": "",
                        "featureHash": "51k+sOtO",
                        "shouldPropagate": False,
                        "manualAnnotation": True,
                    },
                ],
            },
        },
        "label_status": "LABEL_IN_PROGRESS",
        "export_history": [
            {
                "export_hash": UUID("b4668ae9-f0c3-4e89-b003-954f9a8f1741"),
                "exported_at": "Fri, 01 Dec 2023 11:18:14 UTC",
                "user_email": "adam@encord.com",
            },
            {
                "export_hash": UUID("df6109eb-1dac-4cc8-b419-304eaa52b4b6"),
                "exported_at": "Fri, 01 Dec 2023 11:17:24 UTC",
                "user_email": "adam@encord.com",
            },
        ],
        "export_hash": UUID("b4668ae9-f0c3-4e89-b003-954f9a8f1741"),
        "exported_at": "Fri, 01 Dec 2023 11:18:14 UTC",
    },
    {
        "label_hash": "6ccb4c2d-d54b-4299-b001-c1dc6dbec4e9",
        "branch_name": None,
        "created_at": datetime.datetime(2024, 6, 5, 12, 28, 14, 196777, tzinfo=datetime.timezone.utc),
        "last_edited_at": datetime.datetime(2024, 7, 18, 14, 0, 20, 329544, tzinfo=datetime.timezone.utc),
        "dataset_hash": "dbb8ab22-3893-48c6-b38f-1e1a3cc8bfec",
        "dataset_title": "test NIFTI",
        "data_title": "RIDER-1346917136_20000101-120021_01_chestct.nii.gz",
        "data_hash": "9cccbe15-4a1b-4374-bddf-8bf270a81b53",
        "data_type": "nifti",
        "is_image_sequence": None,
        "video_link": None,
        "data_units": {
            "9cccbe15-4a1b-4374-bddf-8bf270a81b53": {
                "data_hash": "9cccbe15-4a1b-4374-bddf-8bf270a81b53",
                "data_title": "RIDER-1346917136_20000101-120021_01_chestct.nii.gz",
                "data_type": "application/nifti1",
                "data_sequence": 0,
                "labels": {
                    "127": {
                        "objects": [
                            {
                                "featureHash": "ImO9dtQh",
                                "objectHash": "P/9LI504",
                                "name": "box",
                                "value": "box",
                                "color": "#D33115",
                                "shape": "bounding_box",
                                "confidence": 1,
                                "createdBy": "adam@encord.com",
                                "createdAt": "Fri, 01 Dec 2023 11:03:24 GMT",
                                "lastEditedBy": "adam@encord.com",
                                "lastEditedAt": "Fri, 01 Dec 2023 11:03:48 GMT",
                                "manualAnnotation": True,
                                "boundingBox": {"x": 0.0877, "y": 0.2134, "w": 0.1221, "h": 0.1667},
                            },
                        ],
                        "classifications": [],
                    }
                },
                "data_link": "cord-nifti-dev/UoSJBO7DltRjF8b9aem7WOLrFrm2/9cccbe15-4a1b-4374-bddf-8bf270a81b53",
                "width": 512,
                "height": 512,
            }
        },
        "object_answers": {
            "P/9LI504": {
                "objectHash": "P/9LI504",
                "classifications": [
                    {
                        "name": "box text",
                        "value": "box_text",
                        "answers": "4rfw",
                        "featureHash": "E6Wai5ZG",
                        "manualAnnotation": True,
                    }
                ],
            },
        },
        "classification_answers": {},
        "object_actions": {},
        "label_status": "LABELLED",
        "is_valid": True,
        "export_hash": UUID("23f99935-cca7-4c7d-8987-44e46a00b392"),
        "exported_at": "Fri, 19 Jul 2024 09:20:25 UTC",
        "export_history": [
            {
                "export_hash": UUID("625aea31-6d63-4623-b9aa-ed8d89f1db14"),
                "exported_at": "Thu, 18 Jul 2024 13:07:59 UTC",
                "user_email": "clinton@encord.com",
            },
        ],
    },
]

ONTOLOGY_STRUCTURE_DICT = {
    "objects": [
        {
            "id": "1",
            "name": "box",
            "color": "#D33115",
            "shape": "bounding_box",
            "required": False,
            "attributes": [
                {
                    "id": "1.1",
                    "name": "box radio",
                    "type": "radio",
                    "dynamic": True,
                    "options": [
                        {
                            "id": "1.1.1",
                            "label": "box radio option 0",
                            "value": "box_radio_option_0",
                            "featureNodeHash": "pCZJZTnj",
                        },
                        {
                            "id": "1.1.2",
                            "label": "box radio option 1",
                            "value": "box_radio_option_1",
                            "featureNodeHash": "wTSXji2I",
                        },
                    ],
                    "required": True,
                    "featureNodeHash": "u+4bIbCR",
                },
                {
                    "id": "1.2",
                    "name": "box text",
                    "type": "text",
                    "dynamic": False,
                    "required": True,
                    "featureNodeHash": "E6Wai5ZG",
                },
                {
                    "id": "1.3",
                    "name": "box checklist",
                    "type": "checklist",
                    "dynamic": True,
                    "options": [
                        {
                            "id": "1.3.1",
                            "label": "box checklist option 0",
                            "value": "box_checklist_option_0",
                            "featureNodeHash": "lBbzV4El",
                        },
                        {
                            "id": "1.3.2",
                            "label": "box checklist option 1",
                            "value": "box_checklist_option_1",
                            "featureNodeHash": "teq8aIDY",
                        },
                    ],
                    "required": False,
                    "featureNodeHash": "UHclwXeD",
                },
            ],
            "featureNodeHash": "ImO9dtQh",
        },
        {
            "id": "2",
            "name": "rotatable box",
            "color": "#E27300",
            "shape": "rotatable_bounding_box",
            "required": True,
            "attributes": [
                {
                    "id": "2.1",
                    "name": "rotatable box radio",
                    "type": "radio",
                    "dynamic": False,
                    "options": [
                        {
                            "id": "2.1.1",
                            "label": "rotatable box radio option 0",
                            "value": "rotatable_box_radio_option_0",
                            "featureNodeHash": "SIEdjcuH",
                        },
                        {
                            "id": "2.1.2",
                            "label": "rotatable box radio option 1",
                            "value": "rotatable_box_radio_option_1",
                            "featureNodeHash": "Ms0a5hnw",
                        },
                    ],
                    "required": True,
                    "featureNodeHash": "LCek15f3",
                }
            ],
            "featureNodeHash": "NBMDpwcd",
        },
        {
            "id": "3",
            "name": "polygon",
            "color": "#16406C",
            "shape": "polygon",
            "required": False,
            "attributes": [
                {
                    "id": "3.1",
                    "name": "polygon checklist",
                    "type": "checklist",
                    "dynamic": True,
                    "options": [
                        {
                            "id": "3.1.1",
                            "label": "polygon checklist option 0",
                            "value": "polygon_checklist_option_0",
                            "featureNodeHash": "8kDCDHWL",
                        },
                        {
                            "id": "3.1.2",
                            "label": "polygon checklist option 1",
                            "value": "polygon_checklist_option_1",
                            "featureNodeHash": "sj7I7lsB",
                        },
                    ],
                    "required": False,
                    "featureNodeHash": "PhRGDJdU",
                }
            ],
            "featureNodeHash": "gr3562OV",
        },
        {
            "id": "4",
            "name": "polyline",
            "color": "#FE9200",
            "shape": "polyline",
            "required": True,
            "attributes": [
                {
                    "id": "4.1",
                    "name": "polygon text",
                    "type": "text",
                    "dynamic": True,
                    "required": False,
                    "featureNodeHash": "8wiMXlVz",
                }
            ],
            "featureNodeHash": "SKRR+bNg",
        },
        {
            "id": "5",
            "name": "bitmask",
            "color": "#FCDC00",
            "shape": "bitmask",
            "required": False,
            "attributes": [
                {
                    "id": "5.1",
                    "name": "bitmask radio",
                    "type": "radio",
                    "dynamic": True,
                    "options": [
                        {
                            "id": "5.1.1",
                            "label": "bitmask radio option 0",
                            "value": "bitmask_radio_option_0",
                            "featureNodeHash": "exM6kLRQ",
                        },
                        {
                            "id": "5.1.2",
                            "label": "bitmask radio option 1",
                            "value": "bitmask_radio_option_1",
                            "featureNodeHash": "a9ZztiRl",
                        },
                    ],
                    "required": False,
                    "featureNodeHash": "7tC1hS87",
                }
            ],
            "featureNodeHash": "hN0/lF+8",
        },
        {
            "id": "6",
            "name": "keypoint",
            "color": "#DBDF00",
            "shape": "point",
            "required": True,
            "attributes": [
                {
                    "id": "6.1",
                    "name": "keypoint text",
                    "type": "text",
                    "dynamic": True,
                    "required": True,
                    "featureNodeHash": "73XckWFd",
                }
            ],
            "featureNodeHash": "bhkdPLGR",
        },
        {
            "id": "7",
            "name": "skeleton",
            "color": "#A4DD00",
            "shape": "skeleton",
            "required": False,
            "attributes": [
                {
                    "id": "7.1",
                    "name": "skeleton checklist",
                    "type": "checklist",
                    "dynamic": True,
                    "options": [
                        {
                            "id": "7.1.1",
                            "label": "skeleton checklist option 0",
                            "value": "skeleton_checklist_option_0",
                            "featureNodeHash": "qL8VXCXm",
                        },
                        {
                            "id": "7.1.2",
                            "label": "skeleton checklist option 1",
                            "value": "skeleton_checklist_option_1",
                            "featureNodeHash": "YHqgS4Mu",
                        },
                    ],
                    "required": True,
                    "featureNodeHash": "51k+sOtO",
                }
            ],
            "featureNodeHash": "68gUGGu7",
        },
    ],
    "classifications": [
        {
            "id": "1",
            "attributes": [
                {
                    "id": "1.1",
                    "name": "radio",
                    "type": "radio",
                    "dynamic": False,
                    "options": [
                        {
                            "id": "1.1.1",
                            "label": "radio 0",
                            "value": "radio_0",
                            "options": [],
                            "featureNodeHash": "jBISfIky",
                        },
                        {
                            "id": "1.1.2",
                            "label": "radio 1",
                            "value": "radio_1",
                            "options": [
                                {
                                    "id": "1.1.2.1",
                                    "name": "radio nested radio",
                                    "type": "radio",
                                    "options": [
                                        {
                                            "id": "1.1.2.1.1",
                                            "label": "opt 0",
                                            "value": "opt_0",
                                            "options": [],
                                            "featureNodeHash": "z29i8QS0",
                                        },
                                        {
                                            "id": "1.1.2.1.2",
                                            "label": "opt 1",
                                            "value": "opt_1",
                                            "options": [],
                                            "featureNodeHash": "8j3CaCjU",
                                        },
                                    ],
                                    "required": False,
                                    "featureNodeHash": "MVDBTicG",
                                },
                                {
                                    "id": "1.1.2.2",
                                    "name": "radio nested checklist",
                                    "type": "checklist",
                                    "options": [
                                        {
                                            "id": "1.1.2.2.1",
                                            "label": "opt 0",
                                            "value": "opt_0",
                                            "featureNodeHash": "6n60OH3Q",
                                        },
                                        {
                                            "id": "1.1.2.2.2",
                                            "label": "opt 1",
                                            "value": "opt_1",
                                            "featureNodeHash": "HhB+tsH2",
                                        },
                                    ],
                                    "required": False,
                                    "featureNodeHash": "JE/BiaGw",
                                },
                                {
                                    "id": "1.1.2.3",
                                    "name": "radio nested text",
                                    "type": "text",
                                    "required": False,
                                    "featureNodeHash": "tY6bNKl3",
                                },
                            ],
                            "featureNodeHash": "gxCMit/w",
                        },
                    ],
                    "required": False,
                    "featureNodeHash": "s+3ehT7T",
                }
            ],
            "featureNodeHash": "R3daKWYA",
        },
        {
            "id": "2",
            "attributes": [
                {
                    "id": "2.1",
                    "name": "checklist",
                    "type": "checklist",
                    "dynamic": False,
                    "options": [
                        {"id": "2.1.1", "label": "checklist 0", "value": "checklist_0", "featureNodeHash": "Irh8Wgjq"},
                        {"id": "2.1.2", "label": "checklist 1", "value": "checklist_1", "featureNodeHash": "fd/FLN0x"},
                    ],
                    "required": True,
                    "featureNodeHash": "YtqQrGVm",
                }
            ],
            "featureNodeHash": "is0CLEV9",
        },
        {
            "id": "3",
            "attributes": [
                {
                    "id": "3.1",
                    "name": "text",
                    "type": "text",
                    "dynamic": False,
                    "required": False,
                    "featureNodeHash": "hBo6zZds",
                }
            ],
            "featureNodeHash": "NW40sdPd",
        },
    ],
}

COCO_EXPORTER_EXPECTED_RES = {
    "info": {
        "description": "dicom",
        "contributor": None,
        "date_created": None,
        "url": None,
        "version": None,
        "year": None,
    },
    "categories": [
        {"supercategory": "bounding_box", "id": 1, "name": "box"},
        {"supercategory": "rotatable_bounding_box", "id": 2, "name": "rotatable box"},
        {"supercategory": "polygon", "id": 3, "name": "polygon"},
        {"supercategory": "polyline", "id": 4, "name": "polyline"},
        {"supercategory": "bitmask", "id": 5, "name": "bitmask"},
        {"supercategory": "point", "id": 6, "name": "keypoint", "keypoints": "keypoint", "skeleton": []},
        {"supercategory": "skeleton", "id": 7, "name": "skeleton"},
    ],
    "images": [
        {
            "coco_url": "cord-dicoms-dev/fOG7LpSlbyVNLFE1tKOFN1GMOBE2/851fecfe-34cc-4b1e-b40c-35ed7b028668",
            "id": 0,
            "file_name": "dicom/87ffc8da-f005-45a3-b89f-e6086bd90fa7/1.3.6.1.4.1.5962.99.1.1761388472.1291962045.1616669124536.2802.0",
            "height": 512,
            "width": 512,
        },
        {
            "coco_url": "",
            "id": 1,
            "file_name": "dicom/87ffc8da-f005-45a3-b89f-e6086bd90fa7/1",
            "height": 512,
            "width": 512,
        },
        {
            "coco_url": "cord-images-dev/fOG7LpSlbyVNLFE1tKOFN1GMOBE2/e7a67a81-af54-4d6b-9838-ff11bba0d95c",
            "id": 2,
            "image_title": "1.png",
            "file_name": "images/c7c18bd0-bf07-4f5b-a8a8-f402b346097a.png",
            "height": 400,
            "width": 400,
        },
        {
            "coco_url": "cord-images-dev/fOG7LpSlbyVNLFE1tKOFN1GMOBE2/576558d7-b111-4f5d-939e-81c3d99a236a",
            "id": 3,
            "image_title": "2.png",
            "file_name": "images/839d6a14-a063-494a-96e5-3cb46124158e.png",
            "height": 400,
            "width": 400,
        },
        {
            "coco_url": "cord-videos-dev/fOG7LpSlbyVNLFE1tKOFN1GMOBE2/9f4a92e8-c53a-4689-8531-f44e6bc7b03b",
            "id": 4,
            "video_title": "video.mp4",
            "file_name": "videos/9f4a92e8-c53a-4689-8531-f44e6bc7b03b/0.jpg",
            "height": 400,
            "width": 400,
        },
        {
            "coco_url": "cord-videos-dev/fOG7LpSlbyVNLFE1tKOFN1GMOBE2/9f4a92e8-c53a-4689-8531-f44e6bc7b03b",
            "id": 5,
            "video_title": "video.mp4",
            "file_name": "videos/9f4a92e8-c53a-4689-8531-f44e6bc7b03b/1.jpg",
            "height": 400,
            "width": 400,
        },
        {
            "coco_url": "cord-images-dev/fOG7LpSlbyVNLFE1tKOFN1GMOBE2/a07d3ef6-91f3-4184-a7f6-a36c0324ca1d",
            "id": 6,
            "image_title": "1.png",
            "file_name": "images/de5d8787-683d-41d5-9356-1944bb07aadf.png",
            "height": 400,
            "width": 400,
        },
        {
            "coco_url": "cord-images-dev/fOG7LpSlbyVNLFE1tKOFN1GMOBE2/d411a847-7f0e-4603-896a-373b98a6923a",
            "id": 7,
            "image_title": "2.png",
            "file_name": "images/2962623e-f58b-421c-ab8f-e3d577effe86.png",
            "height": 400,
            "width": 400,
        },
        {
            "coco_url": "cord-images-dev/fOG7LpSlbyVNLFE1tKOFN1GMOBE2/9cee5450-b2a2-47cb-a9e9-2eb5ec8499dd",
            "id": 8,
            "image_title": "image.png",
            "file_name": "images/9cee5450-b2a2-47cb-a9e9-2eb5ec8499dd.png",
            "height": 400,
            "width": 400,
        },
        {
            "coco_url": "cord-nifti-dev/UoSJBO7DltRjF8b9aem7WOLrFrm2/9cccbe15-4a1b-4374-bddf-8bf270a81b53",
            "id": 9,
            "file_name": "nifti/9cccbe15-4a1b-4374-bddf-8bf270a81b53/127",
            "height": 512,
            "width": 512,
        },
    ],
    "annotations": [
        {
            "area": 3446.1135667199997,
            "bbox": [122.6752, 88.8832, 51.8144, 66.5088],
            "category_id": 1,
            "image_id": 0,
            "iscrowd": 0,
            "segmentation": [[122.6752, 88.8832, 174.4896, 88.8832, 174.4896, 155.392, 122.6752, 155.392]],
            "keypoints": None,
            "num_keypoints": None,
            "id": 0,
            "attributes": {
                "track_id": 0,
                "encord_track_uuid": "R7OjJwum",
                "classifications": {
                    "box text": "wfwfwfw",
                    "box checklist option 0": False,
                    "box checklist option 1": False,
                    "box radio": "box radio",
                },
                "manual_annotation": True,
            },
        },
        {
            "area": 2348.5349887999996,
            "bbox": [217.5488, 99.2256, 45.824, 51.2512],
            "category_id": 2,
            "image_id": 0,
            "iscrowd": 0,
            "segmentation": [[217.5488, 99.2256, 263.3728, 99.2256, 263.3728, 150.4768, 217.5488, 150.4768]],
            "keypoints": None,
            "num_keypoints": None,
            "id": 1,
            "attributes": {
                "track_id": 1,
                "encord_track_uuid": "aKjphpff",
                "rotation": 19.2854,
                "classifications": {"rotatable box radio": "rotatable box radio option 0"},
                "manual_annotation": True,
            },
        },
        {
            "area": 1221.9200307200003,
            "bbox": [288.768, 122.2144, 58.11200000000002, 35.9936],
            "category_id": 3,
            "image_id": 0,
            "iscrowd": 0,
            "segmentation": [
                [306.3808, 122.2144, 288.768, 156.928, 346.88, 158.208, 328.704, 128.0, 320.3072, 133.2224]
            ],
            "keypoints": None,
            "num_keypoints": None,
            "id": 2,
            "attributes": {
                "track_id": 2,
                "encord_track_uuid": "4xsGCIXj",
                "classifications": {"polygon checklist option 0": False, "polygon checklist option 1": True},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [192.256, 176.64, 79.15520000000001, 57.85600000000002],
            "category_id": 4,
            "image_id": 0,
            "iscrowd": 0,
            "segmentation": [
                [
                    200.9088,
                    176.896,
                    192.256,
                    207.1552,
                    241.92,
                    234.496,
                    271.4112,
                    203.4688,
                    255.6416,
                    184.2688,
                    227.4816,
                    176.64,
                    227.4816,
                    176.64,
                    255.6416,
                    184.2688,
                    271.4112,
                    203.4688,
                    241.92,
                    234.496,
                    192.256,
                    207.1552,
                    200.9088,
                    176.896,
                ]
            ],
            "keypoints": None,
            "num_keypoints": None,
            "id": 3,
            "attributes": {
                "track_id": 3,
                "encord_track_uuid": "Gjx8EgkI",
                "classifications": {"polygon text": "fwfwe"},
                "manual_annotation": True,
            },
        },
        {
            "area": 1963.0,
            "bbox": [148.0, 230.0, 65.0, 41.0],
            "category_id": 5,
            "image_id": 0,
            "iscrowd": 1,
            "segmentation": {
                "size": [512, 512],
                "counts": "eWZ26f?7K4M3L3N2N2N101N2N2O1O1N101O00001O00001O01O00100O1O101N2NO10000O100000000000O100000000000000O10000O101O0O101N101O1N1O2N2N3M3L4J[Xe4",
            },
            "keypoints": None,
            "num_keypoints": None,
            "id": 4,
            "attributes": {
                "track_id": 4,
                "encord_track_uuid": "2gjDymr4",
                "classifications": {"bitmask radio": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [255.6416, 255.7952, 0.0, 0.0],
            "category_id": 6,
            "image_id": 0,
            "iscrowd": 0,
            "segmentation": [[255.6416, 255.7952]],
            "keypoints": [255.6416, 255.7952, 2.0],
            "num_keypoints": 1,
            "id": 5,
            "attributes": {
                "track_id": 5,
                "encord_track_uuid": "/bxlR5g2",
                "classifications": {"keypoint text": "gergg"},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [179.968, 287.9488, 38.912000000000006, 37.88799999999998],
            "category_id": 7,
            "image_id": 0,
            "iscrowd": 0,
            "segmentation": [],
            "keypoints": [
                218.112,
                324.9664,
                0.0,
                204.0832,
                312.7808,
                1.0,
                184.7808,
                325.8368,
                2.0,
                204.2368,
                298.5984,
                2.0,
                218.88,
                304.0256,
                2.0,
                179.968,
                302.5408,
                2.0,
                203.264,
                287.9488,
                0.0,
            ],
            "num_keypoints": 7,
            "id": 6,
            "attributes": {
                "track_id": 6,
                "encord_track_uuid": "g2H23XHg",
                "classifications": {"skeleton checklist option 0": False, "skeleton checklist option 1": False},
                "manual_annotation": True,
            },
        },
        {
            "area": 2404.56,
            "bbox": [17.96, 76.52, 46.6, 51.6],
            "category_id": 1,
            "image_id": 2,
            "iscrowd": 0,
            "segmentation": [[17.96, 76.52, 64.56, 76.52, 64.56, 128.12, 17.96, 128.12]],
            "keypoints": None,
            "num_keypoints": None,
            "id": 7,
            "attributes": {
                "track_id": 7,
                "encord_track_uuid": "Or2a460b",
                "classifications": {
                    "box text": "wefwfw",
                    "box radio": None,
                    "box checklist option 0": False,
                    "box checklist option 1": False,
                },
                "manual_annotation": True,
            },
        },
        {
            "area": 1641.4463999999998,
            "bbox": [94.52000000000001, 76.52, 32.16, 51.04],
            "category_id": 2,
            "image_id": 2,
            "iscrowd": 0,
            "segmentation": [[94.52000000000001, 76.52, 126.68, 76.52, 126.68, 127.56, 94.52000000000001, 127.56]],
            "keypoints": None,
            "num_keypoints": None,
            "id": 8,
            "attributes": {
                "track_id": 8,
                "encord_track_uuid": "EZ89BXK+",
                "rotation": 16.6182,
                "classifications": {"rotatable box radio": "rotatable box radio option 0"},
                "manual_annotation": True,
            },
        },
        {
            "area": 1391.3920000000012,
            "bbox": [148.32, 77.64, 38.28000000000003, 54.36],
            "category_id": 3,
            "image_id": 2,
            "iscrowd": 0,
            "segmentation": [
                [
                    177.72,
                    77.64,
                    148.32,
                    97.04,
                    148.32,
                    125.36,
                    171.08,
                    132.0,
                    184.4,
                    100.92000000000002,
                    186.60000000000002,
                    85.96000000000001,
                ]
            ],
            "keypoints": None,
            "num_keypoints": None,
            "id": 9,
            "attributes": {
                "track_id": 9,
                "encord_track_uuid": "K9lwknkQ",
                "classifications": {"polygon checklist option 0": False, "polygon checklist option 1": False},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [202.11999999999998, 82.64, 47.720000000000056, 95.96],
            "category_id": 4,
            "image_id": 2,
            "iscrowd": 0,
            "segmentation": [
                [
                    210.48,
                    82.64,
                    202.11999999999998,
                    113.16,
                    204.92,
                    131.44,
                    224.88000000000002,
                    145.32,
                    246.51999999999998,
                    139.76,
                    249.84000000000003,
                    164.2,
                    234.32,
                    178.6,
                    234.32,
                    178.6,
                    249.84000000000003,
                    164.2,
                    246.51999999999998,
                    139.76,
                    224.88000000000002,
                    145.32,
                    204.92,
                    131.44,
                    202.11999999999998,
                    113.16,
                    210.48,
                    82.64,
                ]
            ],
            "keypoints": None,
            "num_keypoints": None,
            "id": 10,
            "attributes": {
                "track_id": 10,
                "encord_track_uuid": "EoZuR/9p",
                "classifications": {"polygon text": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 2171.0,
            "bbox": [261.0, 79.0, 39.0, 79.0],
            "category_id": 5,
            "image_id": 2,
            "iscrowd": 1,
            "segmentation": {
                "size": [400, 400],
                "counts": "YQV3:S<9I4K4N3K4N2M3N1N4SEROR:i1M1O2N1O1O001O0010O010O001O1O1O2N2M6K5K2M3M2O2M3M4L3L6I8_OcnV1",
            },
            "keypoints": None,
            "num_keypoints": None,
            "id": 11,
            "attributes": {
                "track_id": 11,
                "encord_track_uuid": "6kA+Tvfx",
                "classifications": {"bitmask radio": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [328.08000000000004, 91.52, 0.0, 0.0],
            "category_id": 6,
            "image_id": 2,
            "iscrowd": 0,
            "segmentation": [[328.08000000000004, 91.52]],
            "keypoints": [328.08000000000004, 91.52, 2.0],
            "num_keypoints": 1,
            "id": 12,
            "attributes": {
                "track_id": 12,
                "encord_track_uuid": "nyOrUeAW",
                "classifications": {"keypoint text": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [330.03999999999996, 98.68, 28.840000000000032, 53.24000000000001],
            "category_id": 7,
            "image_id": 2,
            "iscrowd": 0,
            "segmentation": [],
            "keypoints": [
                358.28000000000003,
                150.72,
                2.0,
                347.88,
                133.6,
                2.0,
                333.59999999999997,
                151.92000000000002,
                2.0,
                348.04,
                113.68,
                2.0,
                358.88,
                121.32000000000001,
                2.0,
                330.03999999999996,
                119.19999999999999,
                2.0,
                347.28,
                98.68,
                2.0,
            ],
            "num_keypoints": 7,
            "id": 13,
            "attributes": {
                "track_id": 13,
                "encord_track_uuid": "WrYyw+oP",
                "classifications": {"skeleton checklist option 0": False, "skeleton checklist option 1": False},
                "manual_annotation": True,
            },
        },
        {
            "area": 1113.3135999999997,
            "bbox": [29.04, 138.68, 29.959999999999997, 37.16],
            "category_id": 1,
            "image_id": 3,
            "iscrowd": 0,
            "segmentation": [[29.04, 138.68, 59.0, 138.68, 59.0, 175.84, 29.04, 175.84]],
            "keypoints": None,
            "num_keypoints": None,
            "id": 14,
            "attributes": {
                "track_id": 14,
                "encord_track_uuid": "RUlxBBGp",
                "classifications": {
                    "box text": "erge",
                    "box radio": None,
                    "box checklist option 0": False,
                    "box checklist option 1": False,
                },
                "manual_annotation": True,
            },
        },
        {
            "area": 566.544,
            "bbox": [100.6, 143.64, 22.2, 25.52],
            "category_id": 2,
            "image_id": 3,
            "iscrowd": 0,
            "segmentation": [[100.6, 143.64, 122.8, 143.64, 122.8, 169.16, 100.6, 169.16]],
            "keypoints": None,
            "num_keypoints": None,
            "id": 15,
            "attributes": {
                "track_id": 15,
                "encord_track_uuid": "KwpUEmos",
                "rotation": 15.0434,
                "classifications": {"rotatable box radio": "rotatable box radio option 0"},
                "manual_annotation": True,
            },
        },
        {
            "area": 2203.131199999998,
            "bbox": [147.76, 147.56, 73.79999999999998, 59.87999999999997],
            "category_id": 3,
            "image_id": 3,
            "iscrowd": 0,
            "segmentation": [
                [177.72, 147.56, 147.76, 190.24, 174.4, 207.43999999999997, 221.55999999999997, 186.35999999999999]
            ],
            "keypoints": None,
            "num_keypoints": None,
            "id": 16,
            "attributes": {
                "track_id": 16,
                "encord_track_uuid": "Aya79dpB",
                "classifications": {"polygon checklist option 0": False, "polygon checklist option 1": False},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [247.64, 156.4, 43.27999999999997, 86.56],
            "category_id": 4,
            "image_id": 3,
            "iscrowd": 0,
            "segmentation": [
                [
                    290.36,
                    156.4,
                    247.64,
                    204.68,
                    253.72,
                    218.56,
                    283.12,
                    242.96,
                    290.91999999999996,
                    224.12,
                    288.68,
                    211.87999999999997,
                    288.68,
                    211.87999999999997,
                    290.91999999999996,
                    224.12,
                    283.12,
                    242.96,
                    253.72,
                    218.56,
                    247.64,
                    204.68,
                    290.36,
                    156.4,
                ]
            ],
            "keypoints": None,
            "num_keypoints": None,
            "id": 17,
            "attributes": {
                "track_id": 17,
                "encord_track_uuid": "Zy5PjiQu",
                "classifications": {"polygon text": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 1991.0,
            "bbox": [300.0, 158.0, 42.0, 71.0],
            "category_id": 5,
            "image_id": 3,
            "iscrowd": 1,
            "segmentation": {
                "size": [400, 400],
                "counts": "Y[e37V<6K4M2N2M3O1N4M9F<E3M4L4L2N2N1O1O1O1O010O010O02N1O1O1O1O1O1O2N2N2M3N6I8H9G7I4L4K6H_^f0",
            },
            "keypoints": None,
            "num_keypoints": None,
            "id": 18,
            "attributes": {
                "track_id": 18,
                "encord_track_uuid": "1oSpiaDM",
                "classifications": {"bitmask radio": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [360.24, 181.4, 0.0, 0.0],
            "category_id": 6,
            "image_id": 3,
            "iscrowd": 0,
            "segmentation": [[360.24, 181.4]],
            "keypoints": [360.24, 181.4, 2.0],
            "num_keypoints": 1,
            "id": 19,
            "attributes": {
                "track_id": 19,
                "encord_track_uuid": "3lLDdvLz",
                "classifications": {"keypoint text": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [342.52, 232.52, 44.920000000000016, 43.83999999999995],
            "category_id": 7,
            "image_id": 3,
            "iscrowd": 0,
            "segmentation": [],
            "keypoints": [
                386.52000000000004,
                275.4,
                2.0,
                370.32,
                261.32,
                2.0,
                348.08,
                276.35999999999996,
                2.0,
                370.52,
                244.88,
                2.0,
                387.44,
                251.2,
                2.0,
                342.52,
                249.44000000000003,
                2.0,
                369.36,
                232.52,
                2.0,
            ],
            "num_keypoints": 7,
            "id": 20,
            "attributes": {
                "track_id": 20,
                "encord_track_uuid": "8M1VEyNi",
                "classifications": {"skeleton checklist option 0": False, "skeleton checklist option 1": False},
                "manual_annotation": True,
            },
        },
        {
            "area": 3291.288,
            "bbox": [19.16, 85.84, 60.28, 54.6],
            "category_id": 1,
            "image_id": 4,
            "iscrowd": 0,
            "segmentation": [[19.16, 85.84, 79.44, 85.84, 79.44, 140.44, 19.16, 140.44]],
            "keypoints": None,
            "num_keypoints": None,
            "id": 21,
            "attributes": {
                "track_id": 21,
                "encord_track_uuid": "JnrA7H0x",
                "classifications": {
                    "box text": None,
                    "box radio": None,
                    "box checklist option 0": False,
                    "box checklist option 1": False,
                },
                "manual_annotation": True,
            },
        },
        {
            "area": 3126.8207999999995,
            "bbox": [178.0, 105.67999999999999, 40.44, 77.32],
            "category_id": 2,
            "image_id": 4,
            "iscrowd": 0,
            "segmentation": [[178.0, 105.67999999999999, 218.44, 105.67999999999999, 218.44, 183.0, 178.0, 183.0]],
            "keypoints": None,
            "num_keypoints": None,
            "id": 22,
            "attributes": {
                "track_id": 22,
                "encord_track_uuid": "I2uztqvP",
                "rotation": 28.6819,
                "classifications": {"rotatable box radio": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 3124.282400000001,
            "bbox": [302.12, 135.48, 65.24000000000001, 80.12000000000003],
            "category_id": 3,
            "image_id": 4,
            "iscrowd": 0,
            "segmentation": [
                [
                    351.76,
                    135.48,
                    302.12,
                    162.44,
                    314.2,
                    214.2,
                    339.72,
                    215.60000000000002,
                    360.28,
                    185.84,
                    348.24,
                    155.32,
                    367.36,
                    146.8,
                ]
            ],
            "keypoints": None,
            "num_keypoints": None,
            "id": 23,
            "attributes": {
                "track_id": 23,
                "encord_track_uuid": "e4Fh0Atj",
                "classifications": {"polygon checklist option 0": False, "polygon checklist option 1": False},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [63.12, 181.56, 82.96000000000001, 54.640000000000015],
            "category_id": 4,
            "image_id": 4,
            "iscrowd": 0,
            "segmentation": [
                [
                    109.2,
                    181.56,
                    63.12,
                    219.88,
                    104.24,
                    236.20000000000002,
                    125.52000000000001,
                    228.35999999999999,
                    146.08,
                    200.72,
                    146.08,
                    200.72,
                    125.52000000000001,
                    228.35999999999999,
                    104.24,
                    236.20000000000002,
                    63.12,
                    219.88,
                    109.2,
                    181.56,
                ]
            ],
            "keypoints": None,
            "num_keypoints": None,
            "id": 24,
            "attributes": {
                "track_id": 24,
                "encord_track_uuid": "MJto5XSv",
                "classifications": {"polygon text": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 3141.0,
            "bbox": [170.0, 224.0, 78.0, 53.0],
            "category_id": 5,
            "image_id": 4,
            "iscrowd": 1,
            "segmentation": {
                "size": [400, 400],
                "counts": "PeR22Y<:H5L4M2M3N2N3M101N2N1O2N1O1O2O0O100O101N10000O100O100O10000O100000O0101O000O100000000O1000O10000O10000O1O1O1O1O1O1O1O1N2N201N10001O1N101N2O0O3M2N2N3L4L5JcTk1",
            },
            "keypoints": None,
            "num_keypoints": None,
            "id": 25,
            "attributes": {
                "track_id": 25,
                "encord_track_uuid": "f0MmrCk0",
                "classifications": {"bitmask radio": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [321.28000000000003, 261.71999999999997, 0.0, 0.0],
            "category_id": 6,
            "image_id": 4,
            "iscrowd": 0,
            "segmentation": [[321.28000000000003, 261.71999999999997]],
            "keypoints": [321.28000000000003, 261.71999999999997, 2.0],
            "num_keypoints": 1,
            "id": 26,
            "attributes": {
                "track_id": 26,
                "encord_track_uuid": "u3X0x0di",
                "classifications": {"keypoint text": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [9.84, 255.76, 34.760000000000005, 45.400000000000034],
            "category_id": 7,
            "image_id": 4,
            "iscrowd": 0,
            "segmentation": [],
            "keypoints": [
                43.88,
                300.15999999999997,
                2.0,
                31.319999999999997,
                285.56,
                2.0,
                14.12,
                301.16,
                2.0,
                31.52,
                268.56,
                2.0,
                44.6,
                275.08,
                2.0,
                9.84,
                273.28000000000003,
                2.0,
                30.599999999999998,
                255.76,
                2.0,
            ],
            "num_keypoints": 7,
            "id": 27,
            "attributes": {
                "track_id": 27,
                "encord_track_uuid": "YK1gFlRi",
                "classifications": {"skeleton checklist option 0": False, "skeleton checklist option 1": False},
                "manual_annotation": True,
            },
        },
        {
            "area": 2999.4624,
            "bbox": [150.36, 149.64, 63.12, 47.52],
            "category_id": 1,
            "image_id": 5,
            "iscrowd": 0,
            "segmentation": [[150.36, 149.64, 213.48000000000002, 149.64, 213.48000000000002, 197.16, 150.36, 197.16]],
            "keypoints": None,
            "num_keypoints": None,
            "id": 28,
            "attributes": {
                "track_id": 21,
                "encord_track_uuid": "JnrA7H0x",
                "classifications": {
                    "box text": None,
                    "box radio": None,
                    "box checklist option 0": False,
                    "box checklist option 1": False,
                },
                "manual_annotation": True,
            },
        },
        {
            "area": 2113.1040000000003,
            "bbox": [276.6, 185.12, 53.2, 39.72],
            "category_id": 2,
            "image_id": 5,
            "iscrowd": 0,
            "segmentation": [[276.6, 185.12, 329.8, 185.12, 329.8, 224.84, 276.6, 224.84]],
            "keypoints": None,
            "num_keypoints": None,
            "id": 29,
            "attributes": {
                "track_id": 22,
                "encord_track_uuid": "I2uztqvP",
                "rotation": 32.0179,
                "classifications": {"rotatable box radio": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 2588.0632,
            "bbox": [29.799999999999997, 163.12, 72.32000000000001, 63.120000000000005],
            "category_id": 3,
            "image_id": 5,
            "iscrowd": 0,
            "segmentation": [[74.48, 163.12, 29.799999999999997, 192.2, 55.32, 217.04, 97.16, 226.24, 102.12, 200.72]],
            "keypoints": None,
            "num_keypoints": None,
            "id": 30,
            "attributes": {
                "track_id": 23,
                "encord_track_uuid": "e4Fh0Atj",
                "classifications": {"polygon checklist option 0": False, "polygon checklist option 1": False},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [41.120000000000005, 247.52, 136.20000000000002, 17.72],
            "category_id": 4,
            "image_id": 5,
            "iscrowd": 0,
            "segmentation": [
                [
                    41.120000000000005,
                    247.52,
                    61.72,
                    265.24,
                    93.60000000000001,
                    263.12,
                    125.52000000000001,
                    248.24,
                    173.04,
                    254.64000000000001,
                    177.32000000000002,
                    258.15999999999997,
                    177.32000000000002,
                    258.15999999999997,
                    173.04,
                    254.64000000000001,
                    125.52000000000001,
                    248.24,
                    93.60000000000001,
                    263.12,
                    61.72,
                    265.24,
                    41.120000000000005,
                    247.52,
                ]
            ],
            "keypoints": None,
            "num_keypoints": None,
            "id": 31,
            "attributes": {
                "track_id": 24,
                "encord_track_uuid": "MJto5XSv",
                "classifications": {"polygon text": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 1567.0,
            "bbox": [210.0, 234.0, 47.0, 43.0],
            "category_id": 5,
            "image_id": 5,
            "iscrowd": 1,
            "segmentation": {
                "size": [400, 400],
                "counts": "hXb2<Q<7J4L3M4N1N2N2O0O2N101O0O101O00001O00001O000001O00001O1O0O2O1O1O1N10001N101N2O0O2N3M2M4M3K9Eccg1",
            },
            "keypoints": None,
            "num_keypoints": None,
            "id": 32,
            "attributes": {
                "track_id": 25,
                "encord_track_uuid": "f0MmrCk0",
                "classifications": {"bitmask radio": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [57.440000000000005, 144.0, 0.0, 0.0],
            "category_id": 6,
            "image_id": 5,
            "iscrowd": 0,
            "segmentation": [[57.440000000000005, 144.0]],
            "keypoints": [57.440000000000005, 144.0, 2.0],
            "num_keypoints": 1,
            "id": 33,
            "attributes": {
                "track_id": 26,
                "encord_track_uuid": "u3X0x0di",
                "classifications": {"keypoint text": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [126.84, 210.44, 34.76000000000002, 25.519999999999982],
            "category_id": 7,
            "image_id": 5,
            "iscrowd": 0,
            "segmentation": [],
            "keypoints": [
                160.88,
                235.4,
                2.0,
                148.32,
                227.2,
                2.0,
                131.12,
                235.95999999999998,
                2.0,
                148.52,
                217.64000000000001,
                2.0,
                161.60000000000002,
                221.28,
                2.0,
                126.84,
                220.27999999999997,
                2.0,
                147.6,
                210.44,
                2.0,
            ],
            "num_keypoints": 7,
            "id": 34,
            "attributes": {
                "track_id": 27,
                "encord_track_uuid": "YK1gFlRi",
                "classifications": {"skeleton checklist option 0": False, "skeleton checklist option 1": False},
                "manual_annotation": True,
            },
        },
        {
            "area": 2712.2752,
            "bbox": [46.800000000000004, 87.96000000000001, 41.120000000000005, 65.96],
            "category_id": 1,
            "image_id": 6,
            "iscrowd": 0,
            "segmentation": [
                [
                    46.800000000000004,
                    87.96000000000001,
                    87.92000000000002,
                    87.96000000000001,
                    87.92000000000002,
                    153.92000000000002,
                    46.800000000000004,
                    153.92000000000002,
                ]
            ],
            "keypoints": None,
            "num_keypoints": None,
            "id": 35,
            "attributes": {
                "track_id": 28,
                "encord_track_uuid": "esSwqOk3",
                "classifications": {
                    "box text": "ergeg",
                    "box radio": None,
                    "box checklist option 0": False,
                    "box checklist option 1": False,
                },
                "manual_annotation": True,
            },
        },
        {
            "area": 543.0655999999999,
            "bbox": [150.36, 120.56, 25.52, 21.279999999999998],
            "category_id": 2,
            "image_id": 6,
            "iscrowd": 0,
            "segmentation": [[150.36, 120.56, 175.88000000000002, 120.56, 175.88000000000002, 141.84, 150.36, 141.84]],
            "keypoints": None,
            "num_keypoints": None,
            "id": 36,
            "attributes": {
                "track_id": 29,
                "encord_track_uuid": "IkdWJi/L",
                "rotation": 32.8422,
                "classifications": {"rotatable box radio": "rotatable box radio option 0"},
                "manual_annotation": True,
            },
        },
        {
            "area": 3116.4815999999996,
            "bbox": [192.92000000000002, 126.24, 57.44, 92.2],
            "category_id": 3,
            "image_id": 6,
            "iscrowd": 0,
            "segmentation": [
                [
                    231.92,
                    126.24,
                    192.92000000000002,
                    173.76,
                    214.88,
                    209.24,
                    250.36,
                    218.44,
                    248.92,
                    168.79999999999998,
                    243.96,
                    161.0,
                ]
            ],
            "keypoints": None,
            "num_keypoints": None,
            "id": 37,
            "attributes": {
                "track_id": 30,
                "encord_track_uuid": "AxVrCSDf",
                "classifications": {"polygon checklist option 0": False, "polygon checklist option 1": False},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [285.8, 119.88000000000001, 39.71999999999997, 117.71999999999998],
            "category_id": 4,
            "image_id": 6,
            "iscrowd": 0,
            "segmentation": [
                [
                    285.8,
                    119.88000000000001,
                    288.64,
                    160.28,
                    325.52,
                    185.84,
                    313.47999999999996,
                    209.96,
                    300.0,
                    226.24,
                    299.28,
                    237.6,
                    299.28,
                    237.6,
                    300.0,
                    226.24,
                    313.47999999999996,
                    209.96,
                    325.52,
                    185.84,
                    288.64,
                    160.28,
                    285.8,
                    119.88000000000001,
                ]
            ],
            "keypoints": None,
            "num_keypoints": None,
            "id": 38,
            "attributes": {
                "track_id": 31,
                "encord_track_uuid": "rGvWCYXp",
                "classifications": {"polygon text": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 3294.0,
            "bbox": [334.0, 118.0, 47.0, 96.0],
            "category_id": 5,
            "image_id": 6,
            "iscrowd": 1,
            "segmentation": {
                "size": [400, 400],
                "counts": "odR48T<7K5I5L5K4dN^OfFd0W9EaF>\\9I\\F;a9KXF9f9Y1O2N1O101N100O10000O100000O10000O101N1O1O101M2O2M3M3K5L4L4L5K6K=B9G7I6J9BgX7",
            },
            "keypoints": None,
            "num_keypoints": None,
            "id": 39,
            "attributes": {
                "track_id": 32,
                "encord_track_uuid": "iyiu8kWG",
                "classifications": {"bitmask radio": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [58.160000000000004, 204.28000000000003, 0.0, 0.0],
            "category_id": 6,
            "image_id": 6,
            "iscrowd": 0,
            "segmentation": [[58.160000000000004, 204.28000000000003]],
            "keypoints": [58.160000000000004, 204.28000000000003, 2.0],
            "num_keypoints": 1,
            "id": 40,
            "attributes": {
                "track_id": 33,
                "encord_track_uuid": "jW3Y8Hwo",
                "classifications": {"keypoint text": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [77.75999999999999, 231.2, 53.20000000000002, 54.60000000000002],
            "category_id": 7,
            "image_id": 6,
            "iscrowd": 0,
            "segmentation": [],
            "keypoints": [
                129.84,
                284.56,
                2.0,
                110.64,
                267.03999999999996,
                2.0,
                84.32,
                285.8,
                2.0,
                110.92,
                246.60000000000002,
                2.0,
                130.96,
                254.44,
                2.0,
                77.75999999999999,
                252.28000000000003,
                2.0,
                109.55999999999999,
                231.2,
                2.0,
            ],
            "num_keypoints": 7,
            "id": 41,
            "attributes": {
                "track_id": 34,
                "encord_track_uuid": "Jnvhu8Kt",
                "classifications": {"skeleton checklist option 0": False, "skeleton checklist option 1": False},
                "manual_annotation": True,
            },
        },
        {
            "area": 1239.264,
            "bbox": [334.03999999999996, 251.08, 31.2, 39.72],
            "category_id": 1,
            "image_id": 6,
            "iscrowd": 0,
            "segmentation": [
                [
                    334.03999999999996,
                    251.08,
                    365.23999999999995,
                    251.08,
                    365.23999999999995,
                    290.8,
                    334.03999999999996,
                    290.8,
                ]
            ],
            "keypoints": None,
            "num_keypoints": None,
            "id": 42,
            "attributes": {
                "track_id": 35,
                "encord_track_uuid": "lbWBe6oj",
                "classifications": {
                    "box text": "wfwf",
                    "box radio": None,
                    "box checklist option 0": False,
                    "box checklist option 1": False,
                },
                "manual_annotation": True,
            },
        },
        {
            "area": 986.6240000000001,
            "bbox": [284.4, 268.08, 26.240000000000002, 37.6],
            "category_id": 2,
            "image_id": 6,
            "iscrowd": 0,
            "segmentation": [[284.4, 268.08, 310.64, 268.08, 310.64, 305.68, 284.4, 305.68]],
            "keypoints": None,
            "num_keypoints": None,
            "id": 43,
            "attributes": {
                "track_id": 36,
                "encord_track_uuid": "96c/yk/d",
                "rotation": 29.0502,
                "classifications": {"rotatable box radio": "rotatable box radio option 0"},
                "manual_annotation": True,
            },
        },
        {
            "area": 667.6736,
            "bbox": [226.24, 268.8, 36.160000000000025, 42.56],
            "category_id": 3,
            "image_id": 6,
            "iscrowd": 0,
            "segmentation": [
                [
                    256.72,
                    268.8,
                    226.24,
                    308.52,
                    241.84,
                    311.36,
                    262.40000000000003,
                    300.72,
                    258.15999999999997,
                    298.6,
                    258.88,
                    288.68,
                ]
            ],
            "keypoints": None,
            "num_keypoints": None,
            "id": 44,
            "attributes": {
                "track_id": 37,
                "encord_track_uuid": "6cc/uT9b",
                "classifications": {"polygon checklist option 0": False, "polygon checklist option 1": False},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [182.95999999999998, 255.32, 28.400000000000006, 58.879999999999995],
            "category_id": 4,
            "image_id": 6,
            "iscrowd": 0,
            "segmentation": [
                [
                    211.35999999999999,
                    255.32,
                    199.28,
                    280.88,
                    209.20000000000002,
                    298.6,
                    191.48000000000002,
                    307.12,
                    182.95999999999998,
                    314.2,
                    182.95999999999998,
                    314.2,
                    191.48000000000002,
                    307.12,
                    209.20000000000002,
                    298.6,
                    199.28,
                    280.88,
                    211.35999999999999,
                    255.32,
                ]
            ],
            "keypoints": None,
            "num_keypoints": None,
            "id": 45,
            "attributes": {
                "track_id": 38,
                "encord_track_uuid": "D6vPWMDX",
                "classifications": {"polygon text": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 1049.0,
            "bbox": [129.0, 292.0, 37.0, 36.0],
            "category_id": 5,
            "image_id": 6,
            "iscrowd": 1,
            "segmentation": {
                "size": [400, 400],
                "counts": "Sfb15W<8J5L2M4M2N2N2O0O2O0O2O0O101O0000000000000000O2O001N101N101N2N2N3M2M4L6HaSk2",
            },
            "keypoints": None,
            "num_keypoints": None,
            "id": 46,
            "attributes": {
                "track_id": 39,
                "encord_track_uuid": "4D+z/QQ1",
                "classifications": {"bitmask radio": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [105.67999999999999, 312.76, 0.0, 0.0],
            "category_id": 6,
            "image_id": 6,
            "iscrowd": 0,
            "segmentation": [[105.67999999999999, 312.76]],
            "keypoints": [105.67999999999999, 312.76, 2.0],
            "num_keypoints": 1,
            "id": 47,
            "attributes": {
                "track_id": 40,
                "encord_track_uuid": "MYbEJpg1",
                "classifications": {"keypoint text": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [29.880000000000003, 291.92, 22.679999999999993, 24.839999999999975],
            "category_id": 7,
            "image_id": 6,
            "iscrowd": 0,
            "segmentation": [],
            "keypoints": [
                52.080000000000005,
                316.2,
                2.0,
                43.88,
                308.24,
                2.0,
                32.68,
                316.76,
                2.0,
                44.0,
                298.91999999999996,
                2.0,
                52.559999999999995,
                302.48,
                2.0,
                29.880000000000003,
                301.52,
                2.0,
                43.44,
                291.92,
                2.0,
            ],
            "num_keypoints": 7,
            "id": 48,
            "attributes": {
                "track_id": 41,
                "encord_track_uuid": "d+yjcHNs",
                "classifications": {"skeleton checklist option 0": False, "skeleton checklist option 1": False},
                "manual_annotation": True,
            },
        },
        {
            "area": 3709.1551999999997,
            "bbox": [43.2, 141.6, 55.76, 66.52],
            "category_id": 1,
            "image_id": 7,
            "iscrowd": 0,
            "segmentation": [[43.2, 141.6, 98.96000000000001, 141.6, 98.96000000000001, 208.12, 43.2, 208.12]],
            "keypoints": None,
            "num_keypoints": None,
            "id": 49,
            "attributes": {
                "track_id": 42,
                "encord_track_uuid": "PoCcR6A4",
                "classifications": {
                    "box text": "geg",
                    "box radio": None,
                    "box checklist option 0": False,
                    "box checklist option 1": False,
                },
                "manual_annotation": True,
            },
        },
        {
            "area": 1842.0768,
            "bbox": [149.8, 166.08, 45.96, 40.08],
            "category_id": 2,
            "image_id": 7,
            "iscrowd": 0,
            "segmentation": [
                [
                    149.8,
                    166.08,
                    195.76000000000002,
                    166.08,
                    195.76000000000002,
                    206.16000000000003,
                    149.8,
                    206.16000000000003,
                ]
            ],
            "keypoints": None,
            "num_keypoints": None,
            "id": 50,
            "attributes": {
                "track_id": 29,
                "encord_track_uuid": "IkdWJi/L",
                "rotation": 31.32,
                "classifications": {"rotatable box radio": "rotatable box radio option 0"},
                "manual_annotation": True,
            },
        },
        {
            "area": 2275.6240000000016,
            "bbox": [241.71999999999997, 161.16, 73.36000000000001, 70.44],
            "category_id": 3,
            "image_id": 7,
            "iscrowd": 0,
            "segmentation": [
                [
                    283.76,
                    161.16,
                    241.71999999999997,
                    225.72,
                    275.96,
                    231.6,
                    308.24,
                    201.28,
                    308.24,
                    196.4,
                    277.92,
                    177.8,
                    315.08,
                    166.08,
                ]
            ],
            "keypoints": None,
            "num_keypoints": None,
            "id": 51,
            "attributes": {
                "track_id": 30,
                "encord_track_uuid": "AxVrCSDf",
                "classifications": {"polygon checklist option 0": False, "polygon checklist option 1": False},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [302.36, 182.72, 66.51999999999998, 89.00000000000003],
            "category_id": 4,
            "image_id": 7,
            "iscrowd": 0,
            "segmentation": [
                [
                    356.15999999999997,
                    182.72,
                    343.44,
                    215.0,
                    368.88,
                    253.12,
                    333.64,
                    271.72,
                    302.36,
                    265.84,
                    302.36,
                    265.84,
                    333.64,
                    271.72,
                    368.88,
                    253.12,
                    343.44,
                    215.0,
                    356.15999999999997,
                    182.72,
                ]
            ],
            "keypoints": None,
            "num_keypoints": None,
            "id": 52,
            "attributes": {
                "track_id": 43,
                "encord_track_uuid": "g+NeRdSm",
                "classifications": {"polygon text": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 2003.0,
            "bbox": [58.0, 226.0, 50.0, 50.0],
            "category_id": 5,
            "image_id": 7,
            "iscrowd": 1,
            "segmentation": {
                "size": [400, 400],
                "counts": "flf09T<7I6K4L4M2N2N2N2N2N2N2O0O2O0O2O00000O2O0000000000000000000000O2O00001N101N101N2N2N2O0N4M2N3L3M5K5J^ja3",
            },
            "keypoints": None,
            "num_keypoints": None,
            "id": 53,
            "attributes": {
                "track_id": 44,
                "encord_track_uuid": "c0Tg67JF",
                "classifications": {"bitmask radio": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [220.2, 176.84, 0.0, 0.0],
            "category_id": 6,
            "image_id": 7,
            "iscrowd": 0,
            "segmentation": [[220.2, 176.84]],
            "keypoints": [220.2, 176.84, 2.0],
            "num_keypoints": 1,
            "id": 54,
            "attributes": {
                "track_id": 45,
                "encord_track_uuid": "qLgBwmdc",
                "classifications": {"keypoint text": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [298.56, 128.56, 31.279999999999973, 34.23999999999998],
            "category_id": 7,
            "image_id": 7,
            "iscrowd": 0,
            "segmentation": [],
            "keypoints": [
                329.2,
                162.0,
                2.0,
                317.91999999999996,
                151.0,
                2.0,
                302.44,
                162.79999999999998,
                2.0,
                318.08,
                138.2,
                2.0,
                329.84,
                143.12,
                2.0,
                298.56,
                141.76,
                2.0,
                317.28000000000003,
                128.56,
                2.0,
            ],
            "num_keypoints": 7,
            "id": 55,
            "attributes": {
                "track_id": 46,
                "encord_track_uuid": "4OBsyrhi",
                "classifications": {"skeleton checklist option 0": False, "skeleton checklist option 1": False},
                "manual_annotation": True,
            },
        },
        {
            "area": 3256.6512,
            "bbox": [35.08, 85.36, 48.84, 66.67999999999999],
            "category_id": 1,
            "image_id": 8,
            "iscrowd": 0,
            "segmentation": [[35.08, 85.36, 83.92, 85.36, 83.92, 152.04, 35.08, 152.04]],
            "keypoints": None,
            "num_keypoints": None,
            "id": 56,
            "attributes": {
                "track_id": 47,
                "encord_track_uuid": "P/9LI504",
                "classifications": {
                    "box text": "4rfw",
                    "box radio": None,
                    "box checklist option 0": False,
                    "box checklist option 1": False,
                },
                "manual_annotation": True,
            },
        },
        {
            "area": 1833.1711999999998,
            "bbox": [144.96, 104.16000000000001, 19.72, 92.96],
            "category_id": 2,
            "image_id": 8,
            "iscrowd": 0,
            "segmentation": [[144.96, 104.16000000000001, 164.68, 104.16000000000001, 164.68, 197.12, 144.96, 197.12]],
            "keypoints": None,
            "num_keypoints": None,
            "id": 57,
            "attributes": {
                "track_id": 48,
                "encord_track_uuid": "DYLkbPO4",
                "rotation": 14.8743,
                "classifications": {"rotatable box radio": "rotatable box radio option 0"},
                "manual_annotation": True,
            },
        },
        {
            "area": 2079.9208000000003,
            "bbox": [209.72, 118.24, 50.72, 84.52000000000002],
            "category_id": 3,
            "image_id": 8,
            "iscrowd": 0,
            "segmentation": [[235.08, 118.24, 209.72, 192.4, 235.08, 202.76000000000002, 252.0, 174.56, 260.44, 168.0]],
            "keypoints": None,
            "num_keypoints": None,
            "id": 58,
            "attributes": {
                "track_id": 49,
                "encord_track_uuid": "sNRMQRZa",
                "classifications": {"polygon checklist option 0": False, "polygon checklist option 1": False},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [265.12, 122.92, 55.39999999999998, 125.83999999999999],
            "category_id": 4,
            "image_id": 8,
            "iscrowd": 0,
            "segmentation": [
                [
                    318.64,
                    122.92,
                    293.28,
                    168.0,
                    320.52,
                    215.88,
                    290.47999999999996,
                    248.76,
                    265.12,
                    245.00000000000003,
                    265.12,
                    245.00000000000003,
                    290.47999999999996,
                    248.76,
                    320.52,
                    215.88,
                    293.28,
                    168.0,
                    318.64,
                    122.92,
                ]
            ],
            "keypoints": None,
            "num_keypoints": None,
            "id": 59,
            "attributes": {
                "track_id": 50,
                "encord_track_uuid": "G0HipOAZ",
                "classifications": {"polygon text": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 3408.0,
            "bbox": [342.0, 138.0, 57.0, 79.0],
            "category_id": 5,
            "image_id": 8,
            "iscrowd": 1,
            "segmentation": {
                "size": [400, 400],
                "counts": "khU48R<;E9H7K5L3L4L5K3N3M3M3M2O2N1O2N1O1O2N100O100O10000O1000000000O10000O100O100O2N1O1O2N1O2N1N3M3L3G:I7K6L3L4M4L5J7Hf7",
            },
            "keypoints": None,
            "num_keypoints": None,
            "id": 60,
            "attributes": {
                "track_id": 51,
                "encord_track_uuid": "S8y9TRAJ",
                "classifications": {"bitmask radio": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [45.4, 189.6, 0.0, 0.0],
            "category_id": 6,
            "image_id": 8,
            "iscrowd": 0,
            "segmentation": [[45.4, 189.6]],
            "keypoints": [45.4, 189.6, 2.0],
            "num_keypoints": 1,
            "id": 61,
            "attributes": {
                "track_id": 52,
                "encord_track_uuid": "oOPOjjAI",
                "classifications": {"keypoint text": None},
                "manual_annotation": True,
            },
        },
        {
            "area": 0.0,
            "bbox": [12.2, 235.95999999999998, 45.08, 58.200000000000045],
            "category_id": 7,
            "image_id": 8,
            "iscrowd": 0,
            "segmentation": [],
            "keypoints": [
                56.36,
                292.88,
                2.0,
                40.08,
                274.16,
                2.0,
                17.76,
                294.16,
                2.0,
                40.32,
                252.36,
                2.0,
                57.28,
                260.72,
                2.0,
                12.2,
                258.44,
                2.0,
                39.160000000000004,
                235.95999999999998,
                2.0,
            ],
            "num_keypoints": 7,
            "id": 62,
            "attributes": {
                "track_id": 53,
                "encord_track_uuid": "jXUPS9nV",
                "classifications": {"skeleton checklist option 0": False, "skeleton checklist option 1": False},
                "manual_annotation": True,
            },
        },
        {
            "area": 5335.69732608,
            "bbox": [44.9024, 109.2608, 62.5152, 85.3504],
            "category_id": 1,
            "image_id": 9,
            "iscrowd": 0,
            "segmentation": [[44.9024, 109.2608, 107.4176, 109.2608, 107.4176, 194.6112, 44.9024, 194.6112]],
            "keypoints": None,
            "num_keypoints": None,
            "id": 63,
            "attributes": {
                "track_id": 47,
                "encord_track_uuid": "P/9LI504",
                "classifications": {
                    "box text": "4rfw",
                    "box radio": None,
                    "box checklist option 0": False,
                    "box checklist option 1": False,
                },
                "manual_annotation": True,
            },
        },
    ],
}

MULTIPOLYGON = [
    [
        [
            0.3161292802202092,
            0.16291740687958764,
            0.3234958222708105,
            0.09597185889426828,
            0.3565651903892706,
            0.057638387279400245,
            0.3913732454513509,
            0.02687582968920815,
            0.4360460611724972,
            0.027797028736529717,
            0.481922231278307,
            0.04039793358581912,
            0.5009837307707323,
            0.06477920506012803,
            0.5248952517374669,
            0.14234904536935808,
            0.529996925269405,
            0.21711258394502575,
            0.5189127960038263,
            0.28225233777135716,
            0.4702089718686552,
            0.32028687724504135,
            0.4232278204552553,
            0.34468035003123537,
            0.386825206446197,
            0.335148075121037,
            0.35110434073871616,
            0.2912264026628143,
            0.3342916955431047,
            0.25336268155552083,
            0.3181219069674371,
            0.20948676401686708,
        ],
        [
            0.40150567238989526,
            0.1081274158597532,
            0.40999549771591437,
            0.14949291347805713,
            0.42495278092300476,
            0.166162955841012,
            0.4372288258433546,
            0.1554563046618772,
            0.4410424983894267,
            0.1311085867952522,
            0.4289403221634389,
            0.10341160881617989,
            0.423154612583945,
            0.09779290469311258,
        ],
    ],
    [
        [
            0.5680627306047946,
            0.16434496037013896,
            0.5747406611158832,
            0.12582846907699513,
            0.6031613294061376,
            0.06553568639700137,
            0.6438671936006559,
            0.04432065535686394,
            0.6723084516047165,
            0.0472123662736217,
            0.7275117620646572,
            0.07271310811338433,
            0.7528371100460721,
            0.1071513109089489,
            0.7754194505993285,
            0.18997076565672338,
            0.7758335326214274,
            0.24243640676245506,
            0.7609952122052163,
            0.3247342554271435,
            0.7045039007594097,
            0.3566437363345306,
            0.65786133575082,
            0.36814957344213656,
            0.6427393348332813,
            0.3391836590270186,
            0.615618106258785,
            0.2961252293846634,
            0.5885655100636421,
            0.26331590172575353,
            0.568284641964704,
            0.23668958886459468,
        ]
    ],
]
MULTIPOLYGON_WITH_ENCLOSED_POLYGONS = [
    [
        [
            0.2605581582105156,
            0.5762185699389406,
            0.2786370150445046,
            0.29383412857501834,
            0.4361891823615411,
            0.2416549488404874,
            0.6349473237417227,
            0.2670006005674611,
            0.630296831160507,
            0.6047117208999829,
        ],
        [
            0.29769848120511905,
            0.5470795843008257,
            0.5990907966290959,
            0.5608913341583893,
            0.5870410248632074,
            0.3092208353153488,
            0.3291998234326626,
            0.32019278123118766,
        ],
    ],
    [
        [
            0.3279064744044547,
            0.5183435629682932,
            0.35584323333225837,
            0.3355276805246496,
            0.43916283533012984,
            0.33746182520774215,
            0.4276175956607972,
            0.5223925747656519,
        ],
        [
            0.3696896264673632,
            0.36980389679343506,
            0.3852746922165247,
            0.473406350444509,
            0.43005112843862875,
            0.37164125025866984,
        ],
    ],
    [
        [
            0.13909987694707798,
            0.643382226965622,
            0.1673462208005459,
            0.18126830424809726,
            0.7602457598307963,
            0.16728722224909698,
            0.779250222052911,
            0.6245667280755506,
            0.5092934266291491,
            0.8621665972961281,
        ],
        [
            0.18195130171380508,
            0.6414789462934296,
            0.7038966842562138,
            0.6525547170622635,
            0.7004226983762256,
            0.21715422565681966,
            0.2095907583325271,
            0.23455837841578517,
        ],
    ],
    [
        [
            0.4586382361675481,
            0.5164365555192747,
            0.4743019316587655,
            0.34053211192474525,
            0.5530722414376936,
            0.3296358038315381,
            0.5591767018793539,
            0.5192093824577529,
        ],
        [
            0.4841171070436124,
            0.4868651587896673,
            0.5387918625166623,
            0.48502780532443246,
            0.5055906901377603,
            0.36433430065762606,
        ],
    ],
]


MULTIPOLYGON_EXPECTED_COCO_SEGMENTATION = {
    "size": [3024, 4032],  # h, w
    "counts": r"Yhbe3<mm2i0XOh0WOh0XOi0WOh0YOh0WOi0WOa0@8G9G9G9H8G9G9G9H8G9G9G9H8G9G9H8G9G9G9H8G9J7L3M3M3N2M3M3M3M3M3M3M3N2M3M3M3M3M3M3M3N2M4L3M3M3M3M3M3N2M3M3M3M3M3M3M3N2M3M3M3M3M3M3M3N2M3M2N3M3M2N3N2M2N3M3M2N3M3M2O2M3M3M2N3M3M2N3N2M2N3M3M2N3M3M2O2M3M2N3M3M2N3M3N1N3M3M2N3M3M2O2M3M2N3M3M3M2N3N2M2N3M3M2N3M3M2O2M3M2N3M3M2N2N2O1N2N2N2N1O2N2N2O1N2N2N2N2N2N2N2O1N1O2N2N2O1N2N2O1N2N2O1N2N2O0O2N2O1N2N2O1N2N2O1N2N2O1N101N2N2O1N2N2O1N2N2O1N2N2O0O2N2O1N2N2O1N2N2O1N2N2O1N1O2O1N2N2O1N2N2O1N2N2O1N2N2O0O2N2O1N2N2O1N2O1N2N2O1N2N101N2N2O1N2N2O1N2N2O1N2N2O0O2N2O1N2N2O1N2N2O1N2N2O1N1O2O1N2N2O1N2N2O1N2N2O1N2N101N2O1N2N2O1N1O101N1O100O1O2O0O1O100O2N100O1O101N100000001O000000001O000000001O00000000001O000000001O0000000010O00000001O00000000UZOQoMV>nP2jAVoMR>jP2mA[oMo=eP2QB^oMl=bP2TBboMh=^P2WBfoMg=YP2YBkoMc=UP2]BooM_=QP2`BSPN]=mo1cBWPNY=io1fB[PNX=do1hB`PNT=`o1lBdPNP=\o1oBhPNn<Xo1RClPNj<To1VCoPNh<Po1WCUQNe<kn1[CYQNa<gn1_C\QN^<dn1aCaQN[<_n1eCdQNY<[n1gCiQNU<Wn1jCnQNR<Rn1nCQRNo;om1QDURNk;km1TDYRNj;fm1VD^RNf;bm1YDcRNc;]m1]DfRN`;Zm1`DjRN\;Vm1cDnRN[;Qm1eDSSNW;ml1iDWSNS;il1lD[SNQ;el1oD_SNm:al1SEaSNl:^l1SEdSNl:\l1TEeSNk:[l1UEeSNk:[l1TEgSNk:Yl1UEhSNk:Wl1UEjSNj:Vl1UElSNj:Tl1VEmSNi:Sl1WEmSNi:Sl1VEoSNj:Pl1VEQTNi:ok1VESTNi:mk1WETTNh:lk1XEUTNg:kk1XEVTNi:jk1VEWTNi:ik1WEXTNh:hk1WEZTNh:fk1XE[TNg:ek1YE\TNf:dk1YE]TNh:bk1XE_TNg:ak1YE`TNf:`k1YEbTNf:^k1ZEcTNe:]k1[EdTNe:[k1ZEfTNf:Zk1ZEgTNe:Yk1ZEiTNe:Wk1[EjTNd:Vk1\EkTNd:Tk1[EnTNd:Rk1\EnTNd:Rk1\EoTNc:Qk1\EQUNc:oj1]ERUNc:mj1]ETUNb:lj1]EVUNb:jj1^EVUNb:jj1^EWUNa:ij1^EYUNb:fj1^E[UNa:ej1_E\UN`:dj1_E^UN`:bj1`E^UN`:bj1_E`UNa:_j1_EbUN`:^j1`EcUN_:]j1`EeUN_:[j1aEfUN^:Zj1bEfUN_:Yj1`EiUN_:Wj1aEjUN^:Vj1cEjUN\:Vj1dEkUNZ:Vj1gEjUNX:Vj1iEiUNV:Xj1kEhUNT:Xj1lEiUNS:Wj1nEiUNP:Xj1QFfUNP:Zj1QFeUNn9\j1RFcUNo9]j1RFaUNo9_j1RF`UNm9aj1TF]UNm9cj1SF\UNn9dj1SF[UNl9fj1UFXUNl9hj1UFVUNk9kj1UFUUNk9kj1VFSUNk9mj1VFRUNi9oj1XFoTNi9Qk1WFnTNi9Tk1WFkTNi9Uk1XFiTNi9Wk1YFfTNg9[k1[FcTNe9]k1]F`TNc9ak1^F]TNc9ck1_F[TNa9ek1aFXTN_9ik1bFUTN_9kk1cFSTN\9nk1fFoSN[9Ql1gFlSNZ9Tl1gFkSNX9Vl1jFgSNW9Yl1kFdSNV9\l1kFcSNT9^l1nF_SNS9al1oF\SNQ9el1QGYSNo8gl1RGWSNo8il1SGTSNm8ml1UGQSNk8ol1VGoRNj8Rm1XGlRNh8Tm1ZGiRNg8Wm1[GfRNe8[m1\GdRNd8\m1^GaRNb8`m1`G]RNa8cm1`G\RN`8dm1bGYRN^8hm1dGURN]8lm1dGRRN[8om1fGoQN[8Qn1gGjQN\8Vn1fGdQN]8]n1dG]QNa8dn1`GUQNe8kn1]GoPNf8Ro1\GgPNi8Yo1XGaPNl8`o1VGZPNn8go1SGRPNR9no1oFmoMT9TP2nFeoMW9[P2kF^oMY9cP2iFWoM[9jP2eFPoM`9PQ2bFinMb9XQ2`FbnMd9^Q2f92O000O100O2O000O10001N100O10001N100O10001N100O10001N100O10001N100O101O0O10000O2O0O10000O2O0O10000O2O0O10000O2O0O10000O2O000O100O2O000O100O2O000O101N10000O101N10000O101O0O100O101O0O100O101O0O100O101O0O100O101O0O10000O2O0O10001N100O100O2O0O100O1O2O0O100O101N1O100O101N1O100O101N100O1O101N100O1O2O0O100O101N1O100O101N1O100O101N100O2N2O1N2O1N2N2O1N2O1N2O1N1O2O1N2O1N2N2O1N2O1N2O1N2N2O1N2O1N2N2O1N2O1N2O1N2N101N2O1N2N2O1N2O1N2O1N2N2O1N2O1N2N2O1N2O1N2O1N2N2O1N101N2N2O1N2O1N2O1N2N2O1N2O2M3M4M2M3N3L3N3L3M4M2M3N3L3M4M2M3N3L3N3L3M4M2M3N3L3M4M2M4M2M3N3L3M4M2M4M2M3M4M2M4M2M3N3L3M4M2M4M2M3M4M2M4M2M4M2M3M4M2M4M2M3M4M2M4M2M4M2M3M4M2M4M2M4J5J6I8I6I8I6I8I6I7J7H7J7I6I7J7H7J7H7J7H7J6I8I6I<E?@a0@?@`0A`0_O`0A?@a0@?A?@`0A`0_O`0A?@a0@?@`0A`0_O`0AgeS>X3QWlAb3^L5J6K5K5K5J6K5K5J6K5K5J6K5K5K5J6K5K5J6K5K5K5J6K5K5L4M3N2M3M3N2M3N2M3M3N2M3N2M3M3N1N3N2M3M3N2M3N2M3M3N2M3N2M3M3N2M3N2M3M3N2M3N2M3M3N2M3N2M3M3N2M3N2M3M3N2M3N2M3M3N2M3N2M3N2M3M3N1N3N2M3M3N2M3N2M3M3N2M2O2M3M3N2M3N2M3M3N2M3N1N3M3N2M3N2M3M3N2M3N2M2N3N2M3N2M3M3N2M3N2M3M2O2M3N2M3M3N2M3N2O1N101N2O1O1N2O1O1N2O1N2O001N2O1N2O1O1N2O1N2O1O0O2O1O1N2O1N2O1O1N2O1N101O1N2O1N2O1O1N2O1O1N101N2O1O1N2O1N2O2N1N2O1O1N3N1N2O1O1N3N1N2O1O1N3N1N2O1O1N3N1O1N2O1N2O2N1N2O1N2O2N1N2O1N2O2N1N2O1O1N3N1N2O1O1N3N1N2O1O1N3N1N2O1O1N2O2N1N2O1N2O2N1N2O1N2O2N1N2O1O1N3N1N2O1O1N3N1N2O1O1N2O2M2O1O1N2O2N1N2O1N2O2N1N2O1N2O2N1N2O1N2O2N1N2O1O2M2O2M2O1O2N1O2N1O2N1O2O0O1O2N1O2N1O2N1O2N1O1O2N1O2O0O2N1O2N1O1O2N1O2N1O2N1O1O2O0O2N1O2N1O2N1O1O2N1O2N1O2N101N1O1O2N1O2N1O0000O10000000001N100000000O100000000O1000001O000O100000000O100000000O101O0000000O100000000O100000001O0O100000000O10001O000O2O00001O000O2O00001O0O2O00001O0O101O00001O0O101O00001N10001O00001N10001O001N10001O000O2O00001O000O2O00001O0O101O00001N10001O00001N101O00001N10001O000O2O00001O000O2O00001O0O101O00001O0O101O001O0O101O00001N10001O00001N10001O000O2O00001O0O101O001O000O2O00001N100O2O0O101O0O101N100O2O000O2O0O101N10001N101N10001N100O2O0O101O0O101N100O2O000O2O0O101N10001N100O2O0O2O000O2O0O101N10001N100O2O0O101O0O101N10001N100O2O0O2O000O2O0O101N10001N100O2O0O2O1O1N2O1N2O1N2O1O1N2O1N2O1N2O1O1N3N1N2O1O1N2O1N2O1N2O1O1N2O1N2O1N2O1O1N2O1N2O1N2O1O1N2O1N2O1N2O1O1N2O2M2O1N2O1O1N2O1N2O1N2O1O1N2O1N2O1O1N2O1N2O1N2O1O1N2O1N2O1N2O1O1N2O1N3N1N2O1O1N2O1N2O1N2O1O1N2O1N2O1N2O2N3L3N3L4M3L3N3M3L4M2M4M3M3L3N3L4M3L3N3M3L4M2M4M3L4M2N3L4M3L3N3L4M3J5J7I7I7I6J7I7H8I6J7I7I7I6J7I7H7J7I7I7I6J7I7H8I6J7I7I7I6J7I7H8I6J7I7I7I6J7H8I7I6J7I7I7I6J7H8I7I6J7I7I7I6I8I7I7I6J7I]1cNd2\MnoYc2",
}

MULTIPOLYGON_WITH_ENCLOSED_POLYGONS_EXPECTED_COCO_SEGMENTATION = {
    "size": [3024, 4032],
    "counts": r"cdgc17mm2<D=C<C>C<D=C<C>C<D<D=B=D=C<D=B=D=C<D<C>C<D=C<C>C<D=C<C=D=C<C>C<D=C<C>C<D<D=B=D=C<D=B=D=C<D<C>C<D=C<C>C<D=C<C=D=C<D=B=D=C<D<C>C<D=C<C>C<D=C<C=D=C<D=B=D=C<D=B=D<D=C<C>C<D=B=D=C<D<C>C<D=C<C>C<D=C<C=D=C<D=B=D=C<D=B=D<D=C<C>C<D=C<I8O00001O001O001O001O00001O001O001O001O00001O001O001O001N10001O001O001O001O00001O001O001O001O00001O001O001O00001O001O00XMi_NXgNV`1]X1U`NcgNk_1RX1``NogN__1fW1l`NZhNT_1[W1WaNehNi^1PW1baNQiN]^1dV1naN\iNR^1YV1YbNhiNf]1mU1ebNSjN[]1bU1PcN_jNo\1VU1\cNjjNd\1kT1gcNVkNX\1_T1SdNakNm[1TT1^dNlkNb[1iS1idNXlNV[1]S1UeNclNkZ1RS1`eNolN_Z1fR1leNZmNTZ1[R1WfNfmNhY1oQ1cfNQnN]Y1dQ1nfN]nNQY1XQ1ZgNhnNfX1mP1egNSoN[X1bP1PhN_oNoW1VP1\hNjoNcW1lo0hhNUPOWW1`o0TiN`POlV1Uo0_iNlPO`V1jn0jiNVQOVV1_n0UjNbQOjU1Sn0ajNmQO_U1hm0mjNWROSU1^m0XkNcROgT1Rm0dkNnRO\T1gl0okNZSOPT1[l0[lNeSOeS1Pl0flNQTOYS1dk0RmN\TOnR1Yk0]mNhTObR1mj0imNSUOWR1bj0TnN^UOlQ1Wj0_nNjUO`Q1ki0knNUVOUQ1`i0VoNaVOiP1Ti0boNlVO^P1ih0moNXWORP1]h0YPOcWOgo0Rh0dPOoWO[o0fg0PQOZXOPo0[g0[QOeXOen0Pg0fQOQYOYn0df0RRO\YOnm0Yf0]ROhYObm0me0iROSZOWm0be0TSO_ZOkl0Ve0`SOjZO`l0kd0kSOV[OTl0_d0WTOa[Oik0Td0bTOl[O^k0ic0mTOX\ORk0]c0YUOc\Ogj0Rc0dUOo\O[j0fb0PVOZ]OPj0[b0[VOf]Odi0oa0gVOQ^OYi0da0RWO]^Omh0Xa0^WOh^Obh0m`0iWOS_OWh0b`0TXO__Okg0V`0`XOj_O`g0k?kXOV@Tg0_?WYOa@if0T?bYOm@]f0h>nYOXARf0]>YZOdAfe0Q>eZOoA[e0f=P[OZBPe0[=[[OfBdd0o<g[OQCYd0d<R\O]Cmc0X<^\OhCac0n;j\OSDUc0b;V]O^Djb0W;a]OjD^b0l:l]OTETb0a:W^O_Eia0V:b^OkE]a0j9n^OVFRa0_9Y_ObFf`0S9e_OmF[`0h8P@YGo?\8\@dGd?Q8g@PHX?e7TAZHl>[7_AeHa>P7jAQIU>d6VB\Ij=Y6aBhI^=m5mBSJS=b5XC_Jg<V5dCjJ\<k4oCUKQ<`4ZDaKe;T4fDlKZ;i3QEXLn:]3]EcLc:R3hEoLW:f2TFZMl9[2_FfM`9o1kFQNU9d1VG\Nj8Y1aGhN^8R1hGnNX8R1hGoNW8Q1iGoNW8Q1iGPOV8P1jGPOV8P1jGQOU8o0kGQOU8o0kGQOU8o0kGROT8n0lGROT8n0lGSOS8m0mGSOS8m0mGTOR8l0nGTOR8l0nGUOQ8k0oGUOQ8k0oGUOQ8k0oGVOP8j0PHVOP8i0QHXOn7h0RHXOn7h0RHYOm7g0SHYOm7g0SHZOk7g0UHYOk7g0UHYOk7g0UHZOj7f0VHZOj7f0VH[Oi7e0WH[Oi7e0WH\Oh7d0XH\Oh7d0XH]Og7c0YH]Og7c0YH]Og7c0YH^Of7b0ZH^Of7b0ZH_Oe7a0[H_Oe7a0[H@d7`0\H@d7`0\HAc7?]HAc7?^H@b7`0^HAa7?_HAa7?_HB`7>`HB`7>`HC_7=aHC_7=aHD^7<bHD^7<bHD^7<bHE]7;cHE]7;cHF\7:dHF\79eHHZ78fHHZ78fHIY77gHIY77gHIY77gHJX76hHJX76hHKW75iHKW75iHLV74jHLV74jHMU73kHMU73kHMU73kHNT72lHNT72lHOS71mHOS71mH0R70nH0R70nH1Q7OoH1Q7OoH1P70PI1o6OQI1o6OQI2n6NRI2n6NRI3m6MSI3m6MSI4l6LTI4l6LTI4l6LTI5k6KUI5k6KUI6j6JVI6j6JVI7i6HXI8h6HXI8h6HXI9g6GYI9g6GYI:f6FZI:f6FZI;e6E[I;e6E[I<d6D\I<d6D\I<d6D]I<b6D^I<b6D^I=a6C_I=a6C_I>`6B`I>`6B`I?_6AaI?_6AaI?_6AaI`0^6@bI`0^6@bIa0]6_OcIa0]6_OcIb0\6^OdIb0\6^OdIc0[6]OeIc0[6]OeIc0[6]OeId0Z6\OfId0Z6\OfIe0Y6[OgIe0Y6[OgIf0X6ZOhIf0X6ZOhIg0W6YOiIg0W6XOjIh0V6XOjIi0U6WOkIi0U6WOkIj0S6WOmIi0S6WOmIj0R6VOnIj0R6VOnIk0Q6UOoIk0Q6UOoIk0Q6UOoIl0P6TOPJl0P6TOPJm0o5SOQJm0o5SOQJn0n5RORJn0n5RORJo0m5QOSJo0m5QOSJo0m5QOSJP1l5POTJP1l5POTJQ1k5oNUJQ1k5oNUJR1j5nNVJR1j5nNVJS1i5mNWJS1i5mNWJS1i5mNWJT1h5lNXJT1h5lNXJU1g5kNYJU1g5kNYJV1f5jNZJV1f5jNZJW1e5iN[JW1e5iN\JV1d5jN\JW1c5hN^JX1b5hN^JY1a5gN_JY1a5gN_JZ1`5fN`JZ1`5fN`J[1_5eNaJ[1_5eNaJ[1_5eNaJ\1^5dNbJ\1^5dNbJ]1]5cNcJ]1]5cNcJ^1\5bNdJ^1\5bNdJ_1[5aNeJ_1[5aNeJ_1[5aNeJ`1Z5`NfJ`1Z5`NfJa1Y5_NgJa1Y5_NgJb1W5_NiJa1W5_NiJb1V5^NjJb1V5^NjJb1V5^NjJc1U5]NkJc1U5]NkJd1T5\NlJd1T5\NlJe1S5[NmJe1S5[NmJe1S5[NmJf1R5ZNnJf1R5ZNnJg1Q5YN_DSKQVOd6`U1XNTD`K\VOY6_U1WNiClKhVOm5_U1WN^CWLSWOc5^U1VNSCcL_WOW5^U1VNgBoLkWOk4^U1VN[B[MWXO`4]U1UNQBfMbXOU4]U1UNeARNnXOj3\U1TNZA_NYYO]3]U1TNo@jNdYOS3\U1SNd@VOPZOg2\U1SNX@B\ZO\2[U1RNn_OMgZOQ2[U1RNb_O9S[Oe1[U1RNV_Oe0_[OZ1ZU1QNk^OQ1k[On0ZU1QN`^O\1V\Od0YU1PNU^Oh1b\O8YU1PNi]OT2n\OMXU1oM_]O_2Y]OBXU1oMS]Ok2e]OWOWU1nMh\OW3Q^OkNWU1nM]\Ob3\^O`NWU1nMQ\On3i^OTNUU1nMf[OZ4U_OhMUU1nMZ[Of4a_O]MTU1mMP[OR5k_OQMUU1mMdZO^5W@fLTU1lMYZOj5c@ZLTU1lMnYOU6n@PLSU1kMcYOa6ZAdKSU1kMWYOm6fAXKSU1kMlXOX7QBnJRU1jMaXOd7]BbJRU1jMUXOP8iBWJQU1iMjWO\8UCkIQU1iM_WOg8`CaIPU1gMUWOT9kCUIPU1gMiVO`9WDjHoT1fM_VOk9bD_HoT1fMSVOW:nDSHnT1gMhUOb:ZEhGmT1fM^UOm:eE]GmT1fMRUOZ;PFQGmT1eMgTOf;\FeFmT1eM\TOQ<gF[FlT1dMQTO]<SGoElT1dMeSOi<_GdEkT1cMZSOU=kGXEkT1cMoRO`=VHmDkT1cMcROl=bHbDjT1bMXROX>nHVDjT1bMmQOc>YIlCiT1aMbQOo>eI`CiT1aMVQO[?QJUChT1`MlPOf?\JjBhT1`M`POR`0hJ_BgT1_MUPO^`0TKSBgT1_MioNj`0`KgAgT1_M^oNUa0kK]AfT1^MSoNba0VLPAgT1^MgnNna0bLe@fT1]M]nNYb0mLZ@fT1]MQnNeb0YMo_OeT1\MfmNQc0eMc_OeT1\M[mN\c0PNY_OdT1[MPmNhc0\Nm^OdT1[MdlNTd0hNa^OdT1[MXlN`d0TOV^OcT1ZMnkNkd0_Ok]OcT1ZMbkNWe0K`]ObT1YMWkNce07T]ObT1YMQkNie0=o\OaT1XMRkNie0=o\OaT1XMRkNie0=P]O`T1VMSkNke0=o\O`T1VMSkNke0=o\O`T1VMSkNke0=P]O_T1UMTkNle0<o\O`T1UMSkNme0=o\O_T1TMTkNme0=o\O_T1TMTkNme0=P]O^T1SMUkNme0=P]O^T1SMTkNne0>P]O]T1RMUkNne0>P]O]T1RMUkNne0?o\O\T1SMUkNne0?P]O[T1RMUkNoe0`0o\O[T1RMUkNoe0`0P]OZT1QMVkNoe0`0P]OZT1QMVkNoe0`0Q]OYT1PMVkNPf0a0P]OYT1PMVkNPf0a0Q]OXT1oLWkNPf0a0Q]OXT1oLWkNPf0a0Q]OXT1oLVkNRf0a0P]OWT1oLXkNQf0a0P]OWT1oLXkNQf0a0Q]OVT1nLYkNQf0a0Q]OVT1nLXkNRf0b0Q]OUT1mLYkNRf0b0Q]OUT1mLYkNRf0b0Q]OUT1mLYkNRf0b0R]OTT1lLYkNSf0c0Q]OTT1lLYkNSf0c0R]OST1kLZkNSf0c0R]OST1kLZkNSf0c0S]ORT1jLZkNTf0d0R]ORT1jLZkNTf0d0S]OQT1iL[kNTf0d0S]OQT1iL[kNTf0d0S]OQT1iLZkNUf0e0S]OPT1gL\kNWf0c0R]OQT1gL\kNWf0c0S]OPT1fL]kNWf0c0S]OPT1fL\kNXf0d0S]OoS1eL]kNXf0d0S]OoS1eL]kNXf0d0T]OnS1dL^kNXf0d0T]OnS1dL]kNYf0e0S]OnS1dL]kNYf0e0T]OmS1cL^kNYf0e0T]OmS1cL^kNYf0e0U]OlS1bL^kNZf0f0T]OlS1bL^kNZf0f0U]OkS1aL_kNZf0f0U]OkS1aL_kNZf0f0V]OjS1`L_kN[f0g0U]OjS1`L_kN[f0g0U]OjS1`L_kN[f0g0V]OiS1_L`kN\f0f0U]OjS1_L_kN]f0g0U]OiS1^L`kN]f0g0U]OiS1^L`kN]f0g0V]OhS1]LakN]f0g0V]OhS1]L`kN^f0h0V]OgS1\LakN^f0h0V]OgS1\LakN^f0h0V]OgS1\LakN^f0h0W]OfS1[LakN_f0i0V]OfS1[LakN_f0i0W]OeS1ZLbkN_f0i0W]OeS1ZLbkN_f0i0X]OdS1YLbkN`f0j0W]OdS1YLbkN`f0j0X]OcS1XLckN`f0j0X]OcS1XLckN`f0j0X]OcS1XLbkNbf0k0V]ObS1XLckNbf0k0V]ObS1WLdkN_c0iJbZOQ6i5aS1VLekNYc0oJhZOk5i5aS1VLdkNUc0UKlZOf5j5_S1VLfkNob0ZKQ[Oa5j5_S1VLfkNib0`KW[O[5k5^S1ULgkNdb0eK\[OV5k5^S1ULfkN_b0lKa[OP5k5^S1ULfkNZb0QLf[Ok4l5]S1TLgkNUb0VLk[Of4l5]S1TLgkNoa0\LQ\O`4m5\S1SLgkNka0bLU\O[4m5\S1SLgkNea0hL[\OU4n5[S1RLhkN`a0mL`\OP4n5[S1RLhkN[a0RMe\Ok3o5ZS1QLhkNVa0YMj\Oe3o5ZS1QLhkNQa0_Mo\O^3o5[S1QLhkNk`0eMU]OX3P6ZS1PLikNf`0jMZ]OS3P6ZS1PLhkNb`0PN^]On2Q6YS1oKikN\`0VNd]Oh2Q6YS1oKikNW`0[Ni]Oc2R6XS1nKjkNQ`0aNo]O]2R6XS1nKikNm?gNS^OX2S6WS1mKjkNh?lNX^OS2S6WS1mKjkNb?RO^^Om1S6WS1mKjkN]?WOc^Oh1T6VS1lKjkNX?^Oh^Ob1T6VS1lKjkNS?Cm^O]1U6US1kKkkNn>HR_OX1U6US1kKkkNh>NX_OR1V6TS1jKkkNd>4\_Om0V6TS1jKkkN^>:b_Og0W6SS1iKlkNY>?g_Ob0W6SS1iKlkNT>d0m_O<V6TS1iKkkNo=k0R@6W6SS1hKlkNj=P1W@1W6SS1hKlkNd=V1]@KX6RS1gKmkN_=[1b@FX6RS1fKmkN\=`1f@AY6QS1eKnkNV=f1l@[OY6QS1eKnkNQ=k1QAVOZ6PS1dKokNk<Q2WAPOZ6PS1dKnkNg<W2[AkNZ6PS1dKnkNb<\2`AfN[6oR1cKokN\<c2eA_N\6oR1cKokNW<h2jAZN]6nR1bKokNR<o2oATN]6nR1bKokNm;T3TBoM^6mR1aKPlNh;Y3YBjM^6mR1aKPlNb;_3_BdM_6lR1`KPlN^;e3dB^M^6mR1`KPlNX;k3jBXM^6mR1`KPlNS;P4oBSM_6lR1_KQlNn:U4TCnL_6lR1_KPlNi:\4YChL`6kR1^KQlNd:a4^CcL`6kR1^KQlN^:g4dC]La6jR1]KRlNY:l4iCXLa6iR1^KRlNT:R5mCSLa6iR1^KRlNn9X5SDmKb6hR1]KSlNi9]5XDiKa6gR1^KSlNc9c5^DcKb6fR1]KSlN_9i5bD^Kb6fR1]KSlNY9o5hDXKc6eR1\KTlNT9T6mDSKc6eR1\KTlNo8Y6REnJd6dR1[KTlNj8`6WEhJd6dR1[KTlNe8e6]EbJc6eR1[KTlN_8k6cE\Jd6dR1ZKUlNZ8P7hEWJd6dR1ZKTlNV8V7lERJe6cR1YKUlNP8\7RFlIe6cR1YKUlNk7a7WFgIf6bR1XKVlNe7h7\F`Ig6bR1XKUlNa7n7`F[Ih6aR1VKWlN]7R8eFVIh6aR1VKWlNW7X8kFPIh6aR1VKWlNR7]8PGkHi6`R1UKWlNm6d8UGeHi6`R1UKWlNh6i8ZG`Hj6_R1TKXlNc6n8_G[Hj6_R1TKXlN]6T9eGUHk6^R1SKXlNY6Z9iGPHk6^R1SKXlNS6`9oGjGl6]R1RKYlNn5e9THeGl6]R1RKYlNi5j9ZH_Gk6^R1RKXlNd5Q:_HYGl6]R1QKYlN_5V:dHTGl6]R1QKYlNY5\:jHnFm6\R1PKZlNT5a:oHiFm6\R1PKYlNP5g:SIdFn6[R1oJZlNj4m:YI^Fn6[R1oJZlNe4R;^IYFo6ZR1nJ[lN_4X;dISFo6ZR1nJZlN[4^;hInEo6ZR1nJZlNV4c;mIiEP7YR1mJ[lNP4i;SJcEP7YR1mJ[lNk3n;XJ^EQ7XR1lJ[lNf3U<]JXEQ7XR1lJ[lNa3Z<bJSER7WR1kJ\lN\3_<gJnDR7WR1kJ\lNV3e<mJhDS7VR1jJ\lNR3l<QKaDS7WR1jJ\lNl2R=WK[DS7WR1jJ\lNg2W=\KVDT7VR1iJ]lNb2\=aKQDT7VR1iJ\lN]2c=fKkCU7UR1hJ]lNX2h=kKfCU7UR1hJ]lNR2n=QL`CV7TR1gJ^lNm1S>VL[CV7TR1gJ]lNi1Y>ZLVCW7SR1fJ^lNc1_>`LPCW7SR1eJ_lN_1c>eLkBW7SR1eJ_lNY1i>kLeBX7QR1eJ`lNT1o>oL`BX7QR1eJ`lNo0T?TM[BY7PR1dJalNi0Z?ZMUBY7PR1dJalNd0_?_MPBZ7oQ1cJalN?f?dMjAZ7oQ1cJalN:k?jMdAZ7oQ1bJblN5P`0oM_AZ7oQ1bJblNOV`0UNYAZ7oQ1bJalNK^=XKo@Q3T3Z7mQ1bJblNE_=cKn@l2T3Z7mQ1bJblN@_=mKn@g2T3[7lQ1aJclN[O_=WLn@b2T3[7lQ1aJblNVOa=aLm@]2T3\7kQ1`JclNSO_=iLo@X2T3\7kQ1`JclNSOZ=nLTAS2T3]7jQ1_JdlNSOU=SMYAn1T3]7jQ1_JclNTOR=VM]Aj1T3]7jQ1_JclNTOm<[McAd1S3_7iQ1^JdlNTOh<`MhA_1S3_7iQ1^JdlNTOc<eMmAZ1S3`7hQ1]JdlNUO_<iMRBU1S3`7hQ1]JdlNUOZ<nMWBP1S3a7gQ1\JelNUOU<SN\Bk0S3a7gQ1\JelNUOP<XNaBg0R3a7gQ1[JflNUOk;]NfBb0R3a7gQ1[JelNVOg;bNjB<S3a7gQ1[JelNVOb;gNoB7S3b7fQ1ZJflNVO];lNTC2S3b7fQ1ZJflNVOX;QOYCMS3c7eQ1YJflNVOU;VO]CHS3c7eQ1YJflNVOP;[ObCCS3d7dQ1XJglNVOk:@gC^OS3d7dQ1XJglNVOg:DkCZOS3e7cQ1WJglNWOc:HPDUOS3e7cQ1WJglNWO^:MUDPOS3e7cQ1WJglNWOY:2ZDkNS3f7bQ1UJilNXOS:7_DfNS3f7bQ1UJhlNYOo9;dDaNS3g7aQ1TJilNYOj9`0iD\NS3g7aQ1TJilNYOe9e0nDWNS3h7`Q1SJjlNYO`9j0SESNR3g7aQ1SJilNZO\9n0XEnMR3h7`Q1RJjlNZOW9S1]EiMR3h7`Q1RJjlNZOR9X1bEdMR3h7`Q1RJjlNZOm8]1gE_MR3i7_Q1QJjlN[Oi8a1lEZMR3i7_Q1QJjlN[Od8f1RFTMQ3k7^Q1PJklN[O_8k1WFoLQ3k7^Q1PJklN[O[8o1[FkLQ3l7]Q1oIklN\OW8S2`FfLQ3l7]Q1oIklN\OR8X2eFaLQ3l7]Q1oIklN\Om7]2jF\LQ3m7\Q1nIllN\Oh7b2oFWLQ3m7\Q1nIklN]Od7f2TGRLQ3n7[Q1mIllN]O_7k2YGmKQ3n7[Q1mIllN]OZ7P3^GhKQ3o7YQ1mInlN\OU7U3cGcKQ3o7YQ1mImlN]OQ7Y3hG_KP3o7YQ1lInlN]Ol6^3mGZKP3o7YQ1lInlN]Og6d3QHTKQ3o7YQ1lInlN]Ob6i3VHoJQ3P8XQ1kInlN]O_6n3ZHjJQ3P8XQ1kInlN]OZ6S4_HeJQ3Q8WQ1jIolN]OU6X4dH`JQ3Q8WQ1jIolN]OQ6\4hH\JQ3R8VQ1iIolN^Om5`4mHWJQ3R8VQ1iIolN^Oh5e4RIRJQ3S8UQ1hIPmN^Oc5j4WImIQ3S8UQ1hIPmN^O^5o4\IhIQ3S8UQ1hIolN_OZ5S5aIcIQ3T8TQ1gIPmN_OU5X5fI^IR3S8SQ1hIPmN_OP5]5kIYIR3T8RQ1gIQmN_Ok4b5PJTIR3T8RQ1fIQmNAf4f5UJoHR3U8QQ1eIRmNAa4k5ZJjHR3U8QQ1eIRmNA\4P6`JeHP3V8QQ1dISmNAW4U6eJ`HP3V8QQ1dIRmNBS4Y6jJ[HP3V8QQ1dIRmNBn3^6oJVHP3W8PQ1cISmNBi3c6TKQHP3W8PQ1cISmNBe3g6XKmGP3X8oP1bISmNCa3k6]KhGP3X8oP1bISmNC\3P7bKcGP3Y8nP1aITmNCW3U7gK^GP3Y8nP1aITmNCR3Z7lKYGP3Z8mP1`ITmNDn2^7QLTGP3Z8mP1`ITmNDi2c7VLoFP3Z8mP1`ITmNDd2h7[LjFP3[8lP1_IUmND_2m7`LeFP3[8lP1_ITmNE[2Q8eL`FP3\8kP1^IUmNEV2V8jL[FP3\8kP1^IUmNEQ2[8oLVFP3]8jP1]IVmNDm1b8RMQFP3\8kP1]IUmNEi1f8WMlEP3]8jP1\IVmNEd1k8\MgEP3]8jP1\IVmNE_1P9aMbEP3]8jP1\IVmNE[1T9eM^EP3^8iP1[IVmNFW1X9jMYEP3^8iP1[IVmNFR1]9oMTEP3_8hP1ZIWmNFm0b9TNoDP3_8hP1ZIWmNFh0g9YNjDP3`8gP1YIWmNGd0k9^NeDP3`8gP1YIWmNG?P:cN`DP3a8fP1XIXmNG:U:iNZDo2b8fP1XIXmNG5Z:nNUDo2b8fP1XIWmNH1^:SOPDo2c8eP1WIXmNHLc:XOkCo2c8eP1WIXmNHGh:]OfCo2d8dP1VIYmNHBm:BaCo2d8dP1VIXmNI^OQ;G]Cn2d8dP1TIZmNJXOV;LXCn2d8cP1UI[mNISO[;1SCn2e8bP1TI\mNIoN_;5oBn2e8bP1TI[mNJkNc;:jBn2e8bP1TI[mNJfNh;?eBn2f8aP1SI\mNJaNm;d0`Bn2f8aP1SI\mNJ\NR<i0[Bn2g8`P1RI\mNKXNV<n0VBn2g8`P1RI\mNKSN[<S1QBn2h8_P1QI]mNKnM`<X1lAn2h8_P1QI]mNKkMc<[1iAn2i8^P1PI]mNLlMb<[1iAn2i8^P1PI]mNLlMb<[1iAn2i8^P1PI]mNLlMb<[1iAn2j8]P1oH^mNKmMc<Z1iAn2j8]P1oH]mNLnMb<Z1iAn2k8\P1nH^mNLnMc<Y1hAo2k8\P1nH^mNLnMc<Y1iAn2k8\P1mH_mNLnMc<Y1iAn2k8\P1mH^mNMoMb<Y1iAn2l8[P1lH_mNMoMb<Y1iAn2l8[P1lH_mNMoMb<Y1iAo2k8ZP1mH_mNMoMb<Z1hAn2m8YP1lH_mNNPNa<Z1hAn2m8YP1lH_mNNPNa<Z1hAn2n8XP1kH`mNNPNa<Z1hAn2n8XP1kH`mNNPNa<Z1hAn2o8WP1jH`mNOQN`<Z1hAn2o8WP1jH`mNOQN`<Z1hAn2P9VP1iHamNOQN`<Z1hAn2P9VP1iHamNOQN`<Z1hAn2P9VP1iH`mN0RN_<Z1hAn2Q9UP1hHamN0RN_<Z1hAn2Q9UP1hHamN0RN_<Z1hAn2R9TP1gHbmN0RN_<Z1iAm2Q9UP1gHamN1SN^<Z1iAm2R9TP1fHbmN1SN^<Z1iAm2R9TP1fHbmN1SN^<Z1iAm2S9SP1dHdmN2RN^<Z1iAm2S9SP1dHcmN3TN\<Y1jAm2S9SP1dHcmN3TN\<Y1jAm2T9RP1cHdmN3TN\<Y1jAm2T9RP1cHdmN3TN\<Y1jAm2U9QP1bHdmN4UN[<Y1jAm2U9QP1bHdmN4UN[<Y1jAm2V9PP1aHemN3VN\<X1jAm2V9PP1aHemN3VN\<X1jAm2V9PP1aHdmN4WN[<X1jAm2W9oo0`HemN4WN[<X1jAm2W9oo0`HemN4WN\<W1iAn2X9no0_HfmN4WN\<W1iAn2X9no0_HemN5XN[<X1iAl2Y9no0^HfmN5XN[<X1iAl2Y9no0^HfmN5XN[<X1iAl2Z9mo0]HgmN5XN[<X1iAl2Z9mo0]HfmN6YNZ<X1iAl2Z9mo0]HfmN6YNZ<X1iAl2[9ko0]HhmN5YNZ<X1iAl2[9ko0]HhmN5YNZ<X1iAl2\9jo0\HhmN6ZNY<X1iAl2\9jo0\HhmN6ZNY<X1iAl2]9io0[HimN6ZNY<X1iAl2]9io0[HimN6ZNY<X1iAl2^9ho0ZHimN7[NX<X1iAl2^9ho0ZHimN7[NX<X1iAl2^9ho0ZHimN7[NX<X1iAl2_9go0YHjmN7[NQN_Nm:i2SEl2_9go0YHimN8\NPNdNh:d2XEl2`9fo0XHjmN8\NPNiNc:_2]El2`9fo0XHjmN8\NPNnN^:Z2cEk2`9fo0WHkmN8\NPNSOY:U2hEk2`9fo0WHjmN9]NoMXOT:P2mEk2a9eo0VHkmN9]NoM]Oo9k1RFk2a9eo0VHkmN9]NoMBj9f1WFk2a9eo0VHkmN9]NoMGe9a1\Fk2b9do0THlmN;]NnML`9\1aFk2b9do0THlmN;]NnM1[9W1fFk2c9co0SHmmN:^NoM5V9R1kFk2c9co0SHmmN:^NoM:Q9m0PGk2d9bo0RHmmN;_NnM?l8h0UGk2d9bo0RHmmN;_NnMd0g8d0YGj2f9ao0QHnmN;_NnMi0b8?^Gj2f9ao0QHnmN;_NnMm0^8;bGj2f9ao0QHmmN<`NmMR1Z85fGl2f9_o0QHnmN<`NmMW1U80kGl2f9_o0QHnmN<`NmM\1P8KPHl2g9^o0PHomN<`NmMa1k7FVHk2f9_o0PHnmN=aNlMf1f7A[Hk2g9^o0oGomN=aNlMk1a7\O`Hk2g9^o0oGomN=aNlMP2\7WOeHk2h9]o0nGPnN=aNlMU2W7ROjHk2h9]o0nGomN>bNlMY2Q7nNoHk2h9]o0nGomN>bNlM^2l6iNTIk2i9\o0mGPnN>bNlMc2g6dNYIk2i9\o0mGPnN>bNlMh2b6_N^Ik2j9[o0lGPnN?dNjMl2^6ZNcIk2j9[o0lGPnN?dNjMQ3Y6UNhIk2k9Zo0kGQnN?dNjMV3T6PNmIk2k9Zo0kGQnN?dNjM[3o5kMRJk2l9Yo0jGQnN`0eNiM`3j5fMWJk2l9Yo0jGQnN`0eNiMe3e5aM\Jk2l9Yo0jGQnN`0eNiMj3`5\MaJk2m9Xo0iGRnN`0eNiMo3[5WMfJk2m9Xo0iGQnNa0fNhMT4V5RMlJj2m9Xo0hGRnNa0fNhMY4Q5mLQKj2m9Xo0hGRnNa0fNhM^4l4hLVKj2n9Wo0gGSnNa0fNhMc4g4cL[Kj2n9Wo0gGRnNb0gNgMh4b4^L`Kj2o9Vo0fGSnNa0hNhMl4]4YLeKj2o9Vo0fGSnNa0hNhMQ5X4ULiKi2P:Vo0fGSnNa0hNhMV5S4PLnKi2Q:Uo0eGSnNb0iNgM[5n3kKSLi2Q:To0eGUnNb0hNgM`5i3fKXLi2R:So0dGVnNb0hNgMd5e3bK\Li2R:So0dGVnNb0hNgMi5`3]KaLi2S:Ro0cGVnNc0iNfMn5[3XKfLi2S:Ro0cGVnNc0iNfMS6W3RKjLj2T:Qo0bGWnNc0iNfMX6R3mJoLj2T:Qo0bGWnNc0iNfM]6m2hJTMj2T:Qo0bGVnNd0jNeMb6h2cJYMj2U:Po0aGWnNd0jNeMg6c2^J^Mj2U:Po0aGWnNd0jNeMl6^2YJdMi2U:Po0`GXnNd0jNeMQ7Y2TJiMi2U:Po0`GXnNd0jNeMV7T2oInMi2V:on0_GXnNe0kNdM[7o1jISNi2V:on0_GXnNe0kNdM`7j1eIXNi2W:nn0^GYnNe0kNdMe7e1`I]Ni2W:nn0^GYnNe0kNdMj7`1[IbNi2W:nn0^GXnNf0lNcMo7[1VIgNi2X:mn0]GYnNf0lNcMR8X1SIjNi2X:mn0]GYnNf0lNcMQ8Y1TIiNi2Y:ln0\GZnNf0lNcMo7[1VIgNi2Y:ln0\GYnNg0mNbMm7]1XIeNi2Z:kn0[GZnNg0mNbMl7^1YIdNi2Z:kn0[GZnNg0mNbMj7`1[IbNi2[:jn0ZG[nNg0mNbMh7b1]I`Ni2[:jn0ZGZnNh0nNaMf7d1_I^Ni2[:jn0ZGZnNh0nNaMe7e1`I]Ni2\:in0YG[nNh0nNaMc7g1cI[Ng2\:jn0YG[nNh0nNbM`7h1fIYNg2]:in0XG[nNh0PObM^7i1gIXNg2]:in0XG[nNh0PObM\7k1iIVNg2^:hn0WG\nNh0PObMZ7m1kITNg2^:hn0WG\nNh0PObMX7o1mIRNg2_:gn0VG\nNi0QOaMW7P2nIQNg2_:gn0VG\nNi0QOaMU7R2PJoMh2^:fn0WG\nNi0QOaMS7T2RJmMh2_:en0VG]nNi0QOaMR7U2SJlMh2_:en0VG\nNj0RO`MP7W2UJjMh2`:dn0UG]nNj0RO`Mn6Y2WJhMh2`:dn0TG^nNk0QO`Ml6\2XJeMi2a:cn0SG_nNk0RO_Mj6^2YJdMi2a:cn0SG^nNl0SO^Mh6`2[JbMi2a:cn0SG^nNl0SO^Mf6b2]J`Mi2b:bn0RG_nNl0SO^Me6c2^J_Mi2b:bn0RG_nNl0SO^Mc6e2`J^Mh2b:bn0QG_nNm0TO]Ma6g2bJ\Mh2b:bn0QG_nNm0TO]M_6i2dJZMh2c:an0PG`nNm0TO]M^6j2eJYMh2c:an0PG`nNm0TO]M\6l2gJWMh2d:`n0oF`nNn0UO\MZ6n2iJUMh2d:`n0oF`nNn0UO\MY6o2jJTMh2d:`n0oF`nNn0UO\MW6Q3lJRMh2e:_n0nFanNn0UO\MU6S3nJPMh2e:_n0nF`nNo0VO[MS6U3PKnLh2f:^n0mFanNo0VO[MR6V3QKmLh2f:^n0mFanNo0VO[MP6X3SKkLh2g:]n0lFbnNo0VO[Mn5Z3VKhLg2h:\n0mFbnNo0WOZMm5[3WKgLg2i:[n0lFcnNo0WOZMk5]3YKeLg2i:[n0lFcnNo0WOZMi5_3[KcLg2i:[n0lFcnNn0XO[Mf5a3]KaLg2j:Zn0kFcnNo0YOZMe5b3^K`Lg2j:Zn0kFcnNo0YOZMc5d3`K_Lf2j:Zn0jFdnNo0YOZMa5f3bK]Lf2j:Zn0jFdnNo0YOZM`5g3cK\Lf2k:Yn0iFdnNP1ZOYM^5i3eKZLf2k:Yn0iFdnNP1ZOYM\5k3gKXLf2l:Xn0hFenNP1ZOYM[5l3hKWLf2l:Xn0hFenNP1ZOYMY5n3jKULf2l:Xn0hFdnNQ1[OXMW5P4lKSLf2m:Wn0gFenNQ1[OXMU5R4nKQLf2m:Wn0gFenNQ1[OXMT5S4oKPLf2n:Vn0fFfnNQ1[OXMR5V4PLmKg2n:Vn0fFenNR1\OWMP5X4RLkKg2o:Un0eFfnNR1\OWMo4Y4SLjKg2o:Un0eFfnNR1\OWMm4[4ULhKg2P;Tn0cFhnNS1[OWMk4]4WLfKg2P;Tn0cFgnNT1\OWMh4^4ZLdKg2P;Tn0cFgnNT1\OWMg4_4[LcKg2Q;Sn0bFhnNT1\OWMe4a4]LbKf2P;Tn0bFhnNT1\OWMc4c4_L`Kf2Q;Sn0aFhnNU1]OVMb4d4`L_Kf2Q;Sn0aFhnNU1]OVM`4f4bL]Kf2R;Rn0`FinNU1]OVM^4h4dL[Kf2R;Rn0`FinNU1]OVM\4j4fLYKf2S;Qn0_FinNV1^OUM[4k4hLWKe2T;Qn0_FinNV1^OUMY4m4jLUKe2T;Qn0_FinNV1^OUMW4o4lLSKe2U;Pn0^FjnNV1^OUMV4P5mLRKe2U;Pn0^FinNW1_OTMT4R5oLPKe2V;om0]FjnNW1_OTMR4T5QMnJe2V;om0]FjnNW1_OTMP4V5SMlJe2W;nm0\FknNV1@UMn3W5TMkJe2W;nm0\FjnNW1ATMl3Y5VMiJe2X;mm0[FknNW1ATMj3[5XMgJe2X;mm0[FknNW1ATMi3\5YMfJe2X;mm0[FknNW1BSMf3_5[MeJe2W;lm0[FknNX1CRMd3a5]McJe2W;lm0[FknNX1CRMb3c5_MaJe2X;km0ZFlnNX1CRMa3d5`M`Je2X;km0ZFlnNX1CRM_3f5bM^Je2Y;jm0YFlnNY1DQM]3h5dM\Je2Y;jm0YFlnNY1DQM\3i5eM[Je2Z;im0XFmnNY1DQMZ3k5gMYJe2Z;im0XFmnNY1DQMX3m5iMWJe2Z;im0XFlnNZ1EPMV3o5kMUJe2[;hm0WFmnNZ1EPMU3Q6kMSJf2[;hm0WFmnNZ1EPMS3S6mMQJf2\;gm0VFnnNZ1EPMQ3U6oMoIf2\;gm0VFmnN[1FoLP3V6PNnIf2];fm0UFnnN[1FoLn2X6RNlIf2];fm0UFnnN[1FoLl2Z6TNjIf2^;em0TFonN[1FoLk2[6UNiIf2^;dm0TFPoN\1FnLi2]6WNgIf2^;dm0TFPoN\1FnLg2_6ZNeId2_;dm0SFQoN\1FnLe2a6\NcId2_;dm0SFQoN\1FnLd2b6]NbId2`;cm0RFQoN]1GmLb2d6_N`Id2`;cm0RFQoN]1GmL`2f6aN^Id2a;bm0QFRoN]1GmL_2g6bN]Id2a;bm0QFRoN]1GmL]2i6dN[Id2b;am0PFRoN^1HlL[2k6fNYId2b;am0PFRoN^1HlLY2m6hNWId2b;am0PFRoN]1ImLW2n6iNVId2c;`m0oESoN]1ImLU2P7kNTId2c;`m0oERoN^1JlLS2R7mNRId2d;_m0nESoN^1JmLQ2R7oNQId2d;_m0nESoN^1JmLo1T7QOoHd2e;^m0mEToN^1JmLm1V7SOmHd2e;^m0mESoN_1KlLk1X7UOkHd2f;]m0lEToN_1KlLj1Y7VOjHd2f;]m0lEToN_1KlLh1[7XOiHc2e;^m0lEToN_1KlLf1]7ZOgHc2f;]m0kEToN`1LkLe1^7[OfHc2f;]m0kEToN`1LkLc1`7]OdHc2g;\m0jEUoN`1LkLa1b7_ObHc2g;\m0jEUoN`1LkL_1d7A`Hc2h;[m0iEUoNa1MjL^1e7B_Hc2h;[m0iEUoNa1MjL\1g7D]Hc2i;Zm0hEVoNa1MjLZ1j7EZHd2i;Zm0hEVoNa1MjLY1k7FYHd2i;Zm0hEUoNb1NiLW1m7HWHd2j;Ym0gEVoNb1NiLU1o7JUHd2j;Ym0gEVoNb1NiLS1Q8MRHc2l;Xm0fEWoNb1NiLR1R8NQHc2l;Xm0fEVoNc1OhLP1T80oGc2m;Wm0eEWoNc1OhLn0V82mGc2m;Wm0eEWoNc1OhLm0W83lGc2m;Wm0eEWoNc1OhLk0Y85kGb2m;Wm0dEWoNd10gLi0[87iGb2m;Wm0dEWoNd10gLg0]89gGb2n;Vm0bEYoNe1OgLf0^8:fGb2n;Vm0bEYoNe10fLc0a8<dGb2o;Um0aEYoNf11eLa0c8>bGb2o;Um0aEYoNf11eL`0d8?aGb2P<Tm0`EZoNe12fL=f8a0_Gb2P<Tm0`EZoNe12fL;h8c0]Gb2P<Tm0`EYoNf13eL:i8d0\Gb2Q<Sm0_EZoNf13eL8k8f0ZGc2P<Rm0`EZoNf13eL6m8h0XGc2Q<Qm0_E[oNf13eL4o8j0VGc2Q<Qm0_EZoNg14dL3P9k0UGc2R<Pm0^E[oNg14dL1R9m0SGc2R<Pm0^E[oNg14dLOT9o0QGc2S<ol0]E\oNg14dLNU9P1PGc2S<ol0]E[oNh15cLLW9R1nFc2S<ol0]E[oNh15cLJY9T1mFb2S<ol0\E\oNh15cLH[9V1kFb2S<nl0]E]oNg15cLG\9W1jFb2T<ml0\E]oNh16bLE^9Y1hFb2T<ml0\E]oNh16bLC`9[1fFb2U<ll0[E^oNh16bLBa9\1eFb2U<ll0[E^oNh16bL@c9_1bFa2W<kl0ZE^oNi17aL^Of9`1_Fb2W<kl0ZE^oNi17bL[Og9c1]Fb2W<kl0ZE^oNi17bLZOh9d1\Fb2X<jl0YE_oNi17bLXOj9f1ZFb2X<jl0YE^oNj18aLVOl9h1XFb2Y<il0XE_oNj18aLUOm9i1WFb2Y<il0XE_oNj18aLSOo9k1UFb2Z<hl0WE`oNj18aLQOQ:m1SFb2Z<hl0WE_oNk19`LoNS:o1QFb2[<gl0VE`oNk19`LnNT:P2PFb2[<gl0VE`oNk19`LlNV:R2oEa2Z<hl0VE`oNk19`LjNX:T2mEa2[<gl0UE`oNl1:_LiNY:U2lEa2[<gl0UE`oNk1;`LfN[:W2jEa2\<fl0TEaoNk1;`LdN]:Y2hEa2\<fl0SEboNl1:`LbN_:[2fEa2]<el0REboNm1;_LaN`:\2eEa2]<el0REboNm1;_L_N[:e2jEZ2^<dl0QEcoNm1;_L]NQ:S3TFn1^<dl0QEcoNm1;_L\Nf9`3_Fb1^<dl0QEboNn1<^LZN\9n3iFV1_<cl0PEcoNn1<^LXNR9\4SGj0_<cl0PEcoNn1<^LVNh8j4]G>`<bl0oDdoNn1<^LUN]8W5hG2`<bl0oDcoNo1=]LSNR8f5SHEa<al0nDdoNo1=]LQNh7T6]HYOa<al0nDdoNo1=R7a4`EmNb<`l0mDeoNo1=f6m4mE`Na<al0mDdoNP2>Y6Z5XFSNb<al0mDdoNP2>m5f5dFgMc<`l0lDeoNP2>`5S6QGZMc<`l0lDeoNP2>T5_6]GnLd<_l0kDeoNQ2?g4k6iGbLd<_l0kDeoNQ2?[4W7UHVLe<^l0jDfoNQ2?o3c7aHjKe<^l0jDfoNQ2`0b3n7nH^Kf<]l0iDfoNR2a0U3Z8ZIRKf<]l0iDfoNR2a0h2g8gIeJf<]l0iDfoNR2a0\2S9SJYJg<\l0hDgoNR2a0P2_9_JmIg<\l0hDfoNS2b0c1k9kJaIh<[l0gDgoNS2b0W1W:WKUIh<[l0gDgoNS2b0k0c:cKiHi<Zl0fDhoNS2b0>P;PL\Hi<Zl0fDgoNT2c01\;\LPHj<Yl0eDhoNS2d0Fg;iLcGi<Zl0eDhoNS2d0ZOS<UMWGi<Zl0eDhoNS2d0nN_<aMlFi<Xl0eDhoNT2e0aNk<mM`Fi<Xl0eDhoNT2e0UNW=YNTFj<Wl0dDioNT2e0hMd=fNgEj<Vl0eDjoNS2e0\MP>RO[Ek<Ul0cDloNT2d0PM\>^OoDk<Ul0cDloNT2d0dLh>JcDl<Tl0bDmoNT2d0XLT?6WDl<Tl0bDmoNT2d0lK`?b0kCl<Tl0bDnoNS2c0`Km?o0^Cm<Sl0aDooNS2c0TKZ`0Z1QCn<Sl0aDooNS2c0hJf`0f1eBo<Rl0`DPPOS2c0\JRa0R2YBo<Rl0`DPPOS2c0PJ^a0^2mAP=Ql0_DQPOS2c0dIja0j2aAP=Ql0_DQPOS2c0XIVb0W3TAP=Ql0^DRPOS2Re0_Lk^OP=Ql0^DRPOS2Re0_Lk^OP=Ql0^DRPOS2Re0_Lk^OQ=Pl0]DTPOR2Qe0`Lk^OQ=Pl0]DTPOR2Qe0`Lk^OR=ok0\DUPOR2Qe0`Lk^OR=ok0\DUPOR2Qe0`Lk^OS=nk0[DVPOR2Qe0`Lk^OS=nk0[DVPOR2Qe0`Lk^OT=mk0ZDWPOR2Qe0`Lk^OT=mk0ZDWPOR2Qe0`Lk^OT=mk0ZDWPOR2Qe0`Lk^OU=lk0YDXPOR2Qe0`Lk^OU=lk0YDXPOQ2Re0aLj^OV=kk0XDZPOP2Qe0bLj^OV=kk0XDZPOP2Qe0bLj^OW=jk0WD[POP2Qe0cLi^OV=kk0WD[POP2Qe0cLi^OV=kk0WD[POP2Qe0cLi^OW=jk0VD\POP2Qe0cLi^OW=jk0VD\POP2Qe0cLi^OX=ik0UD]POP2Qe0cLi^OX=ik0UD]POP2Qe0cLi^OY=hk0TD^POP2Re0bLh^OZ=hk0TD_POo1Qe0cLh^O[=gk0SD`POo1Qe0cLh^O[=gk0SD`POo1Qe0cLh^O[=gk0RDaPOP2Pe0cLh^O\=fk0QDbPOP2Pe0cLh^O\=fk0QDbPOP2Pe0cLh^O]=ek0PDcPOP2Pe0cLh^O]=ek0PDcPOP2Pe0cLh^O^=dk0oCdPOP2Pe0cLh^O^=dk0oCdPOP2Pe0cLh^O_=ck0nCfPOo1od0eLg^O^=dk0nCfPOo1od0eLg^O^=dk0nCfPOo1od0eLg^O_=ck0mCgPOo1od0eLg^O_=ck0mCgPOo1od0eLg^O`=bk0lChPOo1od0eLg^O`=bk0lChPOo1od0eLg^Oa=ak0kCiPOo1od0eLg^Oa=ak0kCiPOo1od0eLg^Ob=_k0kCkPOn1od0eLg^Ob=_k0kCkPOn1od0eLg^Ob=_k0kClPOl1od0gLf^Oc=^k0jCmPOl1od0gLg^Ob=]k0kCmPOl1od0gLg^Oc=\k0jCnPOl1od0gLg^Oc=\k0jCnPOl1od0gLg^Od=[k0iCoPOl1od0gLg^Od=[k0iCoPOl1Pe0gLe^Oe=[k0hCPQOl1Pe0gLe^Oe=[k0hCPQOl1Pe0gLe^Oe=[k0hCPQOl1Pe0gLe^Of=Zk0gCRQOk1od0hLe^Of=Zk0gCRQOk1od0hLe^Og=Yk0fCSQOk1od0hLe^Og=Yk0fCSQOk1od0hLe^Oh=Xk0eCTQOk1od0hLe^Oh=Xk0eCTQOk1od0hLe^Oi=Wk0dCUQOk1od0hLe^Oi=Wk0dCUQOk1od0hLe^Oi=Wk0dCUQOk1od0hLe^Oj=Vk0bCWQOl1nd0hLe^Oj=Vk0bCWQOl1nd0hLe^Ok=Uk0aCYQOk1md0iLe^Ok=Uk0aCYQOk1md0iLe^Ol=Tk0`CZQOk1md0jLd^Ok=Uk0`CZQOk1md0jLd^Ol=Tk0_C[QOk1md0jLd^Ol=Tk0_C[QOk1md0jLd^Ol=Tk0_C[QOk1md0jLd^Om=Sk0^C\QOk1md0jLd^Om=Sk0^C\QOk1md0jLd^On=Rk0]C]QOk1md0jLd^On=Rk0]C^QOi1md0lLc^Oo=Qk0\C_QOi1md0lLc^Oo=Qk0\C_QOi1Ua0aIe@[3f1P>Pk0[C`QOi1m`0iIm@S3f1P>Pk0[C`QOi1d`0RJWAi2e1Q>Pk0[C`QOi1\`0ZJ_Aa2e1R>oj0ZCaQOi1S`0cJhAX2e1R>oj0ZCaQOi1k?kJPBP2e1S>nj0YCbQOi1c?SKXBh1e1S>nj0YCbQOi1Z?\KaB_1e1T>mj0XCdQOh1Q?eKiBX1d1S>nj0XCdQOh1h>nKRCo0d1T>mj0WCeQOh1`>VLZCg0d1T>mj0WCeQOh1W>_LcC>d1T>mj0WCeQOh1o=gLkC6d1U>lj0VCfQOh1f=PMTDMd1U>lj0VCfQOh1^=XM\DEd1V>kj0UCgQOh1V=`MdD]Od1V>kj0UCgQOh1m<iMmDTOd1W>jj0TChQOh1e<QNUElNd1W>jj0TChQOh1\<ZN^EcNd1X>ij0SCjQOg1S<cNfE[Nd1X>ij0SCjQOg1j;lNoERNd1X>hj0TCkQOf1b;TOWFjMd1Y>gj0SClQOf1Y;]O`FaMd1Y>gj0RCmQOg1P;FgFXMe1Z>fj0QCnQOg1h:NoFPMe1Z>fj0QCnQOg1_:7XGhLd1Z>fj0PCoQOg1W:?`G`Ld1Z>fj0PCoQOg1n9h0iGWLd1[>ej0oBPROg1f9P1QHoKd1[>ej0oBQROe1]9[1YHfKd1[>ej0oBQROe1U9c1aH^Ke1[>cj0oBRROe1l8l1kHTKd1\>cj0oBRROe1d8T2SIlJd1]>bj0nBSROe1\8\2[IdJd1]>bj0nBSROe1S8e2dI[Jd1^>aj0mBTROe1k7m2lISJd1^>aj0mBTROe1b7V3UJjId1_>`j0lBUROe1Z7^3]JbId1_>`j0lBUROe1Q7g3fJYId1_>`j0lBUROe1i6o3nJQId1`>_j0kBWROd1_6Y4WKhHd1`>_j0kBWROd1W6a4_K`Hd1a>^j0jBXROd1o5i4gKYHc1`>_j0jBXROd1f5R5PLPHc1a>^j0iBYROd1^5Z5XLhGc1a>^j0iBYROd1U5c5aL_Gc1a>^j0iBYROd1m4k5iLWGc1b>]j0hBZROd1d4T6RMnFc1b>]j0hBZROd1\4\6ZMfFc1c>\j0gB[ROd1S4e6cM]Fc1c>\j0gB\ROc1j3n6kMUFc1d>[j0fB]ROc1b3V7SNmEc1d>[j0fB]ROc1Y3_7\NdEc1e>Zj0eB^ROc1Q3g7dN\Ec1e>Zj0eB^ROc1h2P8mNSEc1e>Zj0eB^ROc1`2X8UOkDc1f>Yj0dB_ROc1W2a8^ObDc1f>Yj0dB_ROc1o1i8FZDc1g>Xj0cB`ROc1f1R9OQDc1g>Xj0cB`ROc1^1Z97iCc1h>Wj0bBaROc1V1b9`0aCa1h>Xj0aBcROb1l0m9h0XCa1i>Wj0`BdROb1d0U:P1PCa1i>Wj0`BdROb1?Z:U1kBa1i>Wj0`BdROb1?Z:U1kBa1j>Vj0_BeROb1?Z:U1kBa1j>Vj0_BeROb1?Z:U1kBa1k>Uj0^BfROb1?Z:U1kBa1k>Uj0^BfROb1>\:U1iBb1l>Tj0]BgROb1>\:U1iBb1l>Tj0]BgROb1>\:U1iBb1m>Sj0\BiROa1=]:U1iBb1m>Sj0\BiROa1=]:U1iBb1m>Sj0\BiROa1=]:U1iBb1n>Rj0[BjROa1=]:U1iBb1n>Rj0[BjROa1=]:U1iBb1o>Qj0ZBkROa1=]:U1iBb1o>Pj0[BlRO`1=]:U1jBa1o>Pj0ZBmRO`1<^:V1iBa1o>Pj0ZBmRO`1<^:V1iBa1P?oi0YBnRO`1<^:V1iBa1P?oi0YBoRO_1;_:V1iBa1P?oi0YBoRO_1;_:V1iBa1Q?ni0XBPSO_1;_:V1iBa1Q?ni0XBPSO_1;_:V1iBa1R?mi0WBQSO_1;_:V1iBa1R?mi0WBQSO_1;_:V1iBa1S?li0VBRSO_1;_:V1iBa1S?li0VBRSO_1:`:W1hBa1T?ki0UBSSO_1:`:X1gB`1U?ki0UBSSO_1:`:X1gB`1U?ki0UBSSO_1:`:X1gB`1V?ji0TBUSO]1:b:W1gBa1U?ii0UBUSO]1:b:W1gBa1V?hi0TBVSO]1:b:W1hB`1U?ii0TBVSO]1:b:W1hB`1V?hi0SBWSO]1:b:W1hB`1V?hi0SBWSO]19c:X1gB`1W?gi0QBYSO^18c:X1gB`1W?gi0QBYSO^18c:X1gB`1W?gi0QBYSO^18c:X1gB`1X?fi0PBZSO^18c:X1gB`1X?fi0PB[SO]17f7fMnDb3g0`1Y?ei0oA\SO]17b7jMRE^3g0`1Y?ei0oA\SO]17^7nMVEZ3g0`1Z?di0nA]SO]17Z7RNZEV3g0`1Z?di0nA]SO]17U7WN_EQ3g0`1[?ci0mA^SO]16R7\NbEm2g0`1[?ci0mA^SO]16n6`NfEi2g0`1[?ci0mA^SO]16j6dNjEe2g0`1\?bi0lA_SO]16e6iNoE`2g0`1\?bi0lA_SO]16a6mNSF\2g0`1]?ai0kA`SO]16]6QOWFX2h0_1\?bi0kAaSO\15Y6VO]FR2g0`1]?ai0jAbSO\15U6ZOaFn1g0`1]?ai0jAbSO\15Q6^OeFj1g0`1^?`i0iAcSO\14n5ChFf1g0`1^?`i0iAcSO\14i5HmFa1g0`1^?`i0iAcSO\14e5LQG^1f0_1`?_i0hAdSO\14a50UGZ1f0_1`?_i0hAdSO\14]54YGV1f0_1a?^i0gAeSO\14X58_GR1e0_1a?^i0gAeSO\14T5<cGn0e0_1b?]i0fAgSO[13Q5`0gGj0e0_1b?]i0fAgSOZ14n4c0kGf0e0_1c?\i0eAhSOZ14i4h0PHa0e0_1c?\i0eAhSOZ13f4m0SH=e0_1c?\i0eAhSOZ13b4Q1WH9e0_1d?[i0dAiSOZ13]4V1\H4e0_1d?[i0dAiSOZ13Y4Z1`H0f0^1d?[i0cAjSOZ13U4^1dHLf0^1d?[i0cAjSOZ13Q4b1hHHf0^1e?Yi0cAlSOY13l3g1mHCf0^1e?Yi0cAmSOX12i3k1QI_Of0^1f?Xi0bAnSOX12e3o1UI[Of0^1f?Xi0aAoSOY11a3S2YIWOf0^1f?Xi0aAoSOY10]3Y2]IROf0^1g?Wi0`APTOY10Y3]2aInNf0^1g?Wi0`APTOY10U3a2eIjNf0^1h?Vi0_AQTOY10Q3e2iIfNf0^1h?Vi0_AQTOY10l2j2nIaNf0^1i?Ui0^ARTOY10h2n2RJ]Nf0^1i?Ui0^ARTOY10d2R3VJYNf0^1j?Ti0]ASTOY10`2V3ZJUNf0^1j?Ti0]ATTOX1O\2[3_JPNf0^1j?Ti0]ATTOX1NY2`3bJlMf0^1k?Si0\AUTOX1NU2d3fJhMg0]1j?Ti0\AUTOX1NP2i3kJdMf0\1l?Si0[AVTOX1Nl1m3oJ`Mf0\1l?Si0[AVTOX1Nh1Q4SK\Mf0\1m?Ri0ZAWTOX1Nd1U4WKXMf0\1m?Ri0ZAWTOX1N_1Z4\KSMf0\1m?Ri0ZAWTOX1N[1^4`KoLf0\1n?Qi0YAXTOX1NW1b4dKkLf0\1n?Qi0YAYTOW1MT1f4hKgLf0]1n?oh0YAZTOV1MQ1k4lKbLf0]1n?oh0YAZTOV1Mm0o4PL^Lf0]1o?nh0XA[TOV1Mi0S5TLZLf0]1o?nh0XA[TOV1Me0V5ZLVLd0^1P`0mh0WA\TOV1M`0[5_LQLd0^1P`0mh0WA\TOV1M<_5cLmKd0^1P`0mh0WA\TOV1M8c5gLiKd0^1Q`0lh0VA]TOV1M4g5kLeKd0^1Q`0lh0VA]TOV1MOl5PM`Kd0^1R`0kh0UA^TOV1LLQ6SM\Ke0]1Q`0lh0UA_TOU1KIU6WMXKe0]1R`0kh0TA`TOU1KDZ6\MSKe0]1R`0kh0TA`TOU1K@^6`MoJe0]1S`0jh0SAaTOU1K\Ob6dMkJe0]1S`0jh0SAaTOU1KXOf6hMgJe0]1S`0jh0SAaTOU1KSOk6mMbJe0]1T`0ih0RAbTOU1KoNo6QN^Je0]1T`0ih0RAbTOU1KkNS7UNZJe0]1U`0hh0PAdTOV1JgNW7YNVJe0]1U`0hh0PAdTOV1IcN]7]NQJe0]1V`0gh0o@fTOU1H`Na7aNmIe0]1V`0gh0o@fTOU1H\Ne7eNjId0\1X`0fh0n@gTOU1HXNi7iNfId0\1X`0fh0n@gTOU1HSNn7nNaId0\1X`0fh0n@gTOU1HoMR8RO]Id0\1Y`0eh0m@hTOU1HkMV8VOYId0\1Y`0eh0m@hTOU1HfM[8[OTIe0[1Y`0eh0l@iTOU1HbM_8_OPIe0[1Y`0eh0l@iTOU1H^Mc8ClHe0[1Z`0dh0k@jTOU1G[Mh8FhHe0[1Z`0dh0k@jTOU1GVMm8KcHe0[1[`0ch0j@lTOT1FSMQ9O_He0[1[`0ch0j@lTOS1GPMT93[He0[1[`0bh0k@mTOR1GlLX97WHe0[1\`0ah0j@nTOR1GiL[9:THe0[1\`0ah0j@nTOR1GkLY98VHe0[1]`0`h0i@oTOR1GnLV95YHe0[1]`0`h0i@oTOR1GPMT93[He0[1^`0_h0h@PUOR1FTMR9O^He0[1^`0_h0h@PUOR1FWMo8LaHe0[1_`0^h0g@QUOR1FYMl8KdHd0[1_`0^h0g@RUOQ1E]Mi8HgHd0[1_`0^h0g@RUOQ1E`Mf8EjHd0[1``0]h0f@SUOQ1EcMc8BmHe0Z1_`0^h0f@SUOQ1EeMa8@oHe0Z1``0]h0e@TUOQ1EhM^8]ORIe0Z1``0]h0e@TUOQ1EkM[8ZOUIe0Z1a`0\h0d@UUOQ1EnMX8WOXIe0Z1a`0\h0d@UUOQ1DQNW8UOYId0[1b`0[h0c@VUOQ1DTNT8RO\Id0[1b`0[h0c@VUOQ1DWNQ8oN`Ic0Z1b`0\h0d@VUOP1CZNo7mNbIc0Z1b`0\h0d@VUOP1C]Nl7jNeIc0Z1a`0]h0e@UUOP1C`Ni7gNhIc0Z1``0^h0f@TUOP1CcNf7dNkIc0Z1``0^h0e@UUOQ1BeNd7bNmIc0Z1_`0_h0f@TUOQ1BhNa7_NPJc0Z1^`0`h0g@SUOQ1AlN_7[NSJc0Z1^`0`h0g@SUOQ1AoN\7XNVJc0Z1]`0ah0h@RUOQ1AQOZ7VNXJc0Z1\`0bh0i@QUOQ1ATOW7SN[Jc0Z1\`0bh0i@QUOQ1AWOT7PN^Jd0Z1Y`0ch0k@QUOP1@ZOR7nM`Jd0Z1X`0dh0l@PUOo0A^On6kMcJd0Z1X`0dh0l@PUOo0AAk6hMfJd0Z1W`0eh0m@oTOo0ADh6eMiJd0Z1V`0fh0n@nTOo0AFf6cMkJd0Z1V`0fh0n@nTOo0@Jd6_MnJd0Z1U`0gh0o@mTOo0@Ma6\MQKd0Z1T`0hh0PAlTOo0@O_6ZMSKd0Z1T`0hh0PAlTOo0@2\6WMVKd0Z1S`0ih0QAkTOo0@5Y6TMYKd0Z1R`0jh0RAkTOn0_O9V6QM\Kd0Z1R`0jh0RAkTOn0_O;T6oL^Kd0Z1Q`0kh0SAjTOn0_O>Q6lLaKd0Z1P`0lh0TAiTOn0_Oa0n5iLdKd0Z1P`0lh0TAiTOn0_Od0j5gLhKc0Z1o?mh0UAhTOn0^Og0i5dLjKc0Z1n?nh0VAgTOn0^Oj0f5aLmKd0Y1m?oh0VAgTOn0^Om0c5^LQLc0X1m?Pi0WAfTOn0^Oo0a5\LSLc0X1m?Pi0WAfTOn0^OR1^5YLVLc0X1l?Qi0XAeTOn0^OU1[5VLYLc0X1k?Ri0YAeTOm0]OY1X5SL\Lc0X1k?Ri0YAeTOm0]O[1V5QL^Lc0X1j?Si0ZAdTOm0]O^1S5nKaLc0X1i?Ti0[AcTOm0\Ob1Q5jKdLc0X1i?Ti0[AcTOm0\Oe1n4gKgLc0X1h?Ti0]AcTOl0\Og1l4eKiLc0X1g?Ui0^AbTOl0\Oj1i4bKlLc0X1g?Ui0^AbTOl0\Om1f4_KoLc0X1f?Vi0_AaTOl0\Oo1d4]KQMc0X1e?Wi0_AaTOm0[OR2a4ZKTMc0X1e?Wi0_AbTOl0ZOV2^4XKVMb0Y1d?Xi0`AaTOl0ZOY2[4UKYMb0Y1c?Yi0aA`TOk0[O\2X4SK[Mc0X1b?Zi0aA`TOk0ZO`2V4oJ^Mc0X1a?[i0bA_TOk0ZOc2S4lJaMc0X1`?\i0cA^TOk0ZOe2Q4jJcMc0X1`?\i0cA^TOk0ZOh2n3gJfMc0X1_?]i0dA]TOk0ZOk2k3dJiMc0X1^?^i0eA\TOk0ZOn2h3aJlMc0X1^?^i0eA\TOk0ZOP3f3_JnMc0X1]?_i0fA\TOj0YOT3c3\JQNc0X1\?`i0gA[TOj0YOW3`3YJTNc0X1\?`i0gA[TOj0XO[3^3UJWNc0X1[?ai0hAZTOj0XO]3\3SJYNc0X1Z?bi0iAYTOj0XO`3Y3PJ\Nc0X1Z?bi0iAYTOj0XOc3V3mI`Nb0W1Z?ci0jAXTOj0XOe3T3kIbNb0W1Y?di0kAWTOj0XOh3Q3hIeNb0W1Y?di0kAWTOj0XOk3n2eIhNb0W1X?ei0lAVTOj0XOn3k2bIkNb0W1W?fi0mAUTOj0XOP4h2aInNb0V1V?gi0mAVTOi0WOT4e2^IQOb0V1U?hi0nAUTOi0VOX4c2ZITOb0V1T?ii0oATTOi0VOZ4a2XIVOb0V1T?ii0oATTOi0VO]4^2UIYOb0V1S?ji0PBSTOi0VO`4[2RI\Ob0V1R?ki0QBRTOi0VOc4X2oH_Ob0V1R?ki0QBRTOi0VOe4V2mHAb0V1Q?li0RBQTOi0VOh4S2jHDb0V1P?mi0SBPTOi0VOk4P2gHGb0V1P?mi0SBPTOi0VOn4m1dHJb0W1n>mi0UBPTOh0UOQ5k1bHLb0W1m>ni0VBoSOh0TOU5i1^HOb0W1m>ni0VBoSOg0UOY5e1[H2b0W1l>oi0WBnSOg0UO[5c1YH4b0W1k>Pj0XBmSOg0UO^5`1VH7b0W1k>Pj0XBmSOg0UOa5]1SH:b0W1j>Qj0XBmSOh0TOd5Z1PH=c0V1h>Sj0YBlSOh0TOf5X1nG?c0V1h>Sj0YBlSOh0TOi5U1kGb0c0V1g>Tj0ZBkSOh0TOl5R1hGe0c0V1f>Uj0[BjSOh0SOP6P1dGh0c0V1f>Uj0[BkSOg0ROS6n0bGj0c0V1e>Vj0\BjSOg0ROV6k0_Gm0c0V1e>Vj0\BjSOg0ROY6h0\GQ1b0U1e>Wj0]BiSOg0RO[6f0[GR1a0V1d>Xj0^BhSOg0RO^6c0XGU1a0V1d>Xj0^BhSOg0ROa6`0UGX1a0V1c>Yj0_BgSOg0ROd6=RG[1a0V1b>Zj0`BfSOg0ROf6;PG]1a0V1b>Zj0`BfSOg0ROi68mF`1a0V1a>Zj0bBfSOf0QOm66iFc1a0V1`>[j0cBfSOe0POP74gFe1a0V1`>[j0cBfSOe0POS71dFh1a0V1_>\j0dBeSOe0POV7NaFk1b0U1]>^j0eBdSOe0POY7K^Fn1b0U1]>^j0eBdSOe0PO[7I\FP2b0U1\>_j0fBcSOe0PO^7EZFT2a0U1[>`j0gBbSOe0POa7BWFW2a0U1[>`j0gBbSOe0POd7_OTFZ2a0U1Z>aj0hBaSOe0oNg7^OQF\2a0U1Y>bj0iB`SOe0oNj7[OnE_2a0U1Y>bj0iB`SOe0oNm7XOkEb2a0U1X>cj0jB`SOd0nNP8VOiEd2a0U1W>dj0kB_SOd0nNS8SOfEg2a0U1W>dj0kB_SOc0oNW8oNcEj2a0U1V>ej0lB^SOc0oNZ8lN`Em2a0U1U>fj0mB]SOc0oN\8jN^Eo2a0U1U>fj0mB]SOc0oN_8gN[ER3a0U1T>gj0nB\SOc0oNb8dNXEU3a0U1S>hj0oB[SOc0nNf8bNTEX3a0U1S>hj0oB[SOc0nNh8`NREZ3a0U1R>ij0PCZSOc0nNk8]NoD]3b0T1P>kj0QCZSOb0mNo8ZNlDa3a0S1Q>kj0PC[SOc0lNQ9XNjDc3a0S1P>lj0QCZSOc0lNT9UNgDf3a0S1o=mj0RCYSOc0lN\<k1PBS1o=mj0RCYSOc0lN\<k1PBS1n=nj0SCXSOc0lN\<k1PBS1m=oj0TCWSOc0lN\<k1PBS1m=oj0TCWSOc0kN]<l1oAS1l=Pk0UCVSOc0kN]<l1oAS1k=Qk0VCUSOc0kN]<l1oAS1k=Qk0VCVSOb0jN^<l1oAS1j=Rk0WCUSOb0jN^<l1oAS1i=Sk0XCTSOb0jN^<l1oAS1i=Sk0XCTSOb0jN^<l1oAS1h=Tk0YCSSOb0jN^<l1oAS1g=Uk0ZCRSOb0jN^<l1oAS1g=Uk0ZCRSOb0iN_<m1oAR1e=Wk0[CQSOb0iN`<l1nAS1d=Xk0\CPSOb0iN`<l1nAT1c=Wk0]CPSOb0iN`<l1nAT1b=Xk0^CoROb0iN`<l1nAT1a=Yk0_CoROa0hNa<l1nAT1a=Yk0_CoROa0hNa<l1nAT1`=Zk0`CnRO`0iNb<k1nAT1_=[k0aCmRO`0iNb<k1nAT1_=[k0aCmRO`0iNb<k1nAT1^=\k0bClRO`0hNc<l1mAT1]=]k0cCkRO`0hNc<l1mAT1]=]k0cCkRO`0hNc<l1mAT1\=^k0dCjRO`0hNc<m1lAS1]=^k0dCjRO`0hNc<m1lAS1\=_k0eCjRO?gNd<m1lAS1[=`k0fCiRO?gNd<m1lAS1[=`k0fCiRO?gNd<m1mAR1Y=ak0hCiRO>gNd<m1mAR1X=bk0iChRO>fNe<n1lAR1X=bk0iChRO>fNe<n1lAR1W=ck0jCgRO>fNe<n1lAR1V=dk0jCgRO?eNe<n1lAR1V=dk0jCgRO?eNe<n1lAR1U=ek0kCfRO?eNe<n1lAR1T=fk0lCeRO?eNe<n1lAR1T=fk0lCfRO>dNf<n1lAR1S=gk0mCeRO>dNf<n1lAR1R=hk0nCdRO>dNf<n1lAR1R=hk0nCdRO>cNg<o1kAR1Q=ik0oCcRO>cNg<o1kAR1P=jk0PDbRO>cNg<o1kAR1P=jk0PDbRO>cNg<o1kAR1o<kk0QDaRO>cNg<o1kAR1n<lk0RD`RO>cNg<o1kAR1n<lk0RD`RO>cNg<o1lAQ1l<nk0SD`RO=bNh<o1lAQ1k<ok0TD_RO=bNh<o1lAQ1k<ok0TD_RO=bNh<o1lAQ1j<Pl0UD^RO<bNj<o1kAQ1i<Ql0VD]RO<bNj<o1kAQ1i<Ql0VD]RO<bNj<P2jAP1i<Rl0WD\RO<bNj<P2jAP1h<Sl0XD[RO<bNj<P2jAP1h<Sl0XD[RO<nN^<d1VBP1g<Tl0YDZRO<Eg;m0mBP1f<Ul0ZDZRO;;R;5cCQ1f<Ul0ZDZRO;R1[:^OZDQ1e<Vl0[DYRO;i1d9gNQEQ1d<Wl0\DXRO;`2m8PNhEQ1d<Wl0\DXRO;W3V8YM_FQ1c<Xl0]DWRO;n3_7bLVGQ1b<Yl0^DVRO;e4h6kKnGP1a<Zl0^DVRO;\5Q6TKeHP1`<[l0_DURO;S6Z5]J\IP1_<\l0`DTRO;j6c4fISJP1_<\l0`DTRO;a7l3oHjJP1^<]l0aDTRO:V8W3YH`KP1]<^l0bDSRO:m8`2bGWLP1]<^l0bDSRO:d9i1kFnLP1\<_l0bDSRO;Z:R1TFeMP1[<`l0cDRRO;Q;;]E\NP1[<`l0cDRRO;h;DfDSOP1Z<al0dDQRO;_<mNoCJP1Y<bl0eDPRO;V=VNXCa0Q1X<al0fDPRO;m=_MaBX1Q1W<bl0gDoQO;d>hLjAo1Q1V<cl0hDoQO:Z?RLSAf2Q1V<cl0hDoQO:Q`0[K\@]3Q1U<dl0iDnQO:Ud0iNX]OT<el0iDnQO9Wd0iNV]OT<fl0jDmQO9Wd0iNV]OS<gl0kDlQO9Wd0iNV]OS<fl0lDmQO8Wd0iNV]OR<gl0mDlQO8Wd0iNV]OQ<hl0nDkQO8Wd0iNV]OQ<hl0nDkQO8Wd0iNV]OP<il0oDjQO8Wd0iNV]Oo;jl0PEjQO7Vd0jNV]Oo;jl0PEjQO7Vd0jNV]On;kl0QEiQO7Vd0jNV]Om;ll0REhQO7Vd0jNV]Om;ll0REhQO7Vd0jNV]Ol;ml0SEgQO7Vd0jNV]Ok;nl0TEfQO7Vd0jNV]Ok;nl0TEfQO7Vd0jNV]Oj;ol0UEeQO7Vd0jNV]Oi;Pm0VEdQO7Vd0kNU]Oh;Qm0VEeQO6Ud0lNU]Og;Rm0WEdQO6Ud0lNU]Of;Sm0XEcQO6Ud0lNU]Of;Sm0XEcQO6Ud0lNU]Oe;Tm0YEbQO6Ud0lNU]Od;Um0ZEaQO6Ud0lNU]Od;Um0ZEaQO6Ud0lNU]Oc;Vm0[E`QO6Ud0lNU]Ob;Wm0\E_QO6Ud0lNU]Ob;Wm0[E`QO7Td0lNU]Oa;Xm0\E`QO6Sd0mNU]O`;Ym0]E_QO6Td0lNT]Oa;Ym0]E_QO6Td0lNT]O`;Zm0^E^QO6Td0lNT]O_;[m0_E]QO5Ud0mNS]O_;[m0_E]QO5Ud0mNS]O^;\m0`E\QO5Ud0nNR]O\;^m0aE[QO5Ud0nNR]O\;^m0aE[QO5Ud0nNR]O[;_m0bEZQO5Ud0nNR]OZ;`m0cEYQO5Ud0nNR]OZ;`m0cEZQO4Td0oNR]OY;am0dEYQO4Td0oNR]OX;bm0eEXQO4Td0oNR]OX;bm0eEXQO4Td0oNR]OW;cm0fEWQO4Td0oNR]OV;dm0gEVQO4Td0oNR]OV;dm0gEVQO4Td0oNR]OU;em0hEUQO4Td0oNR]OT;fm0iETQO4Td0oNR]OT;fm0iETQO4Td0oNR]OS;gm0jETQO3Sd0POR]OR;hm0kESQO3Sd0POR]OR;hm0kESQO3Sd0QOQ]OP;jm0lERQO3Sd0QOQ]Oo:km0mEQQO3Sd0QOQ]Oo:km0mEQQO3Sd0QOQ]On:lm0nEPQO3Sd0QOQ]On:lm0nEPQO3Sd0QOR]Ol:lm0PFoPO3Sd0QOR]Ok:mm0QFnPO3Td0POQ]Ol:lm0RFoPO2Td0POQ]Ok:mm0SFoPO1Sd0QOQ]Oj:nm0TFnPO1Sd0QOQ]Oj:nm0TFnPO1Sd0QOQ]Oi:om0UFmPO0Td0ROP]Oh:Pn0UFmPO1Sd0ROP]Oh:Pn0UFmPO1Sd0ROP]Og:Qn0VFlPO1Sd0ROP]Of:Rn0WFkPO1Sd0ROP]Of:Rn0WFkPO1Sd0ROP]Oe:Sn0XFjPO1Sd0SOo\Oc:Un0YFjPO0Rd0TOo\Oc:Un0YFjPO0Rd0TOo\Ob:Vn0ZFiPO0Rd0TOo\Oa:Wn0[FhPO0Rd0TOo\Oa:Wn0[FhPO0Rd0TOo\O`:Xn0\FgPO0Rd0TOo\O_:Yn0]FfPO0Rd0TOo\O_:Yn0]FfPO0Rd0TOo\O^:Zn0^FePO0Rd0TOo\O]:[n0_FdPO0Rd0TOo\O]:[n0_FdPO0Rd0TOo\O\:\n0`FdPOOQd0UOo\O[:]n0aFcPOOQd0UOo\O[:]n0aFcPOOQd0UOo\OZ:^n0bFbPOOQd0UOo\OY:_n0cFaPOOQd0UOo\OY:_n0cFaPOOQd0VOn\OW:an0dF`POORd0UOm\OW:bn0eF_POORd0UOm\OW:bn0eF_POORd0UOm\OV:cn0fF^POORd0UOm\OU:dn0gF^PONQd0VOm\OU:dn0gF^PONQd0VOm\OT:en0hF]PONQd0VOm\OS:fn0iF\PONQd0VOm\OS:fn0iF\POMRd0WOl\OR:gn0jF[POMRd0WOl\OQ:hn0kFZPOMRd0WOl\OQ:hn0kFZPOMRd0WOl\OP:in0lFYPOMRd0WOl\Oo9jn0mFXPOMRd0WOl\Oo9jn0mFYPOLQd0XOl\On9kn0mFYPOMPd0XOl\Om9ln0nFXPOMPd0YOk\Ol9mn0nFXPOMPd0YOk\Ok9nn0oFWPOMPd0YOk\Oj9on0PGVPOMPd0YOk\Oj9on0PGVPOMPd0YOk\Oi9Po0QGUPOMPd0YOk\Oh9Qo0RGTPOMPd0YOk\Oh9Qo0RGTPOMPd0YOk\Og9Ro0SGSPO5hc0QOS]Of9So0TGSPOd0Wc0bNc]Of9So0TGSPOS1hb0SNR^Oe9So0VGSPOb1Xb0cMb^Oe9So0VGSPOQ2ia0TMQ_Od9To0WGRPOa2Za0cL`_Od9Uo0XGQPOP3k`0TLo_Od9Uo0XGQPO`3[`0dK`@b9Uo0ZGPPOP4k?TKPAa9Vo0[GooN_4\?eJ_Aa9Vo0[GooNo4l>VJnA_9Xo0\GooN]5\>hI]B^9Yo0]GnoNm5l=XImB^9Yo0]GnoN\6]=iH\C]9Zo0^GmoNl6m<YHlC\9[o0_GloN[7^<jG[D\9[o0_GloNk7n;ZGkD[9\o0`GkoNZ8_;kFZEZ9]o0aGjoNj8o:[FjEZ9]o0aGjoNY9`:lEYFY9^o0bGioNi9P:\EiFX9_o0cGhoNX:a9mDXGX9_o0cGioNg:P9^DhGW9`o0dGhoNV;a8oCWHV9ao0eGgoNf;Q8_CgHV9ao0eGgoNV<a7oBWIU9bo0fGfoNe<R7`BfIT9co0gGeoNU=b6QBUJS9do0fGfoNe=R6bAdJR9eo0gGeoNU>b5RATKQ9fo0hGdoNd>S5c@cKQ9fo0hGdoNT?c4S@SLP9go0iGdoNb?S4e_ObLo8ho0jGcoNR`0c3U_ORMo8ho0jGcoNa`0U3e^O`Mo8io0kGboNQa0e2U^OPNn8jo0lGaoN`a0V2f]O_Nn8jo0lGaoNPb0f1V]OoNm8ko0mG`oN_b0W1g\O^Ol8lo0nG_oNob0g0W\ONl8lo0nG_oN^c08h[O=k8mo0oG^oNnc0HX[Om0j8no0PH^oN]d0WOiZO]1j8no0PH^oNld0hNZZOl1i8oo0QH]oN\e0XNkYO[2g8QP1RH\oNke0iM\YOj2g8QP1RH\oN[f0YMlXOZ3f8RP1SH[oNjf0jL]XOi3e8SP1THZoNZg0ZLmWOY4e8SP1THZoN_k0c0\\OTP1UHYoN_k0c0[\OUP1VHXoN_k0c0[\OUP1VHXoN_k0c0Z\OVP1WHXoN^k0b0Z\OWP1XHWoN^k0b0Z\OWP1XHWoN^k0b0Y\OXP1YHVoN^k0b0X\OYP1ZHUoN^k0b0X\OYP1ZHUoN^k0b0W\OYP1\HUoN]k0b0W\OYP1\HUoN]k0b0V\OZP1]HToN]k0b0U\O[P1^HSoN^k0a0T\O\P1^HToN]k0`0T\O]P1_HSoN]k0`0S\O^P1_HSoN^k0?S\O^P1_HSoN^k0?R\O_P1`HRoN^k0?Q\O`P1aHQoN^k0?Q\O`P1aHQoN^k0`0o[O`P1cHPoN^k0`0n[OaP1dHonN^k0`0n[OaP1dHonN^k0`0m[ObP1eHnnN^k0`0l[OcP1fHnnN]k0?m[OcP1fHnnN]k0?l[OdP1gHmnN]k0?k[OeP1hHlnN]k0?k[OeP1hHlnN]k0?j[OfP1iHknN^k0>h[OhP1jHjnN^k0>h[OhP1jHjnN^k0>g[OiP1kHinN^k0>f[OjP1lHhnN^k0>f[OjP1lHinN]k0=f[OkP1mHhnN]k0=e[OlP1nHgnN]k0=e[OlP1nHgnN]k0=d[OmP1oHfnN]k0=c[OnP1PIenN]k0=c[OnP1PIenN]k0=b[OoP1QIdnN]k0=a[OPQ1RIcnN]k0=a[OPQ1RIcnN]k0=`[OQQ1SIbnN]k0=_[ORQ1TIbnN\k0<`[ORQ1TIbnN]k0;^[OTQ1UIanN]k0;][OUQ1VI`nN]k0;][OUQ1VI`nN]k0;\[OVQ1WI_nN]k0;[[OWQ1XI^nN]k0;[[OWQ1XI^nN]k0;Z[OXQ1XI^nN^k0:Y[OYQ1YI]nN^k0:Y[OYQ1YI^nN]k09Y[OZQ1ZI]nN]k09X[O[Q1[I\nN]k09X[O[Q1[I\nN]k09W[O\Q1\I[nN]k09V[O]Q1]IZnN]k09V[O]Q1]IZnN]k09U[O^Q1^IYnN]k09T[O_Q1_IXnN]k09T[O_Q1_IXnN^k08R[O`Q1aIYnN\k07R[OaQ1bIXnN\k07R[OaQ1bIXnN\k07Q[ObQ1cIWnN\k07Q[ObQ1cIWnN\k07P[OcQ1dIVnN\k07oZOdQ1eIUnN\k07oZOdQ1eIUnN\k07nZOeQ1fITnN\k07mZOfQ1gISnN\k07mZOfQ1gISnN\k07lZOgQ1hISnN[k06lZOhQ1iIRnN[k06lZOhQ1iIRnN[k06kZOiQ1jIQnN[k06jZOjQ1kIPnN[k06jZOjQ1kIPnN\k06gZOkQ1mIomN\k06fZOlQ1nInmN\k06fZOlQ1nInmN\k06eZOmQ1oImmN\k06dZOnQ1PJmmN[k05eZOnQ1PJmmN[k05dZOoQ1QJlmN[k05cZOPR1RJkmN[k05cZOPR1QJlmN\k04bZOQR1RJkmN\k04aZORR1SJjmN\k04aZORR1SJjmN\k04`ZOSR1TJimN\k04_ZOTR1UJhmN\k04_ZOTR1UJhmN\k04^ZOUR1VJhmN[k03^ZOVR1WJgmN\k02]ZOWR1WJgmN\k02\ZOXR1XJfmN\k02[ZOYR1YJemN\k02[ZOYR1YJemN\k02ZZOZR1ZJdmN\k02YZO[R1[JcmN\k02YZO[R1[JcmN\k02XZO\R1\JbmN\k02WZO]R1]JbmN[k01XZO]R1]JbmN[k01WZO^R1^JamN[k01VZO_R1_J`mN[k01VZO_R1_J`mN[k01UZO`R1`J_mN[k01TZOaR1aJ^mN[k01TZOaR1aJ^mN[k01SZObR1bJ]mN[k01RZOcR1cJ\mN\k00QZOdR1cJ]mN[k0OQZOeR1dJ\mN[k0OPZOfR1eJ[mN[k0OPZOeR1fJ\mNZk0OoYOfR1gJ[mNZk0OnYOgR1hJZmNZk0OnYOgR1hJZmNZk0OmYOhR1iJYmNZk0OmYOhR1iJYmN_j0j0gZOnQ1jJXmNih0`2\\OYP1jJXmNTg0U4R^Ocn0jJYmN]e0j5h_Onl0kJXmNhc0_7\AZk0lJWmNRb0U9RCdi0lJWmN\`0k:gDog0mJVmNf>a<\FZf0nJUmNQ=V>QHed0nJUmN[;l?fIPc0oJTmNe9ba0[K[a0PKSmNP8Wc0PMf?PKSmNZ6md0eNQ>QKSmNc4bf0;\<RKRmNm2Xh0Q2f:RKRmNX1mi0e3R9SKQmNBck0Z5]7TKPmNlMYm0P7g5TKPmNVLPo0d8Q4VKZ1i4gNWKY1i4gNWKY1h4hNXKX1g4iNYKW1g4iNYKW1f4jNZKV1e4kN[KU1e4kN[KU1d4lN\KT1c4mN]KS1c4mN]KS1b4nN^KR1a4oN_KQ1a4oN_KQ1`4PO`KP1_4QOaKo0_4QOaKo0^4RObKn0]4SOcKm0]4SOcKm0\4TOcKm0\4TOdKl0\4TOdKl0[4UOeKk0Z4VOfKj0Z4VOfKj0Y4WOgKi0X4XOhKh0X4XOhKh0W4YOiKg0V4ZOjKf0V4YOkKg0T4ZOlKf0S4[OmKe0S4[OmKe0R4\OnKd0R4\OnKd0Q4]OoKc0P4^OPLb0P4^OPLb0o3_OQLa0n3@RL`0n3@RL`0m3ASL?l3BTL>l3BTL>k3CUL=j3DVL<j3DVL<i3EWL;h3FXL:h3FXL:g3GYL9f3HZL8f3HZL8e3I[L7d3J\L6d3J[L7d3J\L6c3K]L5c3K]L6a3K_L5`3L`L4`3L`L4_3MaL3^3NbL2^3NbL2]3OcL1\30dL0\30dL0[31eLOZ32fLNZ32fLNY33gLMX34hLLX34hLLW35iLKV36jLJV36jLJU37kLIT38lLHT38lLHS39mLGR3:nLFR3:nLFQ3;oLEP3;QMEo2;QMEn2<RMDm2=SMCm2=SMCl2>TMBk2?UMAk2?UMAj2`0UMAk2?UMAj2`0VM@i2a0WM_Oi2a0WM_Oh2b0XM^Og2c0YM]Og2c0YM]Of2d0ZM\Oe2e0[M[Oe2e0[M[Od2f0\MZOc2g0]MYOc2g0]MYOb2h0^MXOa2i0_MWOa2i0_MWO`2j0`MVO_2k0aMUO_2k0aMUO^2l0bMTO]2m0cMSO]2m0cMSO\2n0dMRO[2o0eMQO[2o0eMQOZ2P1fMPOY2Q1gMoNY2Q1gMPOW2Q1iMoNV2R1jMnNV2R1jMnNU2S1kMmNT2T1lMlNT2T1lMlNS2U1mMkNR2V1nMjNR2V1nMjNQ2W1nMjNQ2W1oMiNQ2W1oMiNP2X1PNhNo1Y1QNgNo1Y1QNgNn1Z1RNfNm1[1SNeNm1[1SNeNl1\1TNdNk1\1VNdNj1\1VNdNi1]1WNcNh1^1XNbNh1^1XNbNg1_1YNaNf1`1ZN`Nf1`1ZN`Ne1a1[N_Ne1a1[N_Nd1b1\N^Nc1c1]N]Nc1c1]N]Nb1d1^N\Na1e1_N[Na1e1_N[N`1f1`NZN_1g1aNYN_1g1aNYN^1h1bNXN]1i1cNWN]1i1cNWN\1j1dNVN[1k1eNUN[1k1eNUNZ1l1fNTNY1m1gNSNY1m1fNTNY1m1gNSNX1n1hNRNX1n1hNRNW1o1iNQNV1P2jNPNV1P2jNPNU1Q2kNoMT1R2lNnMT1R2lNnMS1S2mNmMR1T2nNlMR1T2nNlMQ1U2oNkMP1V2POjMP1V2POkMn0V2ROjMm0W2SOiMm0W2SOiMl0X2TOhMk0Y2UOgMk0Y2UOgMj0Z2VOfMi0[2WOeMi0[2WOeMh0\2XOdMg0]2YOcMg0]2YOcMf0^2ZObMe0^2\ObMd0^2\ObMc0_2]OaMb0`2^O`Mb0`2^O`Ma0a2_O_M`0b2@^M`0b2@^M?c2@^M?c2A]M?c2A]M>d2B\M>d2B\M=e2C[M<f2DZM<f2DZM;g2EYM:h2FXM:h2FXM9i2GWM8j2HVM8j2HVM7k2IUM6l2JTM6l2JTM5m2KSM4n2LRM4n2LRM3o2MQM2P3NPM2P3NPM1Q3OoL0R30nL0R30nLOS31mLNT32lLNT32lLMU33kLLV34jLLV34jLKW35iLJX36hLJX36hLIY37gLHZ38fLHZ38fLG[38fLG[39eLG[39fLE[3;eLD\3<dLD\3<dLC]3=cLB^3>bLB^3>bLA^3`0bL_O_3a0aL_O_3a0aL^O`3b0`L]Oa3c0_L]Oa3c0_L\Ob3d0^L[Oc3e0]L[Oc3e0]LZOd3f0\LYOe3W2kJiMU5U5mGjJT8T8nDlGR;R;PBmDQ>Q>Q_OnAPa0Pa0R\OP_Onc0nc0TYOQ\Omf0mf0UVORYOli0li0VSOTVOjl0jl0XPOUSOio0io0YmNVPOhR1hR1ZjNXmNfU1fU1\gNYjNeX1eX1]dNZgNd[1i]10O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O00100O1O100O1O100O1O100O1O100O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O10O01O100O1O100O1O100O1O100O1O100O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O10O01O100O1O100O1O100O1O100O1O100O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O100O1O10O01O100O1O100O1O100O1O100O1O100O1O100O100O1O100O1O100O1O;Fb0]Oc0]Oc0^Ob0]Od0\Oc0^Ob0]Oc0]Oc0^Oc0\Oc0]Oc0^Ob0]Oc0]Od0]Ob0]Oc0]Oc0^Ob0]Od0\Oc0^Ob0]Oc0]Oc0^Oc0\Oc0]Oc0^Ob0]Oc0]Od0]Ob0]Oc0]Oc0^Ob0]Od0\Oc0^Ob0]Oc0]Oc0^Ob0]Od0\Oc0^Ob0]Oc0]Oc0^Oc0\Oc0^Ob0]Oc0]Oc0^Oc0\Oc0]Oc0^Ob0]Oc0]Od0]Ob0]Oc0]Oc0^Ob0]Od0\Oc0^Ob0]Oc0]Oc0^Oc0\Oc0]Oc0^Ob0]Oc0]Od0]Ob0]Oc0]Oc0^Ob0]OZ^Rb2",
}
